#include "graphic.h"
#include "board.h"
#include "mqx.h"
#include "Driver_SLCD.h"
#include "Driver_Buzzer.h"
#include <fio.h>


void help(void){

unsigned char menuitem,r,c;
// Draw the various help menu items
    for (menuitem=0; menuitem<16; menuitem++){
      clear_board();
      for(r=0;r<BOARDROWSMAX; r++){
          for(c=0;c<8;c++)
          {
            board[r][7-c] = ((help_graphic[menuitem][r+2])>>c)&0x01;
          }
      } // r
      render();
      _Buzzer_On(help_graphic[menuitem][0]);
      _time_delay(100*help_graphic[menuitem][1]);
    } // for menuitem   
}
                            
                            
void clear_board(void){
unsigned char r,c;
// clear the screen
    for (r=0; r<BOARDROWSMAX; r++){
      for(c=0;c<8;c++)
      {
        board[r][c] = 0x00;
      }
    } // for r 
}

void clear_next(void){
unsigned char r,c;
// clear the screen
    for (r=0; r<START_ROW; r++){
      for(c=0;c<8;c++)
      {
        board[r][c] = 0x00;
      }
    } // for r 
}
void fretris_logo(void){
unsigned char r,c;
// display the title screen
    for (r=0; r<BOARDROWSMAX; r++){
      for(c=0;c<8;c++)
      {
        board[r][7-c] = fretris[c][r];
      }
    } // for r
}

void wait_play(void){
/* The score has been displayed with Pounce's _SLCDModule_PrintString(buffer, position) so
   we will just write directly to the screen, not to the board[][] array
*/
  
    _SLCDModule_SetSegment(0,0 );  
    _SLCDModule_SetSegment(0,1 );  
    _time_delay(200);        
    _SLCDModule_ClearSegment(0,0 );
    _SLCDModule_ClearSegment(0,1 );  
    _time_delay(200);
}
void display_score(unsigned char eight, unsigned char sixfour){
unsigned char r,c;
// clear the screen
    for (r=SCOREPOSITION; r<BOARDROWSMAX; r++){
      for(c=0;c<8;c++)
      {
        board[r][c] = 0x01;
      }
    } // for r 
    if (eight > 0)board[SCOREPOSITION][eight-1] = 0x00;
    if (sixfour > 0) board[SCOREPOSITION+1][sixfour-1] = 0x00;
}


/* FUNCTION - ghost ************************************************************

   Show where a block is going to fall

 ********************************************************************************/

void ghost(unsigned char *pt, char column)

{
  unsigned	char r,c;
  for(r=0;r<4;r++) 
  {
    for(c=0;c<4;c++)
    {
      if (pt[r*4+c]!=0)
      {
        board[GHOST_ROW][column+c] = 0x00;
      }
    }
  }
}
/* FUNCTION - unghost **********************************************************

   Clear the ghost row

********************************************************************************/

void unghost(void)

{
  unsigned char c;
  for(c=0;c<8;c++)
  {
    board[GHOST_ROW][c] = 0x01;
  }
}
/* FUNCTION - draw *************************************************************

   Draw a Block (see the NOTE in "graphic.h")

   The piece is referred to by pointer pt.
   The piece is at location (row, column) but the first positive pixel may not 
   be at this location
   For example (r,c) 0,0,0,0
                     0,0,0,0
                     0,0,0,0
                     1,1,1,1

   erase - we pass in DRAWDRAW or DRAWERASE to set or clear the pixel

********************************************************************************/

void draw(unsigned char *pt,unsigned char row,char column, unsigned char erase)

{
  unsigned	char r,c, C;
  for(r=0;r<4;r++) 
  {
    for(c=0;c<4;c++)
    {
      if (pt[r*4+c]!=0)
      {
        C = (unsigned char) column+c;
        board[row+r][C] = erase;
      }
    }
  }
}
/* FUNCTION - logo *************************************************************

   Draw a logo

   The logo is referred to by pointer pt.
   The logo is at location (row, column) but the first positive pixel may not 
   be at this location

erase - we pass in DRAWDRAW or DRAWERASE to set or clear the pixel

********************************************************************************/

void logo(void)

{
  unsigned	char r,c;
  for(r=0;r<BOARDROWSMAX;r++) 
  {
    for(c=0;c<8;c++)
    {
 
        board[r][c] = fsl_logo[r][c];
      
    }
  }
}

/* FUNCTION - render ***********************************************************

   Draw the screen onto the panel

********************************************************************************/

void render(void)

{
  unsigned	char r,c;
  for(r=0;r<BOARDROWSMAX;r++) 
  {
    for(c=0;c<8;c++)
    {
      if (board[r][c]==0)
      {
        // The function call is (x,y) where x<37 and y<8.
        _SLCDModule_ClearSegment(r,7-c );
      }
      else {
        _SLCDModule_SetSegment(r,7-c );
      }
    }
  }
}

/* FUNCTION - block8 ***********************************************************

   Flash a full line, then remove it and drop the lines above.

********************************************************************************/

void block8(unsigned char row8)

{
  unsigned char r,c,x,t;
  
  for (x=0;x<7;x++){
    t = (x&0x01);
    for(c=0;c<8;c++)
    {
      board[row8][c]= t;
    }
    render();
    _time_delay(100);    
  }
// Now shift all the rows down to row8...

  
  for (r=row8; r>START_ROW; r--){
    for (c=0; c<8; c++){
      board[r][c] = board[r-1][c];     
    }
  }
 /*
  
  for (r=START_ROW; r<row8; r++){   //r= 5 so sum below is broken.
    for (c=0; c<8; c++){
      board[row8-r][c] = board[row8-(r+1)][c]; 
     }
  }*/
  render();
}

/* FUNCTION - game_over ********************************************************

   Animate the end of the game

********************************************************************************/

void game_over (unsigned long score)

{
  unsigned	char r,c,x,t;
  unsigned char buffer[5];
  
  for (x=0;x<12;x++){
    for (r=0; r<BOARDROWSMAX-2; r++){
      for(c=0;c<8;c++)
      {
        t = board[r][c];
        board[r][c] = ~t;
      }
    } // for r
    render();
    _time_delay(150);
  }  

  clear_board();
  render();
  if (score < 100000L ) {
    sprintf((char *)buffer, "%05d", score);
    _SLCDModule_PrintString((char *)buffer, 2);
  }
}


/* FUNCTION - check_row ********************************************************

   Determine if any row now has 8 piece.
   Return the row number if there is a complete row,
   otherwise, return 0xFF
   (cannot return a code of zero, since row zero may be full)

********************************************************************************/

unsigned char check_row(void)

{
  unsigned char r,c;
  unsigned char temp;
  
  for(r=START_ROW;r<STOP_ROW;r++)
  {
    temp = 0;
    for(c=0;c<8;c++)
    {
      temp += board[r][c];
    }
    if (temp == 8) return r;
   }
  return 0xFF;
}



/* FUNCTION - move_allowed *****************************************************

   Test to see if we can move

   The piece is referred to by pointer pt.
   The piece is at CURRENT location (c_row, c_column)
   
   Test directions are rr, cc, signed integers
   Move left: cc = -1
   Move right: cc = 1
   Move down: rr = 1
  
   For example, test(10,4,0,-1,pt) checks if you can move left _from_ (10,4)
                            ==
   Returns FALSE if the move is not allowed

********************************************************************************/

int move_allowed(unsigned char c_row, char c_column, int rr, int cc, unsigned char *pt)

{
  unsigned char r,c, C;
  int validmove = TRUE;

  for (r=0;r<4;r++)
  {
    for (c=0;c<4;c++)
    {
      if (pt[r*4+c]!=0)
      {
        C = (unsigned char) c_column+c;
        // Test if moving off the left of the board.
        // Some pieces do not have a pixel in the first column.
        if (cc == -1) { // Moving Left
          if ((C - 1) < 0) validmove = FALSE;          
        }


        // Test if moving off the right of the board.
        // Some pieces do not have a pixel in the fourth column.
 
         if (cc == 1) { // Moving Right
        if ((C+1)  > 7) validmove = FALSE;   
        }       
        // Test the rare case of moving off the bottom of the board.
        // Some pieces do not have a pixel in the fourth row.
 //       if (((c_row + rr) + r)  > 28) validmove = FALSE;

        if (rr == 1) { // Moving down
          if ((c_row+r) >= STOP_ROW ) {   // Off the end of the board
            validmove = FALSE;
            return validmove;
          } 
          
          // lastly, the case where the space on the board is occupied.
          if (board[c_row+r][C]!=0) validmove = FALSE;
        } // Moving down
      }
    }
  } 
  return validmove;
}


/* FUNCTION - spin_fix *********************************************************

   Make sure a spin does not make us fall off the edge.

   The piece is referred to by pointer pt.
   The piece is at CURRENT location (c_row, c_column)
   
   Test directions are rr, cc, signed integers
   Move left: cc = -1
   Move right: cc = 1
   Move down: rr = 1
  
   For example, test(10,4,0,-1,pt) checks if you can move left _from_ (10,4)
                            ==
   Returns a value to offset the piece if we span too close to an edge

********************************************************************************/

int spin_fix(unsigned char c_row, char c_column, unsigned char *pt)

{
  int r,c;
  int fix = 0;
  int fix_max = 0;
  int ret = 0;

  for (r=0;r<4;r++)
  {
    for (c=0;c<4;c++)
    {
      if (pt[r*4+c]!=0)
      {
        // What column did the spin end up in....
          fix =  c_column + c;
          if (fix > fix_max) fix_max = fix;

      }
    }
  }
  if (fix_max > 7) ret = (fix_max - 7);
  return ret;
}
