#include "Remote_Control.h"
#include <event.h>

/**
  Enumerations for:
    - Remote Control State Machine states.
    - Remote Control Commands
    - Devices
    - Sending Command State Machine states.
*/
enum 
{
  REMOTE_INIT = 0,
  REMOTE_MAIN,
  SEND_COMMAND,
  DELAY_COMMAND,
  EXIT                              
}eRemoteControl;

enum
{
  POWER = 0,
  CHANNEL_UP,
  CHANNEL_DOWN,
  VOLUME_UP,
  VOLUME_DOWN
}eCommands;

enum
{
  TV = 0,
  VCR,
  LASER_DISC_UNIT,
  SURROUND_SOUND,
  CD_PLAYER
}eDevices;

enum
{
  HEADER = 0,
  DATA,
  SEND_DELAY
}eSendCommand;

/**
  Local Function Prototypes
*/

void _RemoteControl_Electrode_Check(void);
void _RemoteControl_Send_Command(U08 Command, U08 Device);
void _FlexTimer_FTM2_Loop(void);

/**
  Global Variable Arrays
*/
U08 Commands[5][7] = 
{
  {1,0,1,0,1,0,0},  // POWER
  {0,0,0,0,1,0,0},  // CHANNEL UP
  {1,0,0,0,1,0,0},  // CHANNEL DOWN
  {0,1,0,0,1,0,0},  // VOLUME UP
  {1,1,0,0,1,0,0}   // VOLUME DOWN
};

U08 Address[5][5] = 
{
  {1,0,0,0,0},  //TV
  {0,1,0,0,0},  //VCR  
  {0,1,1,0,0},  //LASER DISC UNIT
  {0,0,1,1,0},  //SURROUND SOUND
  {1,0,0,0,1}   //CD PLAYER 
};

STRING RemoteMenuList[6] = 
{
  "POWER",
  "CH UP",
  "CH DW",
  "VOL",
  "VOL",
  "EXIT"
};

/**
  Global Variables
*/
BOOL is600uS = FALSE;
BOOL isStartPWM = FALSE;
BOOL isSendCommandFiveTimes = FALSE;
U08 RemoteControlStateMachine = REMOTE_INIT;
U08 Command = POWER;
U08 Device = TV;
U08 Data[12] ={0};
U08 SentFiveTimes = 0;
U08 RemoteMenuIndex = 0;
static BOOL isDelayCommand = TRUE;
static BOOL isSendingCommand = TRUE;

/**
  Function Name	: _RemoteControl_Task
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This is the remote application function. It initializes the FlexTimer and GPIO's needed.
                  After that it falls into a simple state machine, where it will remain until the break condition
                  is met. While no touch event occurs it will keep showing its execution options. This application was
                  hardcoded to use the SIRC - 12 Bit protocol.
*/
void _RemoteControl_Task(uint_32 param)
{
   static U08 CommandDelay = COMMAND_DELAY;
   pointer electrode_event;

   /* open event connection */
   if (_event_open("event.global",&electrode_event) != MQX_OK)  
   {
      printf("\nOpen Event failed");
      _mqx_exit(0);
   }
  
  while (1)
  {    
    //Wait for RemoteControl mode to be entered
    while(MainMenuStateMachine!=REMOTE_CONTROLLER)
    {
      _time_delay(500);
    }

    switch (RemoteControlStateMachine)
    {
      case REMOTE_INIT:
        ElectrodeFlags = 0;
        RemoteMenuIndex = 0;
        _FlexTimer_Init(FTM2,DIV_BY_16,INTERRUPT_ENABLE,50);  
        _GPIO_Init(PORTE,4);
        (void)TSS_SetSystemConfig(System_ElectrodeEnablers_Register,0x33); 
        (void)TSS_KeypadConfig(cKey0.ControlId,Keypad_MaxTouches_Register,1);            

        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[0], 5);
        _SLCDModule_PrintRCBlocks(UPPER_LEFT);
        _time_delay(800);
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[1], 0);
        _SLCDModule_PrintRCBlocks(UPPER_RIGHT);          
        _time_delay(800);
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[2], 0);
        _SLCDModule_PrintRCBlocks(LOWER_RIGHT);          
        _time_delay(800);
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[5], 10);
        _SLCDModule_PrintRCBlocks(LOWER_LEFT);          
        _time_delay(800);
        _SLCDModule_ClearLCD(NO_ARROWS);

        RemoteMenuIndex = 0;
        RemoteControlStateMachine = REMOTE_MAIN;      
      break;

     case REMOTE_MAIN:
      if ((RemoteMenuIndex == 0) )
      {       
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[RemoteMenuIndex++], 5);
        _SLCDModule_PrintRCBlocks(UPPER_LEFT);
      }
      else if ((RemoteMenuIndex == 1) )
      {
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[RemoteMenuIndex++], 0);
        _SLCDModule_PrintRCBlocks(UPPER_RIGHT);          
      }
      else if ((RemoteMenuIndex == 2) )
      {
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[RemoteMenuIndex++], 0);
        _SLCDModule_PrintRCBlocks(LOWER_RIGHT);          
      }
      else if ((RemoteMenuIndex == 3))
      {
        _SLCDModule_ClearLCD(NO_ARROWS);
        _SLCDModule_PrintString(RemoteMenuList[5], 10);
        _SLCDModule_PrintRCBlocks(LOWER_LEFT);          
        RemoteMenuIndex = 0;
      }
      
      if (!(_event_wait_any(electrode_event, 0x3F, 1000) != MQX_OK)) 
      /* touch event happened to escape the wait loop, so process
       * the touch to determine what action to take. 
       */
        _RemoteControl_Menu_Parse(electrode_event);
    break;      
    
    case SEND_COMMAND:        
        if (isSendCommandFiveTimes)
        {
          RemoteControlStateMachine = REMOTE_MAIN;
          isSendCommandFiveTimes = FALSE;
          _SLCDModule_TurnOffWirelessSign();
          _time_delay(200);
          RemoteMenuIndex = 0;
          isSendingCommand = FALSE;
        }
        else
        {
          isSendingCommand = TRUE;
          _RemoteControl_Send_Command(Command, Device);        
          if (SentFiveTimes == 5)
          {
            isSendCommandFiveTimes = TRUE;
            SentFiveTimes = 0;
          }      
        }
      break;
    
      case DELAY_COMMAND:
        while(isDelayCommand)
        {
          if (is600uS)
          {
            is600uS = FALSE;          
            CommandDelay--;
            if (CommandDelay == 0)
            {
              RemoteControlStateMachine = SEND_COMMAND;
              CommandDelay = COMMAND_DELAY;
              isDelayCommand = FALSE;
            }
          } 
        }
      break;
    
      case EXIT:
        _FlexTimer_Disable(FTM2);
        MainMenuStateMachine = MAIN;
        _SLCDModule_ClearLCD(NO_ARROWS);
        RemoteControlStateMachine = INIT;
        isMarqueeRestart = TRUE;
        ElectrodeFlags = 0;
      break;
    
    default:
      break;
    }
  }    
}

/**
  Function Name	: _RemoteControl_Menu_Parse

Notes: This function is used process touch events after one has been
       detected. The function will determine which electrode was
       touched, take the appropriate action, then clear all event
       flags.
Parameters: electrode_event point to the event group storing touch events
Returns: None
*/
void _RemoteControl_Menu_Parse(pointer electrode_event)
{ 
  uint_32 electrode_value;
  
  
  if (_event_get_value(electrode_event, &electrode_value) != MQX_OK)  
  {
    printf("\nGet Event failed");
    _mqx_exit(0);
  }

   
  if (electrode_value & TSS_ELECTRODE_0)
  {
    _SLCDModule_ClearLCD(NO_ARROWS);
    Command = POWER;
    RemoteControlStateMachine = SEND_COMMAND;
    is600uS = TRUE;
    _SLCDModule_PrintString(RemoteMenuList[POWER], 4);
    _SLCDModule_TurnOnWirelessSign();    
    ElectrodeFlags = 0;
    /* Clear all event flags */
    _event_clear(electrode_event, 0x3F);
    _Buzzer_On(40);    
    while(isBuzzerOn){}
    isSendingCommand = TRUE;
  }
  
  
  if (electrode_value & TSS_ELECTRODE_1)
  {
    _SLCDModule_ClearLCD(NO_ARROWS);
    Command = CHANNEL_UP;
    RemoteControlStateMachine = SEND_COMMAND;  
    is600uS = TRUE;
    _SLCDModule_PrintString(RemoteMenuList[CHANNEL_UP], 4);
    _SLCDModule_TurnOnWirelessSign();        
    ElectrodeFlags = 0;
    /* Clear all event flags */
    _event_clear(electrode_event, 0x3F);
    _Buzzer_On(40);   
    while(isBuzzerOn){}        
    isSendingCommand = TRUE;
  }
  if (electrode_value & TSS_ELECTRODE_5)
  {
    _SLCDModule_ClearLCD(NO_ARROWS);
    Command = CHANNEL_DOWN;
    RemoteControlStateMachine = SEND_COMMAND;  
    is600uS = TRUE;
    _SLCDModule_PrintString(RemoteMenuList[CHANNEL_DOWN], 4);
    _SLCDModule_TurnOnWirelessSign();     
    ElectrodeFlags = 0;
    /* Clear all event flags */
    _event_clear(electrode_event, 0x3F);
    _Buzzer_On(40);   
    while(isBuzzerOn){}      
    isSendingCommand = TRUE;
  }  
  if (electrode_value & TSS_ELECTRODE_4)
  {
    RemoteControlStateMachine = EXIT;
    _SLCDModule_TurnOffWirelessSign();  
    _SLCDModule_ClearLCD(NO_ARROWS);
    ElectrodeFlags = 0;
    /* Clear all event flags */
    _event_clear(electrode_event, 0x3F);
    _Buzzer_On(40);    
    while(isBuzzerOn){}    
  }
}




/**
  Function Name	: _RemoteControl_Send_Command
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U08 Command, U08 Device
  Returns       : Nothing
  Notes         : This function manages the send command state machine. It receives which command will send
                  and to what device it is sending it to.              
*/
void _RemoteControl_Send_Command(U08 Command, U08 Device)
{
  static U08 SendCommandState = HEADER;
  static U08 PreviousState = 0;
  static U08 Index = 0;
  static U08 Delay = 0;
  U08 i = 0;  
  U08 j = 0;

  while(isSendingCommand)
  {
    if (is600uS) 
    { 
      is600uS = FALSE;    
      switch (SendCommandState)
      {
        case HEADER:        
          for (i = 0; i < (sizeof(Commands)/5); i++)
          {
            Data[i] = Commands[Command][i];
          }
          for (j = 0 ; j < (sizeof(Address)/5); j++)
          {
            Data[j + 7] = Address[Device][j];        
          }
          _GPIO_Set_Pin(PORTE,4); 
          isStartPWM = TRUE;
          Delay = START_BURST;
          SendCommandState = SEND_DELAY; 
          PreviousState = HEADER; 
          _FlexTimer_Enable(FTM2);
          break;
        case DATA:       
          if (Data[Index] == 0)
          {
            Delay = ONE_T;         
          }
          else if (Data[Index] == 1)
          {
            Delay = TWO_T;
          }
          else
          {
            //Nothing
          }
          
          Index++;
          
          if (Index > sizeof(Data))
          {
            SendCommandState = HEADER;
            Index = 0;
            isStartPWM = FALSE;
            _GPIO_Clear_Pin(PORTE,4);  
            SentFiveTimes++;
            RemoteControlStateMachine = DELAY_COMMAND;
            isSendingCommand = FALSE;
            isDelayCommand = TRUE;
          }
          else
          {
            _GPIO_Set_Pin(PORTE,4);  
            isStartPWM = TRUE;
            SendCommandState = SEND_DELAY;
            PreviousState = DATA;     
          }
          break;   
        case SEND_DELAY:
          Delay--;
          if (Delay == 0)
          {
            _GPIO_Clear_Pin(PORTE,4);    
            isStartPWM = FALSE;
            switch (PreviousState)
            {
              case HEADER:
                SendCommandState = DATA;
                break;
              case DATA:
                SendCommandState = DATA;
                break;
              default:
                break;        
            }          
          }
          break;
      }
    }
  }
}

/**
  Function Name	: _FlexTimer_FTM2_ISR
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: pointer isr
  Returns       : Nothing
  Notes         : This is the interrupt service routine of the FlexTimer
                  that generates the PWM signal to work with the SIRC complient
                  devices. Its current period is 60 KHz.
*/
void _FlexTimer_FTM2_ISR(pointer isr)
{
  volatile static U08 _600uS = 0;
  volatile static U08 _40KHz = 0;
  
  FTM2_SC &= ~(1 << FTM_SC_TOF_SHIFT);
  _600uS++;
  
  if (isStartPWM)
  {
    if (_40KHz == 0)
    {
      _GPIO_Clear_Pin(PORTE,4);
      _40KHz++;      
    }
    else
    {    
      _40KHz++;      
      _GPIO_Set_Pin(PORTE,4);
      if (_40KHz == 3)
      {
        _40KHz = 0;
      }
    }    
  }
  
  if (_600uS == 36)
  {
    is600uS = TRUE;
    _600uS = 0;
  }
}
