#include "Driver_ADC.h"
/**
  Local Functions Prototypes
*/

U08 _ADC_Cal(ADC_MemMapPtr adcmap);
void _ADC_Config(ADC_MemMapPtr adcmap, U08 CONFIG1, U08 CONFIG2, U16 COMPARE1, U16 COMPARE2, U08 STATUS2, U08 STATUS3, U08 STATUS1A, U08 STATUS1B, U32 PGA);
void _ADC_Config_Alt(ADC_MemMapPtr adcmap, tADC_ConfigPtr ADC_CfgPtr);
void _ADC_Read_Cal(ADC_MemMapPtr adcmap, tADC_Cal_Blk *blk);
void _ADC_Write_Cal(ADC_MemMapPtr adcmap, tADC_Cal_Blk *blk);

/**
  Global Variables
*/
tADC_Config Master_Adc_Config;
tADC_Cal_Blk CalibrationStore[2];

/**
  Function Name	: _ADC0_Init
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U08 ADC_Channel, U08 Channel_A_B, U08 Mode
  Returns       : Nothing
  Notes         : This function is used to initialize a given channel of ADC0. It receives which register (A or B) should be used and the
                  mode of operation (8, 9, 10...bits)
*/
void _ADC0_Init(U08 ADC_Channel, U08 Channel_A_B, U08 Mode)
{
   /* Turn on the ADCo and ADC1 clocks */
  SIM_SCGC6 |= (SIM_SCGC6_ADC0_MASK );
  
  /* setup the initial configuration */
  Master_Adc_Config.CONFIG1  = ADLPC_NORMAL | ADC_CFG1_ADIV(ADIV_4) | ADLSMP_LONG | ADC_CFG1_MODE(Mode)| ADC_CFG1_ADICLK(ADICLK_BUS);
  Master_Adc_Config.CONFIG2  = Channel_A_B | ADACKEN_DISABLED | ADHSC_NORMAL | ADC_CFG2_ADLSTS(ADLSTS_20) ;
  Master_Adc_Config.COMPARE1 = 0x00u ;
  Master_Adc_Config.COMPARE2 = 0x00u;
  Master_Adc_Config.STATUS2  = ADTRG_SW | ACFE_DISABLED | ACFGT_GREATER | ACREN_ENABLED | DMAEN_DISABLED | ADC_SC2_REFSEL(REFSEL_EXT);
  Master_Adc_Config.STATUS3  = CAL_OFF | ADCO_SINGLE | AVGE_DISABLED | ADC_SC3_AVGS(AVGS_32);
  Master_Adc_Config.PGA      = PGAEN_DISABLED | PGACHP_NOCHOP | PGALP_NORMAL | ADC_PGA_PGAG(PGAG_64);
  Master_Adc_Config.STATUS1A = AIEN_OFF | DIFF_SINGLE | ADC_SC1_ADCH(ADC_Channel);
  Master_Adc_Config.STATUS1B = AIEN_OFF | DIFF_SINGLE | ADC_SC1_ADCH(ADC_Channel);

  _ADC_Config_Alt(ADC0_BASE_PTR, &Master_Adc_Config);  // config ADC
  _ADC_Cal(ADC0_BASE_PTR);                    // do the calibration
  _ADC_Read_Cal(ADC0_BASE_PTR,&CalibrationStore[1]);   // store the cal
}

/**
  Function Name	: _ADC0_Read
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U08 ADC_Channel, U08 Channel_A_B
  Returns       : AdcValue
  Notes         : This function is used to read a given ADC0 channel and which register (A or B). It returns a 
                  unsigned short value.
*/
U16 _ADC0_Read(U08 ADC_Channel, U08 Channel_A_B)
{
  U16 AdcValue = 0;
  if (Channel_A_B == CHANNEL_A)
  {
    ADC0_SC1A = AIEN_OFF | ADC_SC1_ADCH(ADC_Channel);
    while ( (ADC0_SC1A & ADC_SC1_COCO_MASK) == COCO_NOT) {}  // Wait conversion end
    AdcValue = ADC0_RA;
  }
  else if (Channel_A_B == CHANNEL_B)
  {
    ADC0_SC1B = AIEN_OFF | ADC_SC1_ADCH(ADC_Channel);
    while ( (ADC0_SC1B & ADC_SC1_COCO_MASK) == COCO_NOT) {}  // Wait conversion end
    AdcValue = ADC0_RB;      
  }
  else
  {
    AdcValue = 0;
  }
  
  return AdcValue;
}

/**
  Function Name	: _ADC0_Disable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : Effectively disables the ADC0
*/
void _ADC0_Disable(void)
{
  SIM_SCGC6 &= ~(1 << SIM_SCGC6_ADC0_SHIFT);
}

/**
  Function Name	: _ADC1_Init
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U08 ADC_Channel, U08 Channel_A_B, U08 Mode
  Returns       : Nothing
  Notes         : This function is used to initialize a given channel of ADC1. It receives which register (A or B) should be used and the
                  mode of operation (8, 9, 10...bits)
*/
void _ADC1_Init(U08 ADC_Channel, U08 Channel_A_B, U08 Mode)
{
   /* Turn on the ADCo and ADC1 clocks */
  SIM_SCGC3 |= (SIM_SCGC3_ADC1_MASK );
  
  /* setup the initial configuration */
  Master_Adc_Config.CONFIG1  = ADLPC_NORMAL | ADC_CFG1_ADIV(ADIV_4) | ADLSMP_LONG | ADC_CFG1_MODE(Mode)| ADC_CFG1_ADICLK(ADICLK_BUS);
  Master_Adc_Config.CONFIG2  = Channel_A_B | ADACKEN_DISABLED | ADHSC_NORMAL | ADC_CFG2_ADLSTS(ADLSTS_20) ;
  Master_Adc_Config.COMPARE1 = 0x00u ;
  Master_Adc_Config.COMPARE2 = 0x00u;
  Master_Adc_Config.STATUS2  = ADTRG_SW | ACFE_DISABLED | ACFGT_GREATER | ACREN_ENABLED | DMAEN_DISABLED | ADC_SC2_REFSEL(REFSEL_EXT);
  Master_Adc_Config.STATUS3  = CAL_OFF | ADCO_SINGLE | AVGE_DISABLED | ADC_SC3_AVGS(AVGS_32);
  Master_Adc_Config.PGA      = PGAEN_DISABLED | PGACHP_NOCHOP | PGALP_NORMAL | ADC_PGA_PGAG(PGAG_64);
  Master_Adc_Config.STATUS1A = AIEN_OFF | DIFF_SINGLE | ADC_SC1_ADCH(ADC_Channel);
  Master_Adc_Config.STATUS1B = AIEN_OFF | DIFF_SINGLE | ADC_SC1_ADCH(ADC_Channel);

  _ADC_Config_Alt(ADC1_BASE_PTR, &Master_Adc_Config);  // config ADC
  _ADC_Cal(ADC1_BASE_PTR);                    // do the calibration
  _ADC_Read_Cal(ADC1_BASE_PTR,&CalibrationStore[1]);   // store the cal
}

/**
  Function Name	: _ADC0_Read
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U08 ADC_Channel, U08 Channel_A_B
  Returns       : AdcValue
  Notes         : This function is used to read a given ADC1 channel and which register (A or B). It returns a 
                  unsigned short value.
*/
U16 _ADC1_Read(U08 ADC_Channel, U08 Channel_A_B)
{
  U16 AdcValue = 0;
  if (Channel_A_B == CHANNEL_A)
  {
    ADC1_SC1A = AIEN_OFF | ADC_SC1_ADCH(ADC_Channel);
    while ( (ADC1_SC1A & ADC_SC1_COCO_MASK) == COCO_NOT) {}  // Wait conversion end
    AdcValue = ADC1_RA;
  }
  else if (Channel_A_B == CHANNEL_B)
  {
    ADC1_SC1B = AIEN_OFF | ADC_SC1_ADCH(ADC_Channel);
    while ( (ADC1_SC1B & ADC_SC1_COCO_MASK) == COCO_NOT) {}  // Wait conversion end
    AdcValue = ADC1_RB;      
  }
  else
  {
    AdcValue = 0;
  }
  
  return AdcValue;
}

/**
  Function Name	: _ADC1_Disable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : Effectively disables the ADC1
*/
void _ADC1_Disable(void)
{
  SIM_SCGC3 &= ~(1 << SIM_SCGC3_ADC1_SHIFT);
}

/**
  Function Name	: _ADC_Cal
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: ADC_MemMapPtr adcmap
  Returns       : 0
  Notes         : This function is used to calibrate the given ADC.
*/

U08 _ADC_Cal(ADC_MemMapPtr adcmap)
{

  U16 cal_var;

  ADC_SC2_REG(adcmap) &=  ~ADC_SC2_ADTRG_MASK ; // Enable Software Conversion Trigger for Calibration Process    - ADC0_SC2 = ADC0_SC2 | ADC_SC2_ADTRGW(0);
  ADC_SC3_REG(adcmap) &= ( ~ADC_SC3_ADCO_MASK & ~ADC_SC3_AVGS_MASK ); // set single conversion, clear avgs bitfield for next writing
  ADC_SC3_REG(adcmap) |= ( ADC_SC3_AVGE_MASK | ADC_SC3_AVGS(AVGS_32) );  // Turn averaging ON and set at max value ( 32 )


  ADC_SC3_REG(adcmap) |= ADC_SC3_CAL_MASK ;  // Start CAL
  
  while ((ADC_SC1_REG(adcmap,A) & ADC_SC1_COCO_MASK ) == COCO_NOT){} // Wait calibration end
  	
  if ((ADC_SC3_REG(adcmap)& ADC_SC3_CALF_MASK) == CALF_FAIL) 
  {
    return(1);    // Check for Calibration fail error and return
  }

  // Calculate plus-side calibration as per 21.4.7
  cal_var = 0x00;

  cal_var =  ADC_CLP0_REG(adcmap);
  cal_var += ADC_CLP1_REG(adcmap);
  cal_var += ADC_CLP2_REG(adcmap);
  cal_var += ADC_CLP3_REG(adcmap);
  cal_var += ADC_CLP4_REG(adcmap);
  cal_var += ADC_CLPS_REG(adcmap);

  cal_var = cal_var/2;
  cal_var |= 0x8000; // Set MSB

  ADC_PG_REG(adcmap) = ADC_PG_PG(cal_var);

  // Calculate minus-side calibration as per 21.4.7
  cal_var = 0x00;

  cal_var =  ADC_CLM0_REG(adcmap);
  cal_var += ADC_CLM1_REG(adcmap);
  cal_var += ADC_CLM2_REG(adcmap);
  cal_var += ADC_CLM3_REG(adcmap);
  cal_var += ADC_CLM4_REG(adcmap);
  cal_var += ADC_CLMS_REG(adcmap);

  cal_var = cal_var/2;

  cal_var |= 0x8000; // Set MSB

  ADC_MG_REG(adcmap) = ADC_MG_MG(cal_var);

  ADC_SC3_REG(adcmap) &= ~ADC_SC3_CAL_MASK ; /* Clear CAL bit */

  return(0);
}

/**
  Function Name	: _ADC_Config
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: ADC_MemMapPtr adcmap, U08 CONFIG1, U08 CONFIG2, U16 COMPARE1, U16 COMPARE2, U08 STATUS2, U08 STATUS3, U08 STATUS1A, U08 STATUS1B, U32 PGA
  Returns       : Nothing
  Notes         : This function is used to configure the given ADC.
*/
void _ADC_Config(ADC_MemMapPtr adcmap, U08 CONFIG1, U08 CONFIG2, U16 COMPARE1, U16 COMPARE2, U08 STATUS2, U08 STATUS3, U08 STATUS1A, U08 STATUS1B, U32 PGA)
{
  ADC_CFG1_REG(adcmap) = CONFIG1;
  ADC_CFG2_REG(adcmap) = CONFIG2;
  ADC_CV1_REG(adcmap) = COMPARE1;
  ADC_CV2_REG(adcmap) = COMPARE2;
  ADC_SC2_REG(adcmap) = STATUS2;
  ADC_SC3_REG(adcmap) = STATUS3;
  ADC_SC1_REG(adcmap,A) = STATUS1A;
  ADC_SC1_REG(adcmap,B) = STATUS1B;
  ADC_PGA_REG(adcmap) = PGA;
}

/**
  Function Name	: _ADC_Config_Alt
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: ADC_MemMapPtr adcmap, tADC_ConfigPtr ADC_CfgPtr
  Returns       : Nothing
  Notes         : This function is an alternate way used to configure the given ADC.
*/
void _ADC_Config_Alt(ADC_MemMapPtr adcmap, tADC_ConfigPtr ADC_CfgPtr)
{
  ADC_CFG1_REG(adcmap) = ADC_CfgPtr->CONFIG1;
  ADC_CFG2_REG(adcmap) = ADC_CfgPtr->CONFIG2;
  ADC_CV1_REG(adcmap)  = ADC_CfgPtr->COMPARE1;
  ADC_CV2_REG(adcmap)  = ADC_CfgPtr->COMPARE2;
  ADC_SC2_REG(adcmap)  = ADC_CfgPtr->STATUS2;
  ADC_SC3_REG(adcmap)  = ADC_CfgPtr->STATUS3;
  ADC_PGA_REG(adcmap)  = ADC_CfgPtr->PGA;
  ADC_SC1_REG(adcmap,A)= ADC_CfgPtr->STATUS1A;
  ADC_SC1_REG(adcmap,B)= ADC_CfgPtr->STATUS1B;
}

/**
  Function Name	: _ADC_Read_Cal
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: ADC_MemMapPtr adcmap, tADC_Cal_Blk *blk
  Returns       : Nothing
  Notes         : This function is used to read the calibration of the given ADC.
*/
void _ADC_Read_Cal(ADC_MemMapPtr adcmap, tADC_Cal_Blk *blk)
{
  blk->OFS  = ADC_OFS_REG(adcmap);
  blk->PG   = ADC_PG_REG(adcmap);
  blk->MG   = ADC_MG_REG(adcmap);
  blk->CLPD = ADC_CLPD_REG(adcmap);
  blk->CLPS = ADC_CLPS_REG(adcmap);
  blk->CLP4 = ADC_CLP4_REG(adcmap);
  blk->CLP3 = ADC_CLP3_REG(adcmap);
  blk->CLP2 = ADC_CLP2_REG(adcmap);
  blk->CLP1 = ADC_CLP1_REG(adcmap);
  blk->CLP0 = ADC_CLP0_REG(adcmap);
  blk->CLMD = ADC_CLMD_REG(adcmap);
  blk->CLMS = ADC_CLMS_REG(adcmap);
  blk->CLM4 = ADC_CLM4_REG(adcmap);
  blk->CLM3 = ADC_CLM3_REG(adcmap);
  blk->CLM2 = ADC_CLM2_REG(adcmap);
  blk->CLM1 = ADC_CLM1_REG(adcmap);
  blk->CLM0 = ADC_CLM0_REG(adcmap);
}
