#include "Driver_Buzzer.h"

/**
  Global variables
*/
static U16 mSec = 0;
volatile BOOL isBuzzerOn = FALSE;

/**
  Function Name	: _Buzzer_Init
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function is used to configure the correspoding pin and PIT0 to drive
                  the buzzer.
*/
void _Buzzer_Init(void)
{
  _GPIO_Init(PORTA,8);
  
  _PIT0_Init();
}

/**
  Function Name	: _Buzzer_On
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U16 MilliSeconds
  Returns       : Nothing
  Notes         : This function turns the Buzzer on for the received parameter
*/
void _Buzzer_On(U16 MilliSeconds)
{
  mSec = MilliSeconds;
  if (mSec>0) {
  isBuzzerOn = TRUE;
  
  _PIT0_Enable();
  while(isBuzzerOn){}
  }
}

/**
  Function Name	: _Buzzer_Off
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function disables the PIT0, thus the buzzer turns off.
*/
void _Buzzer_Off(void)
{
  _PIT0_Disable();
}

/**
  Function Name	: _PIT0_Isr
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: pointer isr
  Returns       : Nothing
  Notes         : This is the user defined interrupt service for the PIT0. The 
                  PIT's load value is rewritten, otherwise this interrupt will not
                  happen again.
*/
void _PIT0_Isr(pointer isr)
{ 
  volatile static U08 _250uS = 0;
 
  PIT_TFLG0 = 1;
  PIT_LDVAL0 = 12000; // 250uS

  if (_250uS < 1)
  {
    _GPIO_Set_Pin(PORTA, 8);
    _250uS++;
  }
  else 
  {
    _GPIO_Clear_Pin(PORTA, 8);
    _250uS++;
    if (_250uS == 4)
    {
      _250uS = 0;
      mSec--;
      if (mSec == 0)
      {
        _Buzzer_Off(); 
        isBuzzerOn = FALSE;
      }
    }
  }      
}











