#include "Driver_DAC.h"

/**
  Function Name	: _DAC0_Init
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function enables and configures the DAC0
*/
void _DAC0_Init(void)
{
  /**
    Enable the DAC0's clock
  */
  SIM_SCGC2 |= SIM_SCGC2_DAC0_MASK;

  /**
    Clear the DAC0's registers
  */  
  DAC0_C0 = 0;
  DAC0_C1 = 0;
  DAC0_C2 = 0;

  /**
    - Enable the DAC0 Module
    - Configure it to trigger via SW
    - Select the DACREF_2 Voltage reference
    - Disable the DAC buffer
    - Configure the buffer read pointer and the buffer upper limit
  */
  DAC0_C0 |= DAC_ENABLE | SW_TRIGGER | DACREF_2;
  DAC0_C1 = DAC_BUFFER_DISABLE;
  DAC0_C2 |= SET_BUFFER_UP_LIMIT(0x0f) | SET_BUFFER_POINTER(0x00);

  /**
    Clear the DAC0 data registers
  */  
  DAC0_DAT0L = 0x00;
  DAC0_DAT0H = 0x00;
  DAC0_DAT1L = 0x00;
  DAC0_DAT1H = 0x00;
  DAC0_DAT2L = 0x00;
  DAC0_DAT2H = 0x00;
  DAC0_DAT3L = 0x00;
  DAC0_DAT3H = 0x00;
  DAC0_DAT4L = 0x00;
  DAC0_DAT4H = 0x00;
  DAC0_DAT5L = 0x00;
  DAC0_DAT5H = 0x00;
  DAC0_DAT6L = 0x00;
  DAC0_DAT6H = 0x00;
  DAC0_DAT7L = 0x00;
  DAC0_DAT7H = 0x00;
  DAC0_DAT8L = 0x00;
  DAC0_DAT8H = 0x00;
  DAC0_DAT9L = 0x00;
  DAC0_DAT9H = 0x00;
  DAC0_DAT10L = 0x00;
  DAC0_DAT10H = 0x00;
  DAC0_DAT11L = 0x00;
  DAC0_DAT11H = 0x00;
  DAC0_DAT12L = 0x00;
  DAC0_DAT12H = 0x00;
  DAC0_DAT13L = 0x00;
  DAC0_DAT13H = 0x00;
  DAC0_DAT14L = 0x00;
  DAC0_DAT14H = 0x00;
  DAC0_DAT15L = 0x00;
  DAC0_DAT15H = 0x00;
  
  SIM_SCGC2 &= ~(1 << SIM_SCGC2_DAC0_SHIFT);
}

/**
  Function Name	: _DAC1_Init
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function enables and configures the DAC1
*/
void _DAC1_Init()
{
  /**
    Enable the DAC1's clock
  */
  SIM_SCGC2 |= SIM_SCGC2_DAC1_MASK;
  
  /** 
    Clear the DAC1's registers
  */
  DAC1_C0 = 0;  
  DAC1_C1 = 0;
  DAC1_C2 = 0;
  
   /**
    - Enable the DAC1 Module
    - Configure it to trigger via SW
    - Select the DACREF_2 Voltage reference
    - Configure the buffer read pointer and the buffer upper limit
  */
  DAC1_C0 |= DAC_ENABLE | SW_TRIGGER | DACREF_2;
  DAC1_C1 = DAC_BUFFER_DISABLE;
  DAC1_C2 |= SET_BUFFER_UP_LIMIT(0x0F) | SET_BUFFER_POINTER(0x00);
  
  /**
    Clear the DAC1 data registers
  */
  DAC1_DAT0L = 0x00;
  DAC1_DAT0H = 0x00;
  DAC1_DAT1L = 0x00;
  DAC1_DAT1H = 0x00;
  DAC1_DAT2L = 0x00;
  DAC1_DAT2H = 0x00;
  DAC1_DAT3L = 0x00;
  DAC1_DAT3H = 0x00;
  DAC1_DAT4L = 0x00;
  DAC1_DAT4H = 0x00;
  DAC1_DAT5L = 0x00;
  DAC1_DAT5H = 0x00;
  DAC1_DAT6L = 0x00;
  DAC1_DAT6H = 0x00;
  DAC1_DAT7L = 0x00;
  DAC1_DAT7H = 0x00;
  DAC1_DAT8L = 0x00;
  DAC1_DAT8H = 0x00;
  DAC1_DAT9L = 0x00;
  DAC1_DAT9H = 0x00;
  DAC1_DAT10L = 0x00;
  DAC1_DAT10H = 0x00;
  DAC1_DAT11L = 0x00;
  DAC1_DAT11H = 0x00;
  DAC1_DAT12L = 0x00;
  DAC1_DAT12H = 0x00;
  DAC1_DAT13L = 0x00;
  DAC1_DAT13H = 0x00;
  DAC1_DAT14L = 0x00;
  DAC1_DAT14H = 0x00;
  DAC1_DAT15L = 0x00;
  DAC1_DAT15H = 0x00;  
  
  SIM_SCGC2 &= ~(1 << SIM_SCGC2_DAC1_SHIFT);
}

/**
  Function Name	: _DAC0_Write
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U16 DAC_Value
  Returns       : Nothing
  Notes         : This function writes the given value to the lower and upper nibble of the DAC0's DAT0.
*/
void _DAC0_Write(U16 DAC_Value)
{
  /**
    Since the buffer is disabled, the first word is the value which the DAC will
    convert
  */
  DAC0_DAT0L = (U08)(DAC_Value);
  DAC0_DAT0H = (U08)((DAC_Value >> 8) & (0x0F));
}

/**
  Function Name	: _DAC1_Write
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function writes the given value to the lower and upper nibble of the DAC1's DAT0.
*/
void _DAC1_Write(U16 DAC_Value)
{
  /**
    Since the buffer is disabled, the first word is the value which the DAC will
    convert
  */
  DAC1_DAT0L = (U08)(DAC_Value);
  DAC1_DAT0H = (U08)((DAC_Value >> 8) & (0x0F));
}

/**
  Function Name	: _DAC0_Disable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function disables the DAC0
*/
void _DAC0_Disable(void)
{
  SIM_SCGC2 &= ~(1 << SIM_SCGC2_DAC0_SHIFT);
}

/**
  Function Name	: _DAC1_Disable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function disables the DAC1
*/
void _DAC1_Disable(void)
{
  SIM_SCGC2 &= ~(1 << SIM_SCGC2_DAC1_SHIFT);
}

/**
  Function Name	: _DAC0_Enable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function enables the DAC0
*/
void _DAC0_Enable(void)
{
  SIM_SCGC2 |= SIM_SCGC2_DAC0_MASK;
}

/**
  Function Name	: _DAC1_Enable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function enables the DAC1
*/
void _DAC1_Enable(void)
{
  SIM_SCGC2 |= SIM_SCGC2_DAC1_MASK;
}