#include "Driver_FlexTimer.h"

/**
  Function Name	: _FlexTimer_Init
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: U08 FlexTimer, U08 Prescaler, U08 InterruptEnable, U16 ModValue
  Returns       : Nothing
  Notes         : This function enables and configures the given FlexTimer. It receives:
                  - Prescaler value
                  - Interrupt enabling
                  - Modulus value
*/
void _FlexTimer_Init(U08 FlexTimer, U08 Prescaler, U08 InterruptEnable, U16 ModValue)
{
  switch (FlexTimer)
  {
    case FTM0:
      SIM_SCGC6 |= SIM_SCGC6_FTM0_MASK;      
      FTM0_MOD = SET_MOD_VALUE(ModValue); 
      FTM0_CONF |= FTM_CONF_BDMMODE(3);
      FTM0_CNT = 0x1;
      FTM0_SC = 0;  
      FTM0_SC |= (InterruptEnable | SET_PRESCALER(Prescaler) | SET_CLOCK_SOURCE(1));
      if (InterruptEnable == INTERRUPT_ENABLE)
      {
        NVICISER1 |= (1<<30);	   
        NVICICPR1 |= (1<<30);	
      }        
      SIM_SCGC6 &= ~(1 <<SIM_SCGC6_FTM0_SHIFT);    
      break;
    case FTM1:      
      SIM_SCGC6 |= SIM_SCGC6_FTM1_MASK;      
      FTM1_MOD = SET_MOD_VALUE(ModValue); 
      FTM1_CONF |= FTM_CONF_BDMMODE(3);
      FTM1_CNT = 0x1;
      FTM1_SC = 0;  
      FTM1_SC |= (InterruptEnable | SET_PRESCALER(Prescaler) | SET_CLOCK_SOURCE(1));
      if (InterruptEnable == INTERRUPT_ENABLE)
      {
        NVICISER1 |= (U32)(1<<31);	   
        NVICICPR1 |= (U32)(1<<31);	
      }
      SIM_SCGC6 &= ~(1 <<SIM_SCGC6_FTM1_SHIFT);    
      break;
    case FTM2:
      SIM_SCGC3 |= SIM_SCGC3_FTM2_MASK;      
      FTM2_MOD = SET_MOD_VALUE(ModValue); 
      FTM2_CONF |= FTM_CONF_BDMMODE(3);
      FTM2_CNT = 0x1;
      FTM2_SC = 0;  
      FTM2_SC |= (InterruptEnable | SET_PRESCALER(Prescaler) | SET_CLOCK_SOURCE(1));
      if (InterruptEnable == INTERRUPT_ENABLE)
      {
        NVICISER2 |= (1<<0);	   
        NVICICPR2 |= (1<<0);	
      }       
      SIM_SCGC3 &= ~(1 <<SIM_SCGC3_FTM2_SHIFT);    
      break;
    default:
      break;    
  }  
}

/**
  Function Name	: _FlexTimer_Enable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function enables the given FlexTimer
*/
void _FlexTimer_Enable(U08 Timer)
{
  switch (Timer)
  {
    case FTM0:
      SIM_SCGC6 |= SIM_SCGC6_FTM0_MASK;
      break;
    case FTM1:
      SIM_SCGC6 |= SIM_SCGC6_FTM1_MASK;
      break;
    case FTM2:
      SIM_SCGC3 |= SIM_SCGC3_FTM2_MASK;
      break;
    default:
      break;
  }
}

/**
  Function Name	: _FlexTimer_Disable
  Engineer      : Manglio Gonzlez Carrasco
  Date          : 05/01/2011
  
  Parameters	: Nothing
  Returns       : Nothing
  Notes         : This function disables the given FlexTimer
*/
void _FlexTimer_Disable(U08 Timer)
{ 
  switch (Timer)
  {
    case FTM0:
      SIM_SCGC6 &= ~SIM_SCGC6_FTM0_MASK;
      break;
    case FTM1:
      SIM_SCGC6 &= ~SIM_SCGC6_FTM1_MASK;
      break;
    case FTM2:
      SIM_SCGC3 &= ~SIM_SCGC3_FTM2_MASK;
      break;
    default:
      break;
  }
}
