#include "Driver_UART.h"

void _UART3_Init(U16 SystemClock, U16 BaudRate, U08 UARTChannel)
{
  register U16 ubd, brfa;
  UART_MemMapPtr Channel;
  U08 temp;
  switch (UARTChannel)
  {
    case UART0:
      SIM_SCGC4 |= SIM_SCGC4_UART0_MASK;
      Channel = UART_0;
      break;
    case UART1:
      SIM_SCGC4 |= SIM_SCGC4_UART1_MASK;
      Channel = UART_1;
      break;
    case UART2:
      SIM_SCGC4 |= SIM_SCGC4_UART2_MASK;      
      Channel = UART_2;
      break;
    case UART3:
      SIM_SCGC4 |= SIM_SCGC4_UART3_MASK;
      Channel = UART_3;
      break;
    case UART4:
      SIM_SCGC1 |= SIM_SCGC1_UART4_MASK;      
      Channel = UART_4;
      break;
    case UART5:
      SIM_SCGC1 |= SIM_SCGC1_UART5_MASK;      
      Channel = UART_5;
      break;
    default: 
      break;
  }  

  /* Make sure that the transmitter and receiver are disabled while we
  * change settings.
  */
  UART_C2_REG(Channel) &= ~(UART_C2_TE_MASK | UART_C2_RE_MASK );
  /* Configure the UART for 8-bit mode, no parity */
  /* We need all default settings, so entire register is cleared */
  UART_C1_REG(Channel) = 0;
  /* Calculate baud settings */
  ubd = (U16)((SystemClock*1000)/(BaudRate * 16));
  /* Save off the current value of the UARTx_BDH except for the SBR */
  temp = UART_BDH_REG(Channel) & ~(UART_BDH_SBR(0x1F));
  UART_BDH_REG(Channel) = temp | UART_BDH_SBR(((ubd & 0x1F00) >> 8));
  UART_BDL_REG(Channel) = (U08)(ubd & UART_BDL_SBR_MASK);
  /* Determine if a fractional divider is needed to get closer to the baud rate */
  brfa = (((SystemClock*32000)/(BaudRate * 16)) - (ubd * 32));
  /* Save off the current value of the UARTx_C4 register except for the BRFA */
  temp = UART_C4_REG(Channel) & ~(UART_C4_BRFA(0x1F));
  UART_C4_REG(Channel) = temp | UART_C4_BRFA(brfa);
  if (UARTChannel == UART3)
  {
    UART3_IR = UART_IR_IREN_MASK;
  }
  /* Enable receiver and transmitter */
  UART_C2_REG(Channel) |= (UART_C2_TE_MASK | UART_C2_RE_MASK );
}

void _UART_Send_Char(U08 UARTChannel, U08 Char)
{ 
  UART_MemMapPtr Channel;
  
  switch (UARTChannel)
  {
    case UART0:
      Channel = UART_0;
      break;
    case UART1:
      Channel = UART_1;
      break;
    case UART2:
      Channel = UART_2;
      break;
    case UART3:
      Channel = UART_3;
      break;
    case UART4:
      Channel = UART_4;
      break;
    case UART5:
      Channel = UART_5;
      break;
    default: 
      break;
  }  
  /* Wait until space is available in the FIFO */
  while(!(UART_S1_REG(Channel) & UART_S1_TDRE_MASK)){}
  /* Send the character */
  UART_D_REG(Channel) = (U08)Char;
}