/***********************************************************************************************************************
*
* Freescale Semiconductor Inc.
* (c) Copyright 2006-2009 Freescale Semiconductor, Inc.
* ALL RIGHTS RESERVED.
*
*********************************************************************************************************************//*!
*
* @file   TSS_SensorTIC.h
*
* @brief  Functions Prototypes, constants, variables and macros for the sensing of electrodes
*
* @version 1.0.12.0
* 
* @date Apr-4-2011
* 
*
***********************************************************************************************************************/

#ifndef __TSS_SENSORTIC_H__
  #define __TSS_SENSORTIC_H__

  #include "TSS_Sensor.h"

  /***************************** Types ***************************/

  #if TSS_HCS08_MCU || TSS_CFV1_MCU

    /* Electrode Data */
    typedef struct {
      #if TSS_USE_NOISE_AMPLITUDE_FILTER
        const INT8 tic_ci8AmplitudeFilterDeltaLimit;
      #else
        const UINT8 u8Dummy;
      #endif  
    } TSS_TIC_ELECTRODE_ROMDATA;    
    
    typedef struct {
      #if TSS_USE_NOISE_AMPLITUDE_FILTER
        UINT16 tic_u16AmplitudeFilterBase;
      #else
        UINT8 u8Dummy;
      #endif  
    } TSS_TIC_ELECTRODE_RAMDATA;
    
  #elif TSS_KINETIS_MCU
    
    /* Method Data */
    typedef struct {
      const TSS_METHOD_CONTROL tic_fMethodControl;
      const UINT32 * const tic_cpsu32Timer;
      const UINT32 * const tic_cpsu32Port;
      const UINT32 * const tic_cpsu32RGPIO;
      const UINT8 tic_u8TimerIRQNum;    
      const UINT8 tic_u8PortIRQNum;        
    } TSS_TIC_METHOD_ROMDATA;

    /* Electrode Data */
    typedef struct {
      const TSS_TIC_METHOD_ROMDATA * const tic_cpsu32MethodROMData; 
      const UINT32 tic_cu32PortBit;
      const UINT32 tic_cu32TimerChannel;
      const UINT8 tic_cu8TimerChannelMUX;
      #if TSS_USE_NOISE_AMPLITUDE_FILTER
        const INT8 tic_ci8AmplitudeFilterDeltaLimit;
      #endif  
    } TSS_TIC_ELECTRODE_ROMDATA;    

    typedef struct {
      #if TSS_USE_NOISE_AMPLITUDE_FILTER
        UINT16 tic_u16AmplitudeFilterBase;
      #else
        UINT8 u8Dummy;
      #endif  
    } TSS_TIC_ELECTRODE_RAMDATA;
    
  #else /* End of TSS_KINETIS_MCU */
    #error "TSS - Not supported MCU used"
  #endif

  /******************** Functions prototypes **********************/

  extern UINT8 TIC_SensorInit(void);
  /*
  function:   TIC_SensorInit
  brief:      Initializes modules for the sensing of the electrodes.
  param:      Void                           
  return:     Status code                              
  */
  
  extern UINT8 TIC_SampleElectrode(UINT8 u8ElecNum, UINT8 u8Command);
  /*
  function:   TIC_SampleElectrode
  brief:      Performs a valid reading of one electrode, stores the timer values and returns a status code
  param:      u8ElecNum - Number of electrode to be scanned
              u8Command - Measurement command
  return:     Status code                              
  */

  /*********************************************************************************
   *    Determination what TIC module is used for later conditional TIC module 
   *    initialization
   *********************************************************************************/

  #define TSS_TPMTIC_USED        (TSS_DETECT_EL_MODULE(0,TPMTIC) || TSS_DETECT_EL_MODULE(1,TPMTIC) || TSS_DETECT_EL_MODULE(2,TPMTIC) || TSS_DETECT_EL_MODULE(3,TPMTIC) || TSS_DETECT_EL_MODULE(4,TPMTIC) || TSS_DETECT_EL_MODULE(5,TPMTIC) || TSS_DETECT_EL_MODULE(6,TPMTIC) || TSS_DETECT_EL_MODULE(7,TPMTIC) || TSS_DETECT_EL_MODULE(8,TPMTIC) || TSS_DETECT_EL_MODULE(9,TPMTIC) || TSS_DETECT_EL_MODULE(10,TPMTIC) || TSS_DETECT_EL_MODULE(11,TPMTIC) || TSS_DETECT_EL_MODULE(12,TPMTIC) || TSS_DETECT_EL_MODULE(13,TPMTIC) || TSS_DETECT_EL_MODULE(14,TPMTIC) || TSS_DETECT_EL_MODULE(15,TPMTIC) || TSS_DETECT_EL_MODULE(16,TPMTIC) || TSS_DETECT_EL_MODULE(17,TPMTIC) || TSS_DETECT_EL_MODULE(18,TPMTIC) || TSS_DETECT_EL_MODULE(19,TPMTIC) || TSS_DETECT_EL_MODULE(20,TPMTIC) || TSS_DETECT_EL_MODULE(21,TPMTIC) || TSS_DETECT_EL_MODULE(22,TPMTIC) || TSS_DETECT_EL_MODULE(23,TPMTIC) || TSS_DETECT_EL_MODULE(24,TPMTIC) || TSS_DETECT_EL_MODULE(25,TPMTIC) || TSS_DETECT_EL_MODULE(26,TPMTIC) || TSS_DETECT_EL_MODULE(27,TPMTIC) || TSS_DETECT_EL_MODULE(28,TPMTIC) || TSS_DETECT_EL_MODULE(29,TPMTIC) || TSS_DETECT_EL_MODULE(30,TPMTIC) || TSS_DETECT_EL_MODULE(31,TPMTIC) || TSS_DETECT_EL_MODULE(32,TPMTIC) || TSS_DETECT_EL_MODULE(33,TPMTIC) || TSS_DETECT_EL_MODULE(34,TPMTIC) || TSS_DETECT_EL_MODULE(35,TPMTIC) || TSS_DETECT_EL_MODULE(36,TPMTIC) || TSS_DETECT_EL_MODULE(37,TPMTIC) || TSS_DETECT_EL_MODULE(38,TPMTIC) || TSS_DETECT_EL_MODULE(39,TPMTIC) || TSS_DETECT_EL_MODULE(40,TPMTIC) || TSS_DETECT_EL_MODULE(41,TPMTIC) || TSS_DETECT_EL_MODULE(42,TPMTIC) || TSS_DETECT_EL_MODULE(43,TPMTIC) || TSS_DETECT_EL_MODULE(44,TPMTIC) || TSS_DETECT_EL_MODULE(45,TPMTIC) || TSS_DETECT_EL_MODULE(46,TPMTIC) || TSS_DETECT_EL_MODULE(47,TPMTIC) || TSS_DETECT_EL_MODULE(48,TPMTIC) || TSS_DETECT_EL_MODULE(49,TPMTIC) || TSS_DETECT_EL_MODULE(50,TPMTIC) || TSS_DETECT_EL_MODULE(51,TPMTIC) || TSS_DETECT_EL_MODULE(52,TPMTIC) || TSS_DETECT_EL_MODULE(53,TPMTIC) || TSS_DETECT_EL_MODULE(54,TPMTIC) || TSS_DETECT_EL_MODULE(55,TPMTIC) || TSS_DETECT_EL_MODULE(56,TPMTIC) || TSS_DETECT_EL_MODULE(57,TPMTIC) || TSS_DETECT_EL_MODULE(58,TPMTIC) || TSS_DETECT_EL_MODULE(59,TPMTIC) || TSS_DETECT_EL_MODULE(60,TPMTIC) || TSS_DETECT_EL_MODULE(61,TPMTIC) || TSS_DETECT_EL_MODULE(62,TPMTIC) || TSS_DETECT_EL_MODULE(63,TPMTIC))
  #define TSS_TPM0TIC_USED       (TSS_DETECT_EL_MODULE(0,TPM0TIC) || TSS_DETECT_EL_MODULE(1,TPM0TIC) || TSS_DETECT_EL_MODULE(2,TPM0TIC) || TSS_DETECT_EL_MODULE(3,TPM0TIC) || TSS_DETECT_EL_MODULE(4,TPM0TIC) || TSS_DETECT_EL_MODULE(5,TPM0TIC) || TSS_DETECT_EL_MODULE(6,TPM0TIC) || TSS_DETECT_EL_MODULE(7,TPM0TIC) || TSS_DETECT_EL_MODULE(8,TPM0TIC) || TSS_DETECT_EL_MODULE(9,TPM0TIC) || TSS_DETECT_EL_MODULE(10,TPM0TIC) || TSS_DETECT_EL_MODULE(11,TPM0TIC) || TSS_DETECT_EL_MODULE(12,TPM0TIC) || TSS_DETECT_EL_MODULE(13,TPM0TIC) || TSS_DETECT_EL_MODULE(14,TPM0TIC) || TSS_DETECT_EL_MODULE(15,TPM0TIC) || TSS_DETECT_EL_MODULE(16,TPM0TIC) || TSS_DETECT_EL_MODULE(17,TPM0TIC) || TSS_DETECT_EL_MODULE(18,TPM0TIC) || TSS_DETECT_EL_MODULE(19,TPM0TIC) || TSS_DETECT_EL_MODULE(20,TPM0TIC) || TSS_DETECT_EL_MODULE(21,TPM0TIC) || TSS_DETECT_EL_MODULE(22,TPM0TIC) || TSS_DETECT_EL_MODULE(23,TPM0TIC) || TSS_DETECT_EL_MODULE(24,TPM0TIC) || TSS_DETECT_EL_MODULE(25,TPM0TIC) || TSS_DETECT_EL_MODULE(26,TPM0TIC) || TSS_DETECT_EL_MODULE(27,TPM0TIC) || TSS_DETECT_EL_MODULE(28,TPM0TIC) || TSS_DETECT_EL_MODULE(29,TPM0TIC) || TSS_DETECT_EL_MODULE(30,TPM0TIC) || TSS_DETECT_EL_MODULE(31,TPM0TIC) || TSS_DETECT_EL_MODULE(32,TPM0TIC) || TSS_DETECT_EL_MODULE(33,TPM0TIC) || TSS_DETECT_EL_MODULE(34,TPM0TIC) || TSS_DETECT_EL_MODULE(35,TPM0TIC) || TSS_DETECT_EL_MODULE(36,TPM0TIC) || TSS_DETECT_EL_MODULE(37,TPM0TIC) || TSS_DETECT_EL_MODULE(38,TPM0TIC) || TSS_DETECT_EL_MODULE(39,TPM0TIC) || TSS_DETECT_EL_MODULE(40,TPM0TIC) || TSS_DETECT_EL_MODULE(41,TPM0TIC) || TSS_DETECT_EL_MODULE(42,TPM0TIC) || TSS_DETECT_EL_MODULE(43,TPM0TIC) || TSS_DETECT_EL_MODULE(44,TPM0TIC) || TSS_DETECT_EL_MODULE(45,TPM0TIC) || TSS_DETECT_EL_MODULE(46,TPM0TIC) || TSS_DETECT_EL_MODULE(47,TPM0TIC) || TSS_DETECT_EL_MODULE(48,TPM0TIC) || TSS_DETECT_EL_MODULE(49,TPM0TIC) || TSS_DETECT_EL_MODULE(50,TPM0TIC) || TSS_DETECT_EL_MODULE(51,TPM0TIC) || TSS_DETECT_EL_MODULE(52,TPM0TIC) || TSS_DETECT_EL_MODULE(53,TPM0TIC) || TSS_DETECT_EL_MODULE(54,TPM0TIC) || TSS_DETECT_EL_MODULE(55,TPM0TIC) || TSS_DETECT_EL_MODULE(56,TPM0TIC) || TSS_DETECT_EL_MODULE(57,TPM0TIC) || TSS_DETECT_EL_MODULE(58,TPM0TIC) || TSS_DETECT_EL_MODULE(59,TPM0TIC) || TSS_DETECT_EL_MODULE(60,TPM0TIC) || TSS_DETECT_EL_MODULE(61,TPM0TIC) || TSS_DETECT_EL_MODULE(62,TPM0TIC) || TSS_DETECT_EL_MODULE(63,TPM0TIC))
  #define TSS_TPM1TIC_USED       (TSS_DETECT_EL_MODULE(0,TPM1TIC) || TSS_DETECT_EL_MODULE(1,TPM1TIC) || TSS_DETECT_EL_MODULE(2,TPM1TIC) || TSS_DETECT_EL_MODULE(3,TPM1TIC) || TSS_DETECT_EL_MODULE(4,TPM1TIC) || TSS_DETECT_EL_MODULE(5,TPM1TIC) || TSS_DETECT_EL_MODULE(6,TPM1TIC) || TSS_DETECT_EL_MODULE(7,TPM1TIC) || TSS_DETECT_EL_MODULE(8,TPM1TIC) || TSS_DETECT_EL_MODULE(9,TPM1TIC) || TSS_DETECT_EL_MODULE(10,TPM1TIC) || TSS_DETECT_EL_MODULE(11,TPM1TIC) || TSS_DETECT_EL_MODULE(12,TPM1TIC) || TSS_DETECT_EL_MODULE(13,TPM1TIC) || TSS_DETECT_EL_MODULE(14,TPM1TIC) || TSS_DETECT_EL_MODULE(15,TPM1TIC) || TSS_DETECT_EL_MODULE(16,TPM1TIC) || TSS_DETECT_EL_MODULE(17,TPM1TIC) || TSS_DETECT_EL_MODULE(18,TPM1TIC) || TSS_DETECT_EL_MODULE(19,TPM1TIC) || TSS_DETECT_EL_MODULE(20,TPM1TIC) || TSS_DETECT_EL_MODULE(21,TPM1TIC) || TSS_DETECT_EL_MODULE(22,TPM1TIC) || TSS_DETECT_EL_MODULE(23,TPM1TIC) || TSS_DETECT_EL_MODULE(24,TPM1TIC) || TSS_DETECT_EL_MODULE(25,TPM1TIC) || TSS_DETECT_EL_MODULE(26,TPM1TIC) || TSS_DETECT_EL_MODULE(27,TPM1TIC) || TSS_DETECT_EL_MODULE(28,TPM1TIC) || TSS_DETECT_EL_MODULE(29,TPM1TIC) || TSS_DETECT_EL_MODULE(30,TPM1TIC) || TSS_DETECT_EL_MODULE(31,TPM1TIC) || TSS_DETECT_EL_MODULE(32,TPM1TIC) || TSS_DETECT_EL_MODULE(33,TPM1TIC) || TSS_DETECT_EL_MODULE(34,TPM1TIC) || TSS_DETECT_EL_MODULE(35,TPM1TIC) || TSS_DETECT_EL_MODULE(36,TPM1TIC) || TSS_DETECT_EL_MODULE(37,TPM1TIC) || TSS_DETECT_EL_MODULE(38,TPM1TIC) || TSS_DETECT_EL_MODULE(39,TPM1TIC) || TSS_DETECT_EL_MODULE(40,TPM1TIC) || TSS_DETECT_EL_MODULE(41,TPM1TIC) || TSS_DETECT_EL_MODULE(42,TPM1TIC) || TSS_DETECT_EL_MODULE(43,TPM1TIC) || TSS_DETECT_EL_MODULE(44,TPM1TIC) || TSS_DETECT_EL_MODULE(45,TPM1TIC) || TSS_DETECT_EL_MODULE(46,TPM1TIC) || TSS_DETECT_EL_MODULE(47,TPM1TIC) || TSS_DETECT_EL_MODULE(48,TPM1TIC) || TSS_DETECT_EL_MODULE(49,TPM1TIC) || TSS_DETECT_EL_MODULE(50,TPM1TIC) || TSS_DETECT_EL_MODULE(51,TPM1TIC) || TSS_DETECT_EL_MODULE(52,TPM1TIC) || TSS_DETECT_EL_MODULE(53,TPM1TIC) || TSS_DETECT_EL_MODULE(54,TPM1TIC) || TSS_DETECT_EL_MODULE(55,TPM1TIC) || TSS_DETECT_EL_MODULE(56,TPM1TIC) || TSS_DETECT_EL_MODULE(57,TPM1TIC) || TSS_DETECT_EL_MODULE(58,TPM1TIC) || TSS_DETECT_EL_MODULE(59,TPM1TIC) || TSS_DETECT_EL_MODULE(60,TPM1TIC) || TSS_DETECT_EL_MODULE(61,TPM1TIC) || TSS_DETECT_EL_MODULE(62,TPM1TIC) || TSS_DETECT_EL_MODULE(63,TPM1TIC))
  #define TSS_TPM2TIC_USED       (TSS_DETECT_EL_MODULE(0,TPM2TIC) || TSS_DETECT_EL_MODULE(1,TPM2TIC) || TSS_DETECT_EL_MODULE(2,TPM2TIC) || TSS_DETECT_EL_MODULE(3,TPM2TIC) || TSS_DETECT_EL_MODULE(4,TPM2TIC) || TSS_DETECT_EL_MODULE(5,TPM2TIC) || TSS_DETECT_EL_MODULE(6,TPM2TIC) || TSS_DETECT_EL_MODULE(7,TPM2TIC) || TSS_DETECT_EL_MODULE(8,TPM2TIC) || TSS_DETECT_EL_MODULE(9,TPM2TIC) || TSS_DETECT_EL_MODULE(10,TPM2TIC) || TSS_DETECT_EL_MODULE(11,TPM2TIC) || TSS_DETECT_EL_MODULE(12,TPM2TIC) || TSS_DETECT_EL_MODULE(13,TPM2TIC) || TSS_DETECT_EL_MODULE(14,TPM2TIC) || TSS_DETECT_EL_MODULE(15,TPM2TIC) || TSS_DETECT_EL_MODULE(16,TPM2TIC) || TSS_DETECT_EL_MODULE(17,TPM2TIC) || TSS_DETECT_EL_MODULE(18,TPM2TIC) || TSS_DETECT_EL_MODULE(19,TPM2TIC) || TSS_DETECT_EL_MODULE(20,TPM2TIC) || TSS_DETECT_EL_MODULE(21,TPM2TIC) || TSS_DETECT_EL_MODULE(22,TPM2TIC) || TSS_DETECT_EL_MODULE(23,TPM2TIC) || TSS_DETECT_EL_MODULE(24,TPM2TIC) || TSS_DETECT_EL_MODULE(25,TPM2TIC) || TSS_DETECT_EL_MODULE(26,TPM2TIC) || TSS_DETECT_EL_MODULE(27,TPM2TIC) || TSS_DETECT_EL_MODULE(28,TPM2TIC) || TSS_DETECT_EL_MODULE(29,TPM2TIC) || TSS_DETECT_EL_MODULE(30,TPM2TIC) || TSS_DETECT_EL_MODULE(31,TPM2TIC) || TSS_DETECT_EL_MODULE(32,TPM2TIC) || TSS_DETECT_EL_MODULE(33,TPM2TIC) || TSS_DETECT_EL_MODULE(34,TPM2TIC) || TSS_DETECT_EL_MODULE(35,TPM2TIC) || TSS_DETECT_EL_MODULE(36,TPM2TIC) || TSS_DETECT_EL_MODULE(37,TPM2TIC) || TSS_DETECT_EL_MODULE(38,TPM2TIC) || TSS_DETECT_EL_MODULE(39,TPM2TIC) || TSS_DETECT_EL_MODULE(40,TPM2TIC) || TSS_DETECT_EL_MODULE(41,TPM2TIC) || TSS_DETECT_EL_MODULE(42,TPM2TIC) || TSS_DETECT_EL_MODULE(43,TPM2TIC) || TSS_DETECT_EL_MODULE(44,TPM2TIC) || TSS_DETECT_EL_MODULE(45,TPM2TIC) || TSS_DETECT_EL_MODULE(46,TPM2TIC) || TSS_DETECT_EL_MODULE(47,TPM2TIC) || TSS_DETECT_EL_MODULE(48,TPM2TIC) || TSS_DETECT_EL_MODULE(49,TPM2TIC) || TSS_DETECT_EL_MODULE(50,TPM2TIC) || TSS_DETECT_EL_MODULE(51,TPM2TIC) || TSS_DETECT_EL_MODULE(52,TPM2TIC) || TSS_DETECT_EL_MODULE(53,TPM2TIC) || TSS_DETECT_EL_MODULE(54,TPM2TIC) || TSS_DETECT_EL_MODULE(55,TPM2TIC) || TSS_DETECT_EL_MODULE(56,TPM2TIC) || TSS_DETECT_EL_MODULE(57,TPM2TIC) || TSS_DETECT_EL_MODULE(58,TPM2TIC) || TSS_DETECT_EL_MODULE(59,TPM2TIC) || TSS_DETECT_EL_MODULE(60,TPM2TIC) || TSS_DETECT_EL_MODULE(61,TPM2TIC) || TSS_DETECT_EL_MODULE(62,TPM2TIC) || TSS_DETECT_EL_MODULE(63,TPM2TIC))
  #define TSS_TPM3TIC_USED       (TSS_DETECT_EL_MODULE(0,TPM3TIC) || TSS_DETECT_EL_MODULE(1,TPM3TIC) || TSS_DETECT_EL_MODULE(2,TPM3TIC) || TSS_DETECT_EL_MODULE(3,TPM3TIC) || TSS_DETECT_EL_MODULE(4,TPM3TIC) || TSS_DETECT_EL_MODULE(5,TPM3TIC) || TSS_DETECT_EL_MODULE(6,TPM3TIC) || TSS_DETECT_EL_MODULE(7,TPM3TIC) || TSS_DETECT_EL_MODULE(8,TPM3TIC) || TSS_DETECT_EL_MODULE(9,TPM3TIC) || TSS_DETECT_EL_MODULE(10,TPM3TIC) || TSS_DETECT_EL_MODULE(11,TPM3TIC) || TSS_DETECT_EL_MODULE(12,TPM3TIC) || TSS_DETECT_EL_MODULE(13,TPM3TIC) || TSS_DETECT_EL_MODULE(14,TPM3TIC) || TSS_DETECT_EL_MODULE(15,TPM3TIC) || TSS_DETECT_EL_MODULE(16,TPM3TIC) || TSS_DETECT_EL_MODULE(17,TPM3TIC) || TSS_DETECT_EL_MODULE(18,TPM3TIC) || TSS_DETECT_EL_MODULE(19,TPM3TIC) || TSS_DETECT_EL_MODULE(20,TPM3TIC) || TSS_DETECT_EL_MODULE(21,TPM3TIC) || TSS_DETECT_EL_MODULE(22,TPM3TIC) || TSS_DETECT_EL_MODULE(23,TPM3TIC) || TSS_DETECT_EL_MODULE(24,TPM3TIC) || TSS_DETECT_EL_MODULE(25,TPM3TIC) || TSS_DETECT_EL_MODULE(26,TPM3TIC) || TSS_DETECT_EL_MODULE(27,TPM3TIC) || TSS_DETECT_EL_MODULE(28,TPM3TIC) || TSS_DETECT_EL_MODULE(29,TPM3TIC) || TSS_DETECT_EL_MODULE(30,TPM3TIC) || TSS_DETECT_EL_MODULE(31,TPM3TIC) || TSS_DETECT_EL_MODULE(32,TPM3TIC) || TSS_DETECT_EL_MODULE(33,TPM3TIC) || TSS_DETECT_EL_MODULE(34,TPM3TIC) || TSS_DETECT_EL_MODULE(35,TPM3TIC) || TSS_DETECT_EL_MODULE(36,TPM3TIC) || TSS_DETECT_EL_MODULE(37,TPM3TIC) || TSS_DETECT_EL_MODULE(38,TPM3TIC) || TSS_DETECT_EL_MODULE(39,TPM3TIC) || TSS_DETECT_EL_MODULE(40,TPM3TIC) || TSS_DETECT_EL_MODULE(41,TPM3TIC) || TSS_DETECT_EL_MODULE(42,TPM3TIC) || TSS_DETECT_EL_MODULE(43,TPM3TIC) || TSS_DETECT_EL_MODULE(44,TPM3TIC) || TSS_DETECT_EL_MODULE(45,TPM3TIC) || TSS_DETECT_EL_MODULE(46,TPM3TIC) || TSS_DETECT_EL_MODULE(47,TPM3TIC) || TSS_DETECT_EL_MODULE(48,TPM3TIC) || TSS_DETECT_EL_MODULE(49,TPM3TIC) || TSS_DETECT_EL_MODULE(50,TPM3TIC) || TSS_DETECT_EL_MODULE(51,TPM3TIC) || TSS_DETECT_EL_MODULE(52,TPM3TIC) || TSS_DETECT_EL_MODULE(53,TPM3TIC) || TSS_DETECT_EL_MODULE(54,TPM3TIC) || TSS_DETECT_EL_MODULE(55,TPM3TIC) || TSS_DETECT_EL_MODULE(56,TPM3TIC) || TSS_DETECT_EL_MODULE(57,TPM3TIC) || TSS_DETECT_EL_MODULE(58,TPM3TIC) || TSS_DETECT_EL_MODULE(59,TPM3TIC) || TSS_DETECT_EL_MODULE(60,TPM3TIC) || TSS_DETECT_EL_MODULE(61,TPM3TIC) || TSS_DETECT_EL_MODULE(62,TPM3TIC) || TSS_DETECT_EL_MODULE(63,TPM3TIC))
  #define TSS_TPM4TIC_USED       (TSS_DETECT_EL_MODULE(0,TPM4TIC) || TSS_DETECT_EL_MODULE(1,TPM4TIC) || TSS_DETECT_EL_MODULE(2,TPM4TIC) || TSS_DETECT_EL_MODULE(3,TPM4TIC) || TSS_DETECT_EL_MODULE(4,TPM4TIC) || TSS_DETECT_EL_MODULE(5,TPM4TIC) || TSS_DETECT_EL_MODULE(6,TPM4TIC) || TSS_DETECT_EL_MODULE(7,TPM4TIC) || TSS_DETECT_EL_MODULE(8,TPM4TIC) || TSS_DETECT_EL_MODULE(9,TPM4TIC) || TSS_DETECT_EL_MODULE(10,TPM4TIC) || TSS_DETECT_EL_MODULE(11,TPM4TIC) || TSS_DETECT_EL_MODULE(12,TPM4TIC) || TSS_DETECT_EL_MODULE(13,TPM4TIC) || TSS_DETECT_EL_MODULE(14,TPM4TIC) || TSS_DETECT_EL_MODULE(15,TPM4TIC) || TSS_DETECT_EL_MODULE(16,TPM4TIC) || TSS_DETECT_EL_MODULE(17,TPM4TIC) || TSS_DETECT_EL_MODULE(18,TPM4TIC) || TSS_DETECT_EL_MODULE(19,TPM4TIC) || TSS_DETECT_EL_MODULE(20,TPM4TIC) || TSS_DETECT_EL_MODULE(21,TPM4TIC) || TSS_DETECT_EL_MODULE(22,TPM4TIC) || TSS_DETECT_EL_MODULE(23,TPM4TIC) || TSS_DETECT_EL_MODULE(24,TPM4TIC) || TSS_DETECT_EL_MODULE(25,TPM4TIC) || TSS_DETECT_EL_MODULE(26,TPM4TIC) || TSS_DETECT_EL_MODULE(27,TPM4TIC) || TSS_DETECT_EL_MODULE(28,TPM4TIC) || TSS_DETECT_EL_MODULE(29,TPM4TIC) || TSS_DETECT_EL_MODULE(30,TPM4TIC) || TSS_DETECT_EL_MODULE(31,TPM4TIC) || TSS_DETECT_EL_MODULE(32,TPM4TIC) || TSS_DETECT_EL_MODULE(33,TPM4TIC) || TSS_DETECT_EL_MODULE(34,TPM4TIC) || TSS_DETECT_EL_MODULE(35,TPM4TIC) || TSS_DETECT_EL_MODULE(36,TPM4TIC) || TSS_DETECT_EL_MODULE(37,TPM4TIC) || TSS_DETECT_EL_MODULE(38,TPM4TIC) || TSS_DETECT_EL_MODULE(39,TPM4TIC) || TSS_DETECT_EL_MODULE(40,TPM4TIC) || TSS_DETECT_EL_MODULE(41,TPM4TIC) || TSS_DETECT_EL_MODULE(42,TPM4TIC) || TSS_DETECT_EL_MODULE(43,TPM4TIC) || TSS_DETECT_EL_MODULE(44,TPM4TIC) || TSS_DETECT_EL_MODULE(45,TPM4TIC) || TSS_DETECT_EL_MODULE(46,TPM4TIC) || TSS_DETECT_EL_MODULE(47,TPM4TIC) || TSS_DETECT_EL_MODULE(48,TPM4TIC) || TSS_DETECT_EL_MODULE(49,TPM4TIC) || TSS_DETECT_EL_MODULE(50,TPM4TIC) || TSS_DETECT_EL_MODULE(51,TPM4TIC) || TSS_DETECT_EL_MODULE(52,TPM4TIC) || TSS_DETECT_EL_MODULE(53,TPM4TIC) || TSS_DETECT_EL_MODULE(54,TPM4TIC) || TSS_DETECT_EL_MODULE(55,TPM4TIC) || TSS_DETECT_EL_MODULE(56,TPM4TIC) || TSS_DETECT_EL_MODULE(57,TPM4TIC) || TSS_DETECT_EL_MODULE(58,TPM4TIC) || TSS_DETECT_EL_MODULE(59,TPM4TIC) || TSS_DETECT_EL_MODULE(60,TPM4TIC) || TSS_DETECT_EL_MODULE(61,TPM4TIC) || TSS_DETECT_EL_MODULE(62,TPM4TIC) || TSS_DETECT_EL_MODULE(63,TPM4TIC))
  #define TSS_FTMTIC_USED        (TSS_DETECT_EL_MODULE(0,FTMTIC) || TSS_DETECT_EL_MODULE(1,FTMTIC) || TSS_DETECT_EL_MODULE(2,FTMTIC) || TSS_DETECT_EL_MODULE(3,FTMTIC) || TSS_DETECT_EL_MODULE(4,FTMTIC) || TSS_DETECT_EL_MODULE(5,FTMTIC) || TSS_DETECT_EL_MODULE(6,FTMTIC) || TSS_DETECT_EL_MODULE(7,FTMTIC) || TSS_DETECT_EL_MODULE(8,FTMTIC) || TSS_DETECT_EL_MODULE(9,FTMTIC) || TSS_DETECT_EL_MODULE(10,FTMTIC) || TSS_DETECT_EL_MODULE(11,FTMTIC) || TSS_DETECT_EL_MODULE(12,FTMTIC) || TSS_DETECT_EL_MODULE(13,FTMTIC) || TSS_DETECT_EL_MODULE(14,FTMTIC) || TSS_DETECT_EL_MODULE(15,FTMTIC) || TSS_DETECT_EL_MODULE(16,FTMTIC) || TSS_DETECT_EL_MODULE(17,FTMTIC) || TSS_DETECT_EL_MODULE(18,FTMTIC) || TSS_DETECT_EL_MODULE(19,FTMTIC) || TSS_DETECT_EL_MODULE(20,FTMTIC) || TSS_DETECT_EL_MODULE(21,FTMTIC) || TSS_DETECT_EL_MODULE(22,FTMTIC) || TSS_DETECT_EL_MODULE(23,FTMTIC) || TSS_DETECT_EL_MODULE(24,FTMTIC) || TSS_DETECT_EL_MODULE(25,FTMTIC) || TSS_DETECT_EL_MODULE(26,FTMTIC) || TSS_DETECT_EL_MODULE(27,FTMTIC) || TSS_DETECT_EL_MODULE(28,FTMTIC) || TSS_DETECT_EL_MODULE(29,FTMTIC) || TSS_DETECT_EL_MODULE(30,FTMTIC) || TSS_DETECT_EL_MODULE(31,FTMTIC) || TSS_DETECT_EL_MODULE(32,FTMTIC) || TSS_DETECT_EL_MODULE(33,FTMTIC) || TSS_DETECT_EL_MODULE(34,FTMTIC) || TSS_DETECT_EL_MODULE(35,FTMTIC) || TSS_DETECT_EL_MODULE(36,FTMTIC) || TSS_DETECT_EL_MODULE(37,FTMTIC) || TSS_DETECT_EL_MODULE(38,FTMTIC) || TSS_DETECT_EL_MODULE(39,FTMTIC) || TSS_DETECT_EL_MODULE(40,FTMTIC) || TSS_DETECT_EL_MODULE(41,FTMTIC) || TSS_DETECT_EL_MODULE(42,FTMTIC) || TSS_DETECT_EL_MODULE(43,FTMTIC) || TSS_DETECT_EL_MODULE(44,FTMTIC) || TSS_DETECT_EL_MODULE(45,FTMTIC) || TSS_DETECT_EL_MODULE(46,FTMTIC) || TSS_DETECT_EL_MODULE(47,FTMTIC) || TSS_DETECT_EL_MODULE(48,FTMTIC) || TSS_DETECT_EL_MODULE(49,FTMTIC) || TSS_DETECT_EL_MODULE(50,FTMTIC) || TSS_DETECT_EL_MODULE(51,FTMTIC) || TSS_DETECT_EL_MODULE(52,FTMTIC) || TSS_DETECT_EL_MODULE(53,FTMTIC) || TSS_DETECT_EL_MODULE(54,FTMTIC) || TSS_DETECT_EL_MODULE(55,FTMTIC) || TSS_DETECT_EL_MODULE(56,FTMTIC) || TSS_DETECT_EL_MODULE(57,FTMTIC) || TSS_DETECT_EL_MODULE(58,FTMTIC) || TSS_DETECT_EL_MODULE(59,FTMTIC) || TSS_DETECT_EL_MODULE(60,FTMTIC) || TSS_DETECT_EL_MODULE(61,FTMTIC) || TSS_DETECT_EL_MODULE(62,FTMTIC) || TSS_DETECT_EL_MODULE(63,FTMTIC))
  #define TSS_FTM0TIC_USED       (TSS_DETECT_EL_MODULE(0,FTM0TIC) || TSS_DETECT_EL_MODULE(1,FTM0TIC) || TSS_DETECT_EL_MODULE(2,FTM0TIC) || TSS_DETECT_EL_MODULE(3,FTM0TIC) || TSS_DETECT_EL_MODULE(4,FTM0TIC) || TSS_DETECT_EL_MODULE(5,FTM0TIC) || TSS_DETECT_EL_MODULE(6,FTM0TIC) || TSS_DETECT_EL_MODULE(7,FTM0TIC) || TSS_DETECT_EL_MODULE(8,FTM0TIC) || TSS_DETECT_EL_MODULE(9,FTM0TIC) || TSS_DETECT_EL_MODULE(10,FTM0TIC) || TSS_DETECT_EL_MODULE(11,FTM0TIC) || TSS_DETECT_EL_MODULE(12,FTM0TIC) || TSS_DETECT_EL_MODULE(13,FTM0TIC) || TSS_DETECT_EL_MODULE(14,FTM0TIC) || TSS_DETECT_EL_MODULE(15,FTM0TIC) || TSS_DETECT_EL_MODULE(16,FTM0TIC) || TSS_DETECT_EL_MODULE(17,FTM0TIC) || TSS_DETECT_EL_MODULE(18,FTM0TIC) || TSS_DETECT_EL_MODULE(19,FTM0TIC) || TSS_DETECT_EL_MODULE(20,FTM0TIC) || TSS_DETECT_EL_MODULE(21,FTM0TIC) || TSS_DETECT_EL_MODULE(22,FTM0TIC) || TSS_DETECT_EL_MODULE(23,FTM0TIC) || TSS_DETECT_EL_MODULE(24,FTM0TIC) || TSS_DETECT_EL_MODULE(25,FTM0TIC) || TSS_DETECT_EL_MODULE(26,FTM0TIC) || TSS_DETECT_EL_MODULE(27,FTM0TIC) || TSS_DETECT_EL_MODULE(28,FTM0TIC) || TSS_DETECT_EL_MODULE(29,FTM0TIC) || TSS_DETECT_EL_MODULE(30,FTM0TIC) || TSS_DETECT_EL_MODULE(31,FTM0TIC) || TSS_DETECT_EL_MODULE(32,FTM0TIC) || TSS_DETECT_EL_MODULE(33,FTM0TIC) || TSS_DETECT_EL_MODULE(34,FTM0TIC) || TSS_DETECT_EL_MODULE(35,FTM0TIC) || TSS_DETECT_EL_MODULE(36,FTM0TIC) || TSS_DETECT_EL_MODULE(37,FTM0TIC) || TSS_DETECT_EL_MODULE(38,FTM0TIC) || TSS_DETECT_EL_MODULE(39,FTM0TIC) || TSS_DETECT_EL_MODULE(40,FTM0TIC) || TSS_DETECT_EL_MODULE(41,FTM0TIC) || TSS_DETECT_EL_MODULE(42,FTM0TIC) || TSS_DETECT_EL_MODULE(43,FTM0TIC) || TSS_DETECT_EL_MODULE(44,FTM0TIC) || TSS_DETECT_EL_MODULE(45,FTM0TIC) || TSS_DETECT_EL_MODULE(46,FTM0TIC) || TSS_DETECT_EL_MODULE(47,FTM0TIC) || TSS_DETECT_EL_MODULE(48,FTM0TIC) || TSS_DETECT_EL_MODULE(49,FTM0TIC) || TSS_DETECT_EL_MODULE(50,FTM0TIC) || TSS_DETECT_EL_MODULE(51,FTM0TIC) || TSS_DETECT_EL_MODULE(52,FTM0TIC) || TSS_DETECT_EL_MODULE(53,FTM0TIC) || TSS_DETECT_EL_MODULE(54,FTM0TIC) || TSS_DETECT_EL_MODULE(55,FTM0TIC) || TSS_DETECT_EL_MODULE(56,FTM0TIC) || TSS_DETECT_EL_MODULE(57,FTM0TIC) || TSS_DETECT_EL_MODULE(58,FTM0TIC) || TSS_DETECT_EL_MODULE(59,FTM0TIC) || TSS_DETECT_EL_MODULE(60,FTM0TIC) || TSS_DETECT_EL_MODULE(61,FTM0TIC) || TSS_DETECT_EL_MODULE(62,FTM0TIC) || TSS_DETECT_EL_MODULE(63,FTM0TIC))
  #define TSS_FTM1TIC_USED       (TSS_DETECT_EL_MODULE(0,FTM1TIC) || TSS_DETECT_EL_MODULE(1,FTM1TIC) || TSS_DETECT_EL_MODULE(2,FTM1TIC) || TSS_DETECT_EL_MODULE(3,FTM1TIC) || TSS_DETECT_EL_MODULE(4,FTM1TIC) || TSS_DETECT_EL_MODULE(5,FTM1TIC) || TSS_DETECT_EL_MODULE(6,FTM1TIC) || TSS_DETECT_EL_MODULE(7,FTM1TIC) || TSS_DETECT_EL_MODULE(8,FTM1TIC) || TSS_DETECT_EL_MODULE(9,FTM1TIC) || TSS_DETECT_EL_MODULE(10,FTM1TIC) || TSS_DETECT_EL_MODULE(11,FTM1TIC) || TSS_DETECT_EL_MODULE(12,FTM1TIC) || TSS_DETECT_EL_MODULE(13,FTM1TIC) || TSS_DETECT_EL_MODULE(14,FTM1TIC) || TSS_DETECT_EL_MODULE(15,FTM1TIC) || TSS_DETECT_EL_MODULE(16,FTM1TIC) || TSS_DETECT_EL_MODULE(17,FTM1TIC) || TSS_DETECT_EL_MODULE(18,FTM1TIC) || TSS_DETECT_EL_MODULE(19,FTM1TIC) || TSS_DETECT_EL_MODULE(20,FTM1TIC) || TSS_DETECT_EL_MODULE(21,FTM1TIC) || TSS_DETECT_EL_MODULE(22,FTM1TIC) || TSS_DETECT_EL_MODULE(23,FTM1TIC) || TSS_DETECT_EL_MODULE(24,FTM1TIC) || TSS_DETECT_EL_MODULE(25,FTM1TIC) || TSS_DETECT_EL_MODULE(26,FTM1TIC) || TSS_DETECT_EL_MODULE(27,FTM1TIC) || TSS_DETECT_EL_MODULE(28,FTM1TIC) || TSS_DETECT_EL_MODULE(29,FTM1TIC) || TSS_DETECT_EL_MODULE(30,FTM1TIC) || TSS_DETECT_EL_MODULE(31,FTM1TIC) || TSS_DETECT_EL_MODULE(32,FTM1TIC) || TSS_DETECT_EL_MODULE(33,FTM1TIC) || TSS_DETECT_EL_MODULE(34,FTM1TIC) || TSS_DETECT_EL_MODULE(35,FTM1TIC) || TSS_DETECT_EL_MODULE(36,FTM1TIC) || TSS_DETECT_EL_MODULE(37,FTM1TIC) || TSS_DETECT_EL_MODULE(38,FTM1TIC) || TSS_DETECT_EL_MODULE(39,FTM1TIC) || TSS_DETECT_EL_MODULE(40,FTM1TIC) || TSS_DETECT_EL_MODULE(41,FTM1TIC) || TSS_DETECT_EL_MODULE(42,FTM1TIC) || TSS_DETECT_EL_MODULE(43,FTM1TIC) || TSS_DETECT_EL_MODULE(44,FTM1TIC) || TSS_DETECT_EL_MODULE(45,FTM1TIC) || TSS_DETECT_EL_MODULE(46,FTM1TIC) || TSS_DETECT_EL_MODULE(47,FTM1TIC) || TSS_DETECT_EL_MODULE(48,FTM1TIC) || TSS_DETECT_EL_MODULE(49,FTM1TIC) || TSS_DETECT_EL_MODULE(50,FTM1TIC) || TSS_DETECT_EL_MODULE(51,FTM1TIC) || TSS_DETECT_EL_MODULE(52,FTM1TIC) || TSS_DETECT_EL_MODULE(53,FTM1TIC) || TSS_DETECT_EL_MODULE(54,FTM1TIC) || TSS_DETECT_EL_MODULE(55,FTM1TIC) || TSS_DETECT_EL_MODULE(56,FTM1TIC) || TSS_DETECT_EL_MODULE(57,FTM1TIC) || TSS_DETECT_EL_MODULE(58,FTM1TIC) || TSS_DETECT_EL_MODULE(59,FTM1TIC) || TSS_DETECT_EL_MODULE(60,FTM1TIC) || TSS_DETECT_EL_MODULE(61,FTM1TIC) || TSS_DETECT_EL_MODULE(62,FTM1TIC) || TSS_DETECT_EL_MODULE(63,FTM1TIC))
  #define TSS_FTM2TIC_USED       (TSS_DETECT_EL_MODULE(0,FTM2TIC) || TSS_DETECT_EL_MODULE(1,FTM2TIC) || TSS_DETECT_EL_MODULE(2,FTM2TIC) || TSS_DETECT_EL_MODULE(3,FTM2TIC) || TSS_DETECT_EL_MODULE(4,FTM2TIC) || TSS_DETECT_EL_MODULE(5,FTM2TIC) || TSS_DETECT_EL_MODULE(6,FTM2TIC) || TSS_DETECT_EL_MODULE(7,FTM2TIC) || TSS_DETECT_EL_MODULE(8,FTM2TIC) || TSS_DETECT_EL_MODULE(9,FTM2TIC) || TSS_DETECT_EL_MODULE(10,FTM2TIC) || TSS_DETECT_EL_MODULE(11,FTM2TIC) || TSS_DETECT_EL_MODULE(12,FTM2TIC) || TSS_DETECT_EL_MODULE(13,FTM2TIC) || TSS_DETECT_EL_MODULE(14,FTM2TIC) || TSS_DETECT_EL_MODULE(15,FTM2TIC) || TSS_DETECT_EL_MODULE(16,FTM2TIC) || TSS_DETECT_EL_MODULE(17,FTM2TIC) || TSS_DETECT_EL_MODULE(18,FTM2TIC) || TSS_DETECT_EL_MODULE(19,FTM2TIC) || TSS_DETECT_EL_MODULE(20,FTM2TIC) || TSS_DETECT_EL_MODULE(21,FTM2TIC) || TSS_DETECT_EL_MODULE(22,FTM2TIC) || TSS_DETECT_EL_MODULE(23,FTM2TIC) || TSS_DETECT_EL_MODULE(24,FTM2TIC) || TSS_DETECT_EL_MODULE(25,FTM2TIC) || TSS_DETECT_EL_MODULE(26,FTM2TIC) || TSS_DETECT_EL_MODULE(27,FTM2TIC) || TSS_DETECT_EL_MODULE(28,FTM2TIC) || TSS_DETECT_EL_MODULE(29,FTM2TIC) || TSS_DETECT_EL_MODULE(30,FTM2TIC) || TSS_DETECT_EL_MODULE(31,FTM2TIC) || TSS_DETECT_EL_MODULE(32,FTM2TIC) || TSS_DETECT_EL_MODULE(33,FTM2TIC) || TSS_DETECT_EL_MODULE(34,FTM2TIC) || TSS_DETECT_EL_MODULE(35,FTM2TIC) || TSS_DETECT_EL_MODULE(36,FTM2TIC) || TSS_DETECT_EL_MODULE(37,FTM2TIC) || TSS_DETECT_EL_MODULE(38,FTM2TIC) || TSS_DETECT_EL_MODULE(39,FTM2TIC) || TSS_DETECT_EL_MODULE(40,FTM2TIC) || TSS_DETECT_EL_MODULE(41,FTM2TIC) || TSS_DETECT_EL_MODULE(42,FTM2TIC) || TSS_DETECT_EL_MODULE(43,FTM2TIC) || TSS_DETECT_EL_MODULE(44,FTM2TIC) || TSS_DETECT_EL_MODULE(45,FTM2TIC) || TSS_DETECT_EL_MODULE(46,FTM2TIC) || TSS_DETECT_EL_MODULE(47,FTM2TIC) || TSS_DETECT_EL_MODULE(48,FTM2TIC) || TSS_DETECT_EL_MODULE(49,FTM2TIC) || TSS_DETECT_EL_MODULE(50,FTM2TIC) || TSS_DETECT_EL_MODULE(51,FTM2TIC) || TSS_DETECT_EL_MODULE(52,FTM2TIC) || TSS_DETECT_EL_MODULE(53,FTM2TIC) || TSS_DETECT_EL_MODULE(54,FTM2TIC) || TSS_DETECT_EL_MODULE(55,FTM2TIC) || TSS_DETECT_EL_MODULE(56,FTM2TIC) || TSS_DETECT_EL_MODULE(57,FTM2TIC) || TSS_DETECT_EL_MODULE(58,FTM2TIC) || TSS_DETECT_EL_MODULE(59,FTM2TIC) || TSS_DETECT_EL_MODULE(60,FTM2TIC) || TSS_DETECT_EL_MODULE(61,FTM2TIC) || TSS_DETECT_EL_MODULE(62,FTM2TIC) || TSS_DETECT_EL_MODULE(63,FTM2TIC))
  #define TSS_FTM3TIC_USED       (TSS_DETECT_EL_MODULE(0,FTM3TIC) || TSS_DETECT_EL_MODULE(1,FTM3TIC) || TSS_DETECT_EL_MODULE(2,FTM3TIC) || TSS_DETECT_EL_MODULE(3,FTM3TIC) || TSS_DETECT_EL_MODULE(4,FTM3TIC) || TSS_DETECT_EL_MODULE(5,FTM3TIC) || TSS_DETECT_EL_MODULE(6,FTM3TIC) || TSS_DETECT_EL_MODULE(7,FTM3TIC) || TSS_DETECT_EL_MODULE(8,FTM3TIC) || TSS_DETECT_EL_MODULE(9,FTM3TIC) || TSS_DETECT_EL_MODULE(10,FTM3TIC) || TSS_DETECT_EL_MODULE(11,FTM3TIC) || TSS_DETECT_EL_MODULE(12,FTM3TIC) || TSS_DETECT_EL_MODULE(13,FTM3TIC) || TSS_DETECT_EL_MODULE(14,FTM3TIC) || TSS_DETECT_EL_MODULE(15,FTM3TIC) || TSS_DETECT_EL_MODULE(16,FTM3TIC) || TSS_DETECT_EL_MODULE(17,FTM3TIC) || TSS_DETECT_EL_MODULE(18,FTM3TIC) || TSS_DETECT_EL_MODULE(19,FTM3TIC) || TSS_DETECT_EL_MODULE(20,FTM3TIC) || TSS_DETECT_EL_MODULE(21,FTM3TIC) || TSS_DETECT_EL_MODULE(22,FTM3TIC) || TSS_DETECT_EL_MODULE(23,FTM3TIC) || TSS_DETECT_EL_MODULE(24,FTM3TIC) || TSS_DETECT_EL_MODULE(25,FTM3TIC) || TSS_DETECT_EL_MODULE(26,FTM3TIC) || TSS_DETECT_EL_MODULE(27,FTM3TIC) || TSS_DETECT_EL_MODULE(28,FTM3TIC) || TSS_DETECT_EL_MODULE(29,FTM3TIC) || TSS_DETECT_EL_MODULE(30,FTM3TIC) || TSS_DETECT_EL_MODULE(31,FTM3TIC) || TSS_DETECT_EL_MODULE(32,FTM3TIC) || TSS_DETECT_EL_MODULE(33,FTM3TIC) || TSS_DETECT_EL_MODULE(34,FTM3TIC) || TSS_DETECT_EL_MODULE(35,FTM3TIC) || TSS_DETECT_EL_MODULE(36,FTM3TIC) || TSS_DETECT_EL_MODULE(37,FTM3TIC) || TSS_DETECT_EL_MODULE(38,FTM3TIC) || TSS_DETECT_EL_MODULE(39,FTM3TIC) || TSS_DETECT_EL_MODULE(40,FTM3TIC) || TSS_DETECT_EL_MODULE(41,FTM3TIC) || TSS_DETECT_EL_MODULE(42,FTM3TIC) || TSS_DETECT_EL_MODULE(43,FTM3TIC) || TSS_DETECT_EL_MODULE(44,FTM3TIC) || TSS_DETECT_EL_MODULE(45,FTM3TIC) || TSS_DETECT_EL_MODULE(46,FTM3TIC) || TSS_DETECT_EL_MODULE(47,FTM3TIC) || TSS_DETECT_EL_MODULE(48,FTM3TIC) || TSS_DETECT_EL_MODULE(49,FTM3TIC) || TSS_DETECT_EL_MODULE(50,FTM3TIC) || TSS_DETECT_EL_MODULE(51,FTM3TIC) || TSS_DETECT_EL_MODULE(52,FTM3TIC) || TSS_DETECT_EL_MODULE(53,FTM3TIC) || TSS_DETECT_EL_MODULE(54,FTM3TIC) || TSS_DETECT_EL_MODULE(55,FTM3TIC) || TSS_DETECT_EL_MODULE(56,FTM3TIC) || TSS_DETECT_EL_MODULE(57,FTM3TIC) || TSS_DETECT_EL_MODULE(58,FTM3TIC) || TSS_DETECT_EL_MODULE(59,FTM3TIC) || TSS_DETECT_EL_MODULE(60,FTM3TIC) || TSS_DETECT_EL_MODULE(61,FTM3TIC) || TSS_DETECT_EL_MODULE(62,FTM3TIC) || TSS_DETECT_EL_MODULE(63,FTM3TIC))
  #define TSS_FTM4TIC_USED       (TSS_DETECT_EL_MODULE(0,FTM4TIC) || TSS_DETECT_EL_MODULE(1,FTM4TIC) || TSS_DETECT_EL_MODULE(2,FTM4TIC) || TSS_DETECT_EL_MODULE(3,FTM4TIC) || TSS_DETECT_EL_MODULE(4,FTM4TIC) || TSS_DETECT_EL_MODULE(5,FTM4TIC) || TSS_DETECT_EL_MODULE(6,FTM4TIC) || TSS_DETECT_EL_MODULE(7,FTM4TIC) || TSS_DETECT_EL_MODULE(8,FTM4TIC) || TSS_DETECT_EL_MODULE(9,FTM4TIC) || TSS_DETECT_EL_MODULE(10,FTM4TIC) || TSS_DETECT_EL_MODULE(11,FTM4TIC) || TSS_DETECT_EL_MODULE(12,FTM4TIC) || TSS_DETECT_EL_MODULE(13,FTM4TIC) || TSS_DETECT_EL_MODULE(14,FTM4TIC) || TSS_DETECT_EL_MODULE(15,FTM4TIC) || TSS_DETECT_EL_MODULE(16,FTM4TIC) || TSS_DETECT_EL_MODULE(17,FTM4TIC) || TSS_DETECT_EL_MODULE(18,FTM4TIC) || TSS_DETECT_EL_MODULE(19,FTM4TIC) || TSS_DETECT_EL_MODULE(20,FTM4TIC) || TSS_DETECT_EL_MODULE(21,FTM4TIC) || TSS_DETECT_EL_MODULE(22,FTM4TIC) || TSS_DETECT_EL_MODULE(23,FTM4TIC) || TSS_DETECT_EL_MODULE(24,FTM4TIC) || TSS_DETECT_EL_MODULE(25,FTM4TIC) || TSS_DETECT_EL_MODULE(26,FTM4TIC) || TSS_DETECT_EL_MODULE(27,FTM4TIC) || TSS_DETECT_EL_MODULE(28,FTM4TIC) || TSS_DETECT_EL_MODULE(29,FTM4TIC) || TSS_DETECT_EL_MODULE(30,FTM4TIC) || TSS_DETECT_EL_MODULE(31,FTM4TIC) || TSS_DETECT_EL_MODULE(32,FTM4TIC) || TSS_DETECT_EL_MODULE(33,FTM4TIC) || TSS_DETECT_EL_MODULE(34,FTM4TIC) || TSS_DETECT_EL_MODULE(35,FTM4TIC) || TSS_DETECT_EL_MODULE(36,FTM4TIC) || TSS_DETECT_EL_MODULE(37,FTM4TIC) || TSS_DETECT_EL_MODULE(38,FTM4TIC) || TSS_DETECT_EL_MODULE(39,FTM4TIC) || TSS_DETECT_EL_MODULE(40,FTM4TIC) || TSS_DETECT_EL_MODULE(41,FTM4TIC) || TSS_DETECT_EL_MODULE(42,FTM4TIC) || TSS_DETECT_EL_MODULE(43,FTM4TIC) || TSS_DETECT_EL_MODULE(44,FTM4TIC) || TSS_DETECT_EL_MODULE(45,FTM4TIC) || TSS_DETECT_EL_MODULE(46,FTM4TIC) || TSS_DETECT_EL_MODULE(47,FTM4TIC) || TSS_DETECT_EL_MODULE(48,FTM4TIC) || TSS_DETECT_EL_MODULE(49,FTM4TIC) || TSS_DETECT_EL_MODULE(50,FTM4TIC) || TSS_DETECT_EL_MODULE(51,FTM4TIC) || TSS_DETECT_EL_MODULE(52,FTM4TIC) || TSS_DETECT_EL_MODULE(53,FTM4TIC) || TSS_DETECT_EL_MODULE(54,FTM4TIC) || TSS_DETECT_EL_MODULE(55,FTM4TIC) || TSS_DETECT_EL_MODULE(56,FTM4TIC) || TSS_DETECT_EL_MODULE(57,FTM4TIC) || TSS_DETECT_EL_MODULE(58,FTM4TIC) || TSS_DETECT_EL_MODULE(59,FTM4TIC) || TSS_DETECT_EL_MODULE(60,FTM4TIC) || TSS_DETECT_EL_MODULE(61,FTM4TIC) || TSS_DETECT_EL_MODULE(62,FTM4TIC) || TSS_DETECT_EL_MODULE(63,FTM4TIC))

  #define TSS_TIC_METHOD_USED    (TSS_DETECT_EL_METHOD(0,TIC) || TSS_DETECT_EL_METHOD(1,TIC) || TSS_DETECT_EL_METHOD(2,TIC) || TSS_DETECT_EL_METHOD(3,TIC) || TSS_DETECT_EL_METHOD(4,TIC) || TSS_DETECT_EL_METHOD(5,TIC) || TSS_DETECT_EL_METHOD(6,TIC) || TSS_DETECT_EL_METHOD(7,TIC) || TSS_DETECT_EL_METHOD(8,TIC) || TSS_DETECT_EL_METHOD(9,TIC) || TSS_DETECT_EL_METHOD(10,TIC) || TSS_DETECT_EL_METHOD(11,TIC) || TSS_DETECT_EL_METHOD(12,TIC) || TSS_DETECT_EL_METHOD(13,TIC) || TSS_DETECT_EL_METHOD(14,TIC) || TSS_DETECT_EL_METHOD(15,TIC) || TSS_DETECT_EL_METHOD(16,TIC) || TSS_DETECT_EL_METHOD(17,TIC) || TSS_DETECT_EL_METHOD(18,TIC) || TSS_DETECT_EL_METHOD(19,TIC) || TSS_DETECT_EL_METHOD(20,TIC) || TSS_DETECT_EL_METHOD(21,TIC) || TSS_DETECT_EL_METHOD(22,TIC) || TSS_DETECT_EL_METHOD(23,TIC) || TSS_DETECT_EL_METHOD(24,TIC) || TSS_DETECT_EL_METHOD(25,TIC) || TSS_DETECT_EL_METHOD(26,TIC) || TSS_DETECT_EL_METHOD(27,TIC) || TSS_DETECT_EL_METHOD(28,TIC) || TSS_DETECT_EL_METHOD(29,TIC) || TSS_DETECT_EL_METHOD(30,TIC) || TSS_DETECT_EL_METHOD(31,TIC) || TSS_DETECT_EL_METHOD(32,TIC) || TSS_DETECT_EL_METHOD(33,TIC) || TSS_DETECT_EL_METHOD(34,TIC) || TSS_DETECT_EL_METHOD(35,TIC) || TSS_DETECT_EL_METHOD(36,TIC) || TSS_DETECT_EL_METHOD(37,TIC) || TSS_DETECT_EL_METHOD(38,TIC) || TSS_DETECT_EL_METHOD(39,TIC) || TSS_DETECT_EL_METHOD(40,TIC) || TSS_DETECT_EL_METHOD(41,TIC) || TSS_DETECT_EL_METHOD(42,TIC) || TSS_DETECT_EL_METHOD(43,TIC) || TSS_DETECT_EL_METHOD(44,TIC) || TSS_DETECT_EL_METHOD(45,TIC) || TSS_DETECT_EL_METHOD(46,TIC) || TSS_DETECT_EL_METHOD(47,TIC) || TSS_DETECT_EL_METHOD(48,TIC) || TSS_DETECT_EL_METHOD(49,TIC) || TSS_DETECT_EL_METHOD(50,TIC) || TSS_DETECT_EL_METHOD(51,TIC) || TSS_DETECT_EL_METHOD(52,TIC) || TSS_DETECT_EL_METHOD(53,TIC) || TSS_DETECT_EL_METHOD(54,TIC) || TSS_DETECT_EL_METHOD(55,TIC) || TSS_DETECT_EL_METHOD(56,TIC) || TSS_DETECT_EL_METHOD(57,TIC) || TSS_DETECT_EL_METHOD(58,TIC) || TSS_DETECT_EL_METHOD(59,TIC) || TSS_DETECT_EL_METHOD(60,TIC) || TSS_DETECT_EL_METHOD(61,TIC) || TSS_DETECT_EL_METHOD(62,TIC) || TSS_DETECT_EL_METHOD(63,TIC))

  /**************** ROM & RAM Data prototypes ********************/

  #if TSS_N_ELECTRODES > 0
    #if (TSS_DETECT_EL_METHOD(0,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E0_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E0_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 1
    #if (TSS_DETECT_EL_METHOD(1,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E1_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E1_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 2
    #if (TSS_DETECT_EL_METHOD(2,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E2_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E2_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 3
    #if (TSS_DETECT_EL_METHOD(3,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E3_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E3_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 4
    #if (TSS_DETECT_EL_METHOD(4,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E4_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E4_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 5
    #if (TSS_DETECT_EL_METHOD(5,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E5_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E5_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 6
    #if (TSS_DETECT_EL_METHOD(6,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E6_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E6_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 7
    #if (TSS_DETECT_EL_METHOD(7,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E7_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E7_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 8
    #if (TSS_DETECT_EL_METHOD(8,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E8_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E8_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 9
    #if (TSS_DETECT_EL_METHOD(9,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E9_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E9_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 10
    #if (TSS_DETECT_EL_METHOD(10,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E10_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E10_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 11
    #if (TSS_DETECT_EL_METHOD(11,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E11_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E11_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 12
    #if (TSS_DETECT_EL_METHOD(12,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E12_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E12_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 13
    #if (TSS_DETECT_EL_METHOD(13,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E13_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E13_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 14
    #if (TSS_DETECT_EL_METHOD(14,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E14_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E14_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 15
    #if (TSS_DETECT_EL_METHOD(15,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E15_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E15_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 16
    #if (TSS_DETECT_EL_METHOD(16,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E16_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E16_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 17
    #if (TSS_DETECT_EL_METHOD(17,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E17_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E17_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 18
    #if (TSS_DETECT_EL_METHOD(18,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E18_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E18_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 19
    #if (TSS_DETECT_EL_METHOD(19,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E19_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E19_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 20
    #if (TSS_DETECT_EL_METHOD(20,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E20_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E20_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 21
    #if (TSS_DETECT_EL_METHOD(21,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E21_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E21_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 22
    #if (TSS_DETECT_EL_METHOD(22,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E22_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E22_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 23
    #if (TSS_DETECT_EL_METHOD(23,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E23_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E23_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 24
    #if (TSS_DETECT_EL_METHOD(24,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E24_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E24_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 25
    #if (TSS_DETECT_EL_METHOD(25,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E25_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E25_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 26
    #if (TSS_DETECT_EL_METHOD(26,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E26_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E26_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 27
    #if (TSS_DETECT_EL_METHOD(27,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E27_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E27_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 28
    #if (TSS_DETECT_EL_METHOD(28,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E28_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E28_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 29
    #if (TSS_DETECT_EL_METHOD(29,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E29_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E29_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 30
    #if (TSS_DETECT_EL_METHOD(30,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E30_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E30_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 31
    #if (TSS_DETECT_EL_METHOD(31,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E31_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E31_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 32
    #if (TSS_DETECT_EL_METHOD(32,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E32_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E32_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 33
    #if (TSS_DETECT_EL_METHOD(33,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E33_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E33_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 34
    #if (TSS_DETECT_EL_METHOD(34,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E34_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E34_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 35
    #if (TSS_DETECT_EL_METHOD(35,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E35_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E35_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 36
    #if (TSS_DETECT_EL_METHOD(36,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E36_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E36_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 37
    #if (TSS_DETECT_EL_METHOD(37,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E37_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E37_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 38
    #if (TSS_DETECT_EL_METHOD(38,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E38_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E38_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 39
    #if (TSS_DETECT_EL_METHOD(39,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E39_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E39_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 40
    #if (TSS_DETECT_EL_METHOD(40,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E40_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E40_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 41
    #if (TSS_DETECT_EL_METHOD(41,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E41_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E41_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 42
    #if (TSS_DETECT_EL_METHOD(42,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E42_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E42_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 43
    #if (TSS_DETECT_EL_METHOD(43,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E43_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E43_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 44
    #if (TSS_DETECT_EL_METHOD(44,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E44_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E44_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 45
    #if (TSS_DETECT_EL_METHOD(45,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E45_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E45_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 46
    #if (TSS_DETECT_EL_METHOD(46,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E46_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E46_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 47
    #if (TSS_DETECT_EL_METHOD(47,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E47_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E47_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 48
    #if (TSS_DETECT_EL_METHOD(48,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E48_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E48_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 49
    #if (TSS_DETECT_EL_METHOD(49,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E49_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E49_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 50
    #if (TSS_DETECT_EL_METHOD(50,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E50_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E50_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 51
    #if (TSS_DETECT_EL_METHOD(51,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E51_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E51_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 52
    #if (TSS_DETECT_EL_METHOD(52,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E52_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E52_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 53
    #if (TSS_DETECT_EL_METHOD(53,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E53_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E53_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 54
    #if (TSS_DETECT_EL_METHOD(54,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E54_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E54_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 55
    #if (TSS_DETECT_EL_METHOD(55,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E55_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E55_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 56
    #if (TSS_DETECT_EL_METHOD(56,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E56_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E56_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 57
    #if (TSS_DETECT_EL_METHOD(57,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E57_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E57_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 58
    #if (TSS_DETECT_EL_METHOD(58,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E58_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E58_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 59
    #if (TSS_DETECT_EL_METHOD(59,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E59_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E59_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 60
    #if (TSS_DETECT_EL_METHOD(60,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E60_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E60_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 61
    #if (TSS_DETECT_EL_METHOD(61,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E61_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E61_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 62
    #if (TSS_DETECT_EL_METHOD(62,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E62_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E62_RAMDATA_CONTEXT;
    #endif
  #endif

  #if TSS_N_ELECTRODES > 63
    #if (TSS_DETECT_EL_METHOD(63,TIC))
      extern const TSS_TIC_ELECTRODE_ROMDATA TSS_E63_ROMDATA_CONTEXT;
      extern       TSS_TIC_ELECTRODE_RAMDATA TSS_E63_RAMDATA_CONTEXT;
    #endif
  #endif
  
  /*******************************************************
  ******        Determine what is needed             *****
  *******************************************************/

  #if TSS_DETECT_METHOD(TIC)
    /* HW Timer */  
    #ifndef TSS_HW_TIMER_USED
      #define TSS_HW_TIMER_USED      0
    #endif
    /* GPIO */        
    #ifndef TSS_HW_GPIO_USED
      #define TSS_HW_GPIO_USED       1
    #else
      #undef TSS_HW_GPIO_USED
      #define TSS_HW_GPIO_USED       1
    #endif  
  #endif  

  /* 
  * Handler Body of the measurement method 
  */
  #if TSS_HCS08_MCU || TSS_CFV1_MCU

    #define TSS_TIC_SAMPLE_ELECTRODE_LOW(el)    TSS_SAVE_ELECTRODE_PORT(el);          /* Save the electrode port */\
                                                TSS_ELECTRODE_DISCHARGE(el);\
                                                TSS_TIC_TIMER_EL_START(el);\
                                                TSS_TIC_TIMER_EL_CHANNEL_ENABLE(el);   /* Enable Input Capture + Clear channel flag + Charge*/\
                                                TSS_TIC_TIMER_EL_RESET(el);            /* Reset TPM/FTM Counter */\
                                                while(!TSS_TIC_TIMER_EL_CHANNEL_FLAG(el) && !TSS_FAULT_DETECTED)\
                                                {\
                                                  /* MISRA Rule 14.8 */\
                                                }\
                                                TSS_ELECTRODE_CHARGE(el);             /* Charges the required electrode for high state */\
                                                TSS_TIC_TIMER_EL_CHANNEL_DISABLE(el);  /* Disable Input Capture + Clear channel flag + Discharge*/\
                                                TSS_TIC_TIMER_EL_CLEARFLAG(el);        /* Clear Timer Flag */\
                                                TSS_TIC_TIMER_EL_STOP(el);             /* Stop the Timer */\
                                                u16Result = TSS_TIC_TIMER_EL_CHANNEL_V(el);
  
  #elif TSS_KINETIS_MCU /* Kinetis */    

    #define TSS_TIC_SAMPLE_ELECTRODE_LOW(el)    ;    /* Nothing */

  #else /* End of TSS_KINETIS_MCU */
    #error "TSS - Not supported MCU used"  
  #endif    

  /*********** Sample Electrode Low Level Routine assignment ******/

  #if TSS_N_ELECTRODES > 0
    #if (TSS_DETECT_EL_METHOD(0,TIC))
      #define TSS_E0_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(0)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 1
    #if (TSS_DETECT_EL_METHOD(1,TIC))
      #define TSS_E1_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(1)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 2
    #if (TSS_DETECT_EL_METHOD(2,TIC))
      #define TSS_E2_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(2)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 3
    #if (TSS_DETECT_EL_METHOD(3,TIC))
      #define TSS_E3_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(3)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 4
    #if (TSS_DETECT_EL_METHOD(4,TIC))
      #define TSS_E4_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(4)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 5
    #if (TSS_DETECT_EL_METHOD(5,TIC))
      #define TSS_E5_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(5)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 6
    #if (TSS_DETECT_EL_METHOD(6,TIC))
      #define TSS_E6_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(6)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 7
    #if (TSS_DETECT_EL_METHOD(7,TIC))
      #define TSS_E7_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(7)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 8
    #if (TSS_DETECT_EL_METHOD(8,TIC))
      #define TSS_E8_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(8)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 9
    #if (TSS_DETECT_EL_METHOD(9,TIC))
      #define TSS_E9_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(9)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 10
    #if (TSS_DETECT_EL_METHOD(10,TIC))
      #define TSS_E10_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(10)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 11
    #if (TSS_DETECT_EL_METHOD(11,TIC))
      #define TSS_E11_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(11)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 12
    #if (TSS_DETECT_EL_METHOD(12,TIC))
      #define TSS_E12_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(12)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 13
    #if (TSS_DETECT_EL_METHOD(13,TIC))
      #define TSS_E13_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(13)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 14
    #if (TSS_DETECT_EL_METHOD(14,TIC))
      #define TSS_E14_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(14)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 15
    #if (TSS_DETECT_EL_METHOD(15,TIC))
      #define TSS_E15_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(15)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 16
    #if (TSS_DETECT_EL_METHOD(16,TIC))
      #define TSS_E16_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(16)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 17
    #if (TSS_DETECT_EL_METHOD(17,TIC))
      #define TSS_E17_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(17)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 18
    #if (TSS_DETECT_EL_METHOD(18,TIC))
      #define TSS_E18_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(18)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 19
    #if (TSS_DETECT_EL_METHOD(19,TIC))
      #define TSS_E19_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(19)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 20
    #if (TSS_DETECT_EL_METHOD(20,TIC))
      #define TSS_E20_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(20)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 21
    #if (TSS_DETECT_EL_METHOD(21,TIC))
      #define TSS_E21_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(21)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 22
    #if (TSS_DETECT_EL_METHOD(22,TIC))
      #define TSS_E22_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(22)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 23
    #if (TSS_DETECT_EL_METHOD(23,TIC))
      #define TSS_E23_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(23)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 24
    #if (TSS_DETECT_EL_METHOD(24,TIC))
      #define TSS_E24_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(24)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 25
    #if (TSS_DETECT_EL_METHOD(25,TIC))
      #define TSS_E25_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(25)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 26
    #if (TSS_DETECT_EL_METHOD(26,TIC))
      #define TSS_E26_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(26)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 27
    #if (TSS_DETECT_EL_METHOD(27,TIC))
      #define TSS_E27_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(27)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 28
    #if (TSS_DETECT_EL_METHOD(28,TIC))
      #define TSS_E28_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(28)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 29
    #if (TSS_DETECT_EL_METHOD(29,TIC))
      #define TSS_E29_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(29)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 30
    #if (TSS_DETECT_EL_METHOD(30,TIC))
      #define TSS_E30_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(30)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 31
    #if (TSS_DETECT_EL_METHOD(31,TIC))
      #define TSS_E31_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(31)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 32
    #if (TSS_DETECT_EL_METHOD(32,TIC))
      #define TSS_E32_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(32)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 33
    #if (TSS_DETECT_EL_METHOD(33,TIC))
      #define TSS_E33_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(33)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 34
    #if (TSS_DETECT_EL_METHOD(34,TIC))
      #define TSS_E34_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(34)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 35
    #if (TSS_DETECT_EL_METHOD(35,TIC))
      #define TSS_E35_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(35)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 36
    #if (TSS_DETECT_EL_METHOD(36,TIC))
      #define TSS_E36_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(36)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 37
    #if (TSS_DETECT_EL_METHOD(37,TIC))
      #define TSS_E37_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(37)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 38
    #if (TSS_DETECT_EL_METHOD(38,TIC))
      #define TSS_E38_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(38)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 39
    #if (TSS_DETECT_EL_METHOD(39,TIC))
      #define TSS_E39_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(39)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 40
    #if (TSS_DETECT_EL_METHOD(40,TIC))
      #define TSS_E40_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(40)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 41
    #if (TSS_DETECT_EL_METHOD(41,TIC))
      #define TSS_E41_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(41)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 42
    #if (TSS_DETECT_EL_METHOD(42,TIC))
      #define TSS_E42_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(42)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 43
    #if (TSS_DETECT_EL_METHOD(43,TIC))
      #define TSS_E43_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(43)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 44
    #if (TSS_DETECT_EL_METHOD(44,TIC))
      #define TSS_E44_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(44)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 45
    #if (TSS_DETECT_EL_METHOD(45,TIC))
      #define TSS_E45_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(45)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 46
    #if (TSS_DETECT_EL_METHOD(46,TIC))
      #define TSS_E46_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(46)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 47
    #if (TSS_DETECT_EL_METHOD(47,TIC))
      #define TSS_E47_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(47)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 48
    #if (TSS_DETECT_EL_METHOD(48,TIC))
      #define TSS_E48_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(48)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 49
    #if (TSS_DETECT_EL_METHOD(49,TIC))
      #define TSS_E49_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(49)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 50
    #if (TSS_DETECT_EL_METHOD(50,TIC))
      #define TSS_E50_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(50)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 51
    #if (TSS_DETECT_EL_METHOD(51,TIC))
      #define TSS_E51_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(51)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 52
    #if (TSS_DETECT_EL_METHOD(52,TIC))
      #define TSS_E52_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(52)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 53
    #if (TSS_DETECT_EL_METHOD(53,TIC))
      #define TSS_E53_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(53)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 54
    #if (TSS_DETECT_EL_METHOD(54,TIC))
      #define TSS_E54_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(54)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 55
    #if (TSS_DETECT_EL_METHOD(55,TIC))
      #define TSS_E55_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(55)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 56
    #if (TSS_DETECT_EL_METHOD(56,TIC))
      #define TSS_E56_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(56)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 57
    #if (TSS_DETECT_EL_METHOD(57,TIC))
      #define TSS_E57_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(57)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 58
    #if (TSS_DETECT_EL_METHOD(58,TIC))
      #define TSS_E58_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(58)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 59
    #if (TSS_DETECT_EL_METHOD(59,TIC))
      #define TSS_E59_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(59)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 60
    #if (TSS_DETECT_EL_METHOD(60,TIC))
      #define TSS_E60_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(60)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 61
    #if (TSS_DETECT_EL_METHOD(61,TIC))
      #define TSS_E61_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(61)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 62
    #if (TSS_DETECT_EL_METHOD(62,TIC))
      #define TSS_E62_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(62)
    #endif
  #endif
  #if TSS_N_ELECTRODES > 63
    #if (TSS_DETECT_EL_METHOD(63,TIC))
      #define TSS_E63_SAMPLE_ELECTRODE_LOW()    TSS_TIC_SAMPLE_ELECTRODE_LOW(63)
    #endif
  #endif

  /**************** Sample Electrode Routine assignment ***********/

  #if TSS_KINETIS_MCU == 0
    #define TIC_SampleElectrode            UNI_SampleElectrode
  #endif 

  #if TSS_N_ELECTRODES > 0
    #if (TSS_DETECT_EL_METHOD(0,TIC))
      #define TSS_E0_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 1
    #if (TSS_DETECT_EL_METHOD(1,TIC))
      #define TSS_E1_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 2
    #if (TSS_DETECT_EL_METHOD(2,TIC))
      #define TSS_E2_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 3
    #if (TSS_DETECT_EL_METHOD(3,TIC))
      #define TSS_E3_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 4
    #if (TSS_DETECT_EL_METHOD(4,TIC))
      #define TSS_E4_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 5
    #if (TSS_DETECT_EL_METHOD(5,TIC))
      #define TSS_E5_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 6
    #if (TSS_DETECT_EL_METHOD(6,TIC))
      #define TSS_E6_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 7
    #if (TSS_DETECT_EL_METHOD(7,TIC))
      #define TSS_E7_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 8
    #if (TSS_DETECT_EL_METHOD(8,TIC))
      #define TSS_E8_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 9
    #if (TSS_DETECT_EL_METHOD(9,TIC))
      #define TSS_E9_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 10
    #if (TSS_DETECT_EL_METHOD(10,TIC))
      #define TSS_E10_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 11
    #if (TSS_DETECT_EL_METHOD(11,TIC))
      #define TSS_E11_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 12
    #if (TSS_DETECT_EL_METHOD(12,TIC))
      #define TSS_E12_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 13
    #if (TSS_DETECT_EL_METHOD(13,TIC))
      #define TSS_E13_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 14
    #if (TSS_DETECT_EL_METHOD(14,TIC))
      #define TSS_E14_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 15
    #if (TSS_DETECT_EL_METHOD(15,TIC))
      #define TSS_E15_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 16
    #if (TSS_DETECT_EL_METHOD(16,TIC))
      #define TSS_E16_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 17
    #if (TSS_DETECT_EL_METHOD(17,TIC))
      #define TSS_E17_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 18
    #if (TSS_DETECT_EL_METHOD(18,TIC))
      #define TSS_E18_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 19
    #if (TSS_DETECT_EL_METHOD(19,TIC))
      #define TSS_E19_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 20
    #if (TSS_DETECT_EL_METHOD(20,TIC))
      #define TSS_E20_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 21
    #if (TSS_DETECT_EL_METHOD(21,TIC))
      #define TSS_E21_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 22
    #if (TSS_DETECT_EL_METHOD(22,TIC))
      #define TSS_E22_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 23
    #if (TSS_DETECT_EL_METHOD(23,TIC))
      #define TSS_E23_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 24
    #if (TSS_DETECT_EL_METHOD(24,TIC))
      #define TSS_E24_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 25
    #if (TSS_DETECT_EL_METHOD(25,TIC))
      #define TSS_E25_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 26
    #if (TSS_DETECT_EL_METHOD(26,TIC))
      #define TSS_E26_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 27
    #if (TSS_DETECT_EL_METHOD(27,TIC))
      #define TSS_E27_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 28
    #if (TSS_DETECT_EL_METHOD(28,TIC))
      #define TSS_E28_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 29
    #if (TSS_DETECT_EL_METHOD(29,TIC))
      #define TSS_E29_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 30
    #if (TSS_DETECT_EL_METHOD(30,TIC))
      #define TSS_E30_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 31
    #if (TSS_DETECT_EL_METHOD(31,TIC))
      #define TSS_E31_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 32
    #if (TSS_DETECT_EL_METHOD(32,TIC))
      #define TSS_E32_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 33
    #if (TSS_DETECT_EL_METHOD(33,TIC))
      #define TSS_E33_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 34
    #if (TSS_DETECT_EL_METHOD(34,TIC))
      #define TSS_E34_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 35
    #if (TSS_DETECT_EL_METHOD(35,TIC))
      #define TSS_E35_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 36
    #if (TSS_DETECT_EL_METHOD(36,TIC))
      #define TSS_E36_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 37
    #if (TSS_DETECT_EL_METHOD(37,TIC))
      #define TSS_E37_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 38
    #if (TSS_DETECT_EL_METHOD(38,TIC))
      #define TSS_E38_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 39
    #if (TSS_DETECT_EL_METHOD(39,TIC))
      #define TSS_E39_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 40
    #if (TSS_DETECT_EL_METHOD(40,TIC))
      #define TSS_E40_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 41
    #if (TSS_DETECT_EL_METHOD(41,TIC))
      #define TSS_E41_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 42
    #if (TSS_DETECT_EL_METHOD(42,TIC))
      #define TSS_E42_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 43
    #if (TSS_DETECT_EL_METHOD(43,TIC))
      #define TSS_E43_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 44
    #if (TSS_DETECT_EL_METHOD(44,TIC))
      #define TSS_E44_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 45
    #if (TSS_DETECT_EL_METHOD(45,TIC))
      #define TSS_E45_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 46
    #if (TSS_DETECT_EL_METHOD(46,TIC))
      #define TSS_E46_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 47
    #if (TSS_DETECT_EL_METHOD(47,TIC))
      #define TSS_E47_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 48
    #if (TSS_DETECT_EL_METHOD(48,TIC))
      #define TSS_E48_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 49
    #if (TSS_DETECT_EL_METHOD(49,TIC))
      #define TSS_E49_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 50
    #if (TSS_DETECT_EL_METHOD(50,TIC))
      #define TSS_E50_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 51
    #if (TSS_DETECT_EL_METHOD(51,TIC))
      #define TSS_E51_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 52
    #if (TSS_DETECT_EL_METHOD(52,TIC))
      #define TSS_E52_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 53
    #if (TSS_DETECT_EL_METHOD(53,TIC))
      #define TSS_E53_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 54
    #if (TSS_DETECT_EL_METHOD(54,TIC))
      #define TSS_E54_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 55
    #if (TSS_DETECT_EL_METHOD(55,TIC))
      #define TSS_E55_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 56
    #if (TSS_DETECT_EL_METHOD(56,TIC))
      #define TSS_E56_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 57
    #if (TSS_DETECT_EL_METHOD(57,TIC))
      #define TSS_E57_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 58
    #if (TSS_DETECT_EL_METHOD(58,TIC))
      #define TSS_E58_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 59
    #if (TSS_DETECT_EL_METHOD(59,TIC))
      #define TSS_E59_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 60
    #if (TSS_DETECT_EL_METHOD(60,TIC))
      #define TSS_E60_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 61
    #if (TSS_DETECT_EL_METHOD(61,TIC))
      #define TSS_E61_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 62
    #if (TSS_DETECT_EL_METHOD(62,TIC))
      #define TSS_E62_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
  #if TSS_N_ELECTRODES > 63
    #if (TSS_DETECT_EL_METHOD(63,TIC))
      #define TSS_E63_SAMPLE_ELECTRODE()    TIC_SampleElectrode
    #endif
  #endif
      
  /************** TSS_SystemSetup.h Settings validation ***************/

  #if TSS_N_ELECTRODES > 0
    #if (TSS_DETECT_EL_METHOD(0,TIC))
      #ifndef TSS_E0_P
        #error TSS - TSS_E0_P is not defined
      #endif
      #ifndef TSS_E0_B
        #error TSS - TSS_E0_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 1
    #if (TSS_DETECT_EL_METHOD(1,TIC))
      #ifndef TSS_E1_P
        #error TSS - TSS_E1_P is not defined
      #endif
      #ifndef TSS_E1_B
        #error TSS - TSS_E1_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 2
    #if (TSS_DETECT_EL_METHOD(2,TIC))
      #ifndef TSS_E2_P
        #error TSS - TSS_E2_P is not defined
      #endif
      #ifndef TSS_E2_B
        #error TSS - TSS_E2_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 3
    #if (TSS_DETECT_EL_METHOD(3,TIC))
      #ifndef TSS_E3_P
        #error TSS - TSS_E3_P is not defined
      #endif
      #ifndef TSS_E3_B
        #error TSS - TSS_E3_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 4
    #if (TSS_DETECT_EL_METHOD(4,TIC))
      #ifndef TSS_E4_P
        #error TSS - TSS_E4_P is not defined
      #endif
      #ifndef TSS_E4_B
        #error TSS - TSS_E4_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 5
    #if (TSS_DETECT_EL_METHOD(5,TIC))
      #ifndef TSS_E5_P
        #error TSS - TSS_E5_P is not defined
      #endif
      #ifndef TSS_E5_B
        #error TSS - TSS_E5_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 6
    #if (TSS_DETECT_EL_METHOD(6,TIC))
      #ifndef TSS_E6_P
        #error TSS - TSS_E6_P is not defined
      #endif
      #ifndef TSS_E6_B
        #error TSS - TSS_E6_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 7
    #if (TSS_DETECT_EL_METHOD(7,TIC))
      #ifndef TSS_E7_P
        #error TSS - TSS_E7_P is not defined
      #endif
      #ifndef TSS_E7_B
        #error TSS - TSS_E7_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 8
    #if (TSS_DETECT_EL_METHOD(8,TIC))
      #ifndef TSS_E8_P
        #error TSS - TSS_E8_P is not defined
      #endif
      #ifndef TSS_E8_B
        #error TSS - TSS_E8_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 9
    #if (TSS_DETECT_EL_METHOD(9,TIC))
      #ifndef TSS_E9_P
        #error TSS - TSS_E9_P is not defined
      #endif
      #ifndef TSS_E9_B
        #error TSS - TSS_E9_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 10
    #if (TSS_DETECT_EL_METHOD(10,TIC))
      #ifndef TSS_E10_P
        #error TSS - TSS_E10_P is not defined
      #endif
      #ifndef TSS_E10_B
        #error TSS - TSS_E10_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 11
    #if (TSS_DETECT_EL_METHOD(11,TIC))
      #ifndef TSS_E11_P
        #error TSS - TSS_E11_P is not defined
      #endif
      #ifndef TSS_E11_B
        #error TSS - TSS_E11_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 12
    #if (TSS_DETECT_EL_METHOD(12,TIC))
      #ifndef TSS_E12_P
        #error TSS - TSS_E12_P is not defined
      #endif
      #ifndef TSS_E12_B
        #error TSS - TSS_E12_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 13
    #if (TSS_DETECT_EL_METHOD(13,TIC))
      #ifndef TSS_E13_P
        #error TSS - TSS_E13_P is not defined
      #endif
      #ifndef TSS_E13_B
        #error TSS - TSS_E13_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 14
    #if (TSS_DETECT_EL_METHOD(14,TIC))
      #ifndef TSS_E14_P
        #error TSS - TSS_E14_P is not defined
      #endif
      #ifndef TSS_E14_B
        #error TSS - TSS_E14_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 15
    #if (TSS_DETECT_EL_METHOD(15,TIC))
      #ifndef TSS_E15_P
        #error TSS - TSS_E15_P is not defined
      #endif
      #ifndef TSS_E15_B
        #error TSS - TSS_E15_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 16
    #if (TSS_DETECT_EL_METHOD(16,TIC))
      #ifndef TSS_E16_P
        #error TSS - TSS_E16_P is not defined
      #endif
      #ifndef TSS_E16_B
        #error TSS - TSS_E16_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 17
    #if (TSS_DETECT_EL_METHOD(17,TIC))
      #ifndef TSS_E17_P
        #error TSS - TSS_E17_P is not defined
      #endif
      #ifndef TSS_E17_B
        #error TSS - TSS_E17_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 18
    #if (TSS_DETECT_EL_METHOD(18,TIC))
      #ifndef TSS_E18_P
        #error TSS - TSS_E18_P is not defined
      #endif
      #ifndef TSS_E18_B
        #error TSS - TSS_E18_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 19
    #if (TSS_DETECT_EL_METHOD(19,TIC))
      #ifndef TSS_E19_P
        #error TSS - TSS_E19_P is not defined
      #endif
      #ifndef TSS_E19_B
        #error TSS - TSS_E19_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 20
    #if (TSS_DETECT_EL_METHOD(20,TIC))
      #ifndef TSS_E20_P
        #error TSS - TSS_E20_P is not defined
      #endif
      #ifndef TSS_E20_B
        #error TSS - TSS_E20_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 21
    #if (TSS_DETECT_EL_METHOD(21,TIC))
      #ifndef TSS_E21_P
        #error TSS - TSS_E21_P is not defined
      #endif
      #ifndef TSS_E21_B
        #error TSS - TSS_E21_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 22
    #if (TSS_DETECT_EL_METHOD(22,TIC))
      #ifndef TSS_E22_P
        #error TSS - TSS_E22_P is not defined
      #endif
      #ifndef TSS_E22_B
        #error TSS - TSS_E22_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 23
    #if (TSS_DETECT_EL_METHOD(23,TIC))
      #ifndef TSS_E23_P
        #error TSS - TSS_E23_P is not defined
      #endif
      #ifndef TSS_E23_B
        #error TSS - TSS_E23_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 24
    #if (TSS_DETECT_EL_METHOD(24,TIC))
      #ifndef TSS_E24_P
        #error TSS - TSS_E24_P is not defined
      #endif
      #ifndef TSS_E24_B
        #error TSS - TSS_E24_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 25
    #if (TSS_DETECT_EL_METHOD(25,TIC))
      #ifndef TSS_E25_P
        #error TSS - TSS_E25_P is not defined
      #endif
      #ifndef TSS_E25_B
        #error TSS - TSS_E25_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 26
    #if (TSS_DETECT_EL_METHOD(26,TIC))
      #ifndef TSS_E26_P
        #error TSS - TSS_E26_P is not defined
      #endif
      #ifndef TSS_E26_B
        #error TSS - TSS_E26_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 27
    #if (TSS_DETECT_EL_METHOD(27,TIC))
      #ifndef TSS_E27_P
        #error TSS - TSS_E27_P is not defined
      #endif
      #ifndef TSS_E27_B
        #error TSS - TSS_E27_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 28
    #if (TSS_DETECT_EL_METHOD(28,TIC))
      #ifndef TSS_E28_P
        #error TSS - TSS_E28_P is not defined
      #endif
      #ifndef TSS_E28_B
        #error TSS - TSS_E28_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 29
    #if (TSS_DETECT_EL_METHOD(29,TIC))
      #ifndef TSS_E29_P
        #error TSS - TSS_E29_P is not defined
      #endif
      #ifndef TSS_E29_B
        #error TSS - TSS_E29_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 30
    #if (TSS_DETECT_EL_METHOD(30,TIC))
      #ifndef TSS_E30_P
        #error TSS - TSS_E30_P is not defined
      #endif
      #ifndef TSS_E30_B
        #error TSS - TSS_E30_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 31
    #if (TSS_DETECT_EL_METHOD(31,TIC))
      #ifndef TSS_E31_P
        #error TSS - TSS_E31_P is not defined
      #endif
      #ifndef TSS_E31_B
        #error TSS - TSS_E31_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 32
    #if (TSS_DETECT_EL_METHOD(32,TIC))
      #ifndef TSS_E32_P
        #error TSS - TSS_E32_P is not defined
      #endif
      #ifndef TSS_E32_B
        #error TSS - TSS_E32_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 33
    #if (TSS_DETECT_EL_METHOD(33,TIC))
      #ifndef TSS_E33_P
        #error TSS - TSS_E33_P is not defined
      #endif
      #ifndef TSS_E33_B
        #error TSS - TSS_E33_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 34
    #if (TSS_DETECT_EL_METHOD(34,TIC))
      #ifndef TSS_E34_P
        #error TSS - TSS_E34_P is not defined
      #endif
      #ifndef TSS_E34_B
        #error TSS - TSS_E34_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 35
    #if (TSS_DETECT_EL_METHOD(35,TIC))
      #ifndef TSS_E35_P
        #error TSS - TSS_E35_P is not defined
      #endif
      #ifndef TSS_E35_B
        #error TSS - TSS_E35_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 36
    #if (TSS_DETECT_EL_METHOD(36,TIC))
      #ifndef TSS_E36_P
        #error TSS - TSS_E36_P is not defined
      #endif
      #ifndef TSS_E36_B
        #error TSS - TSS_E36_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 37
    #if (TSS_DETECT_EL_METHOD(37,TIC))
      #ifndef TSS_E37_P
        #error TSS - TSS_E37_P is not defined
      #endif
      #ifndef TSS_E37_B
        #error TSS - TSS_E37_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 38
    #if (TSS_DETECT_EL_METHOD(38,TIC))
      #ifndef TSS_E38_P
        #error TSS - TSS_E38_P is not defined
      #endif
      #ifndef TSS_E38_B
        #error TSS - TSS_E38_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 39
    #if (TSS_DETECT_EL_METHOD(39,TIC))
      #ifndef TSS_E39_P
        #error TSS - TSS_E39_P is not defined
      #endif
      #ifndef TSS_E39_B
        #error TSS - TSS_E39_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 40
    #if (TSS_DETECT_EL_METHOD(40,TIC))
      #ifndef TSS_E40_P
        #error TSS - TSS_E40_P is not defined
      #endif
      #ifndef TSS_E40_B
        #error TSS - TSS_E40_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 41
    #if (TSS_DETECT_EL_METHOD(41,TIC))
      #ifndef TSS_E41_P
        #error TSS - TSS_E41_P is not defined
      #endif
      #ifndef TSS_E41_B
        #error TSS - TSS_E41_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 42
    #if (TSS_DETECT_EL_METHOD(42,TIC))
      #ifndef TSS_E42_P
        #error TSS - TSS_E42_P is not defined
      #endif
      #ifndef TSS_E42_B
        #error TSS - TSS_E42_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 43
    #if (TSS_DETECT_EL_METHOD(43,TIC))
      #ifndef TSS_E43_P
        #error TSS - TSS_E43_P is not defined
      #endif
      #ifndef TSS_E43_B
        #error TSS - TSS_E43_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 44
    #if (TSS_DETECT_EL_METHOD(44,TIC))
      #ifndef TSS_E44_P
        #error TSS - TSS_E44_P is not defined
      #endif
      #ifndef TSS_E44_B
        #error TSS - TSS_E44_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 45
    #if (TSS_DETECT_EL_METHOD(45,TIC))
      #ifndef TSS_E45_P
        #error TSS - TSS_E45_P is not defined
      #endif
      #ifndef TSS_E45_B
        #error TSS - TSS_E45_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 46
    #if (TSS_DETECT_EL_METHOD(46,TIC))
      #ifndef TSS_E46_P
        #error TSS - TSS_E46_P is not defined
      #endif
      #ifndef TSS_E46_B
        #error TSS - TSS_E46_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 47
    #if (TSS_DETECT_EL_METHOD(47,TIC))
      #ifndef TSS_E47_P
        #error TSS - TSS_E47_P is not defined
      #endif
      #ifndef TSS_E47_B
        #error TSS - TSS_E47_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 48
    #if (TSS_DETECT_EL_METHOD(48,TIC))
      #ifndef TSS_E48_P
        #error TSS - TSS_E48_P is not defined
      #endif
      #ifndef TSS_E48_B
        #error TSS - TSS_E48_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 49
    #if (TSS_DETECT_EL_METHOD(49,TIC))
      #ifndef TSS_E49_P
        #error TSS - TSS_E49_P is not defined
      #endif
      #ifndef TSS_E49_B
        #error TSS - TSS_E49_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 50
    #if (TSS_DETECT_EL_METHOD(50,TIC))
      #ifndef TSS_E50_P
        #error TSS - TSS_E50_P is not defined
      #endif
      #ifndef TSS_E50_B
        #error TSS - TSS_E50_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 51
    #if (TSS_DETECT_EL_METHOD(51,TIC))
      #ifndef TSS_E51_P
        #error TSS - TSS_E51_P is not defined
      #endif
      #ifndef TSS_E51_B
        #error TSS - TSS_E51_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 52
    #if (TSS_DETECT_EL_METHOD(52,TIC))
      #ifndef TSS_E52_P
        #error TSS - TSS_E52_P is not defined
      #endif
      #ifndef TSS_E52_B
        #error TSS - TSS_E52_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 53
    #if (TSS_DETECT_EL_METHOD(53,TIC))
      #ifndef TSS_E53_P
        #error TSS - TSS_E53_P is not defined
      #endif
      #ifndef TSS_E53_B
        #error TSS - TSS_E53_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 54
    #if (TSS_DETECT_EL_METHOD(54,TIC))
      #ifndef TSS_E54_P
        #error TSS - TSS_E54_P is not defined
      #endif
      #ifndef TSS_E54_B
        #error TSS - TSS_E54_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 55
    #if (TSS_DETECT_EL_METHOD(55,TIC))
      #ifndef TSS_E55_P
        #error TSS - TSS_E55_P is not defined
      #endif
      #ifndef TSS_E55_B
        #error TSS - TSS_E55_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 56
    #if (TSS_DETECT_EL_METHOD(56,TIC))
      #ifndef TSS_E56_P
        #error TSS - TSS_E56_P is not defined
      #endif
      #ifndef TSS_E56_B
        #error TSS - TSS_E56_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 57
    #if (TSS_DETECT_EL_METHOD(57,TIC))
      #ifndef TSS_E57_P
        #error TSS - TSS_E57_P is not defined
      #endif
      #ifndef TSS_E57_B
        #error TSS - TSS_E57_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 58
    #if (TSS_DETECT_EL_METHOD(58,TIC))
      #ifndef TSS_E58_P
        #error TSS - TSS_E58_P is not defined
      #endif
      #ifndef TSS_E58_B
        #error TSS - TSS_E58_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 59
    #if (TSS_DETECT_EL_METHOD(59,TIC))
      #ifndef TSS_E59_P
        #error TSS - TSS_E59_P is not defined
      #endif
      #ifndef TSS_E59_B
        #error TSS - TSS_E59_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 60
    #if (TSS_DETECT_EL_METHOD(60,TIC))
      #ifndef TSS_E60_P
        #error TSS - TSS_E60_P is not defined
      #endif
      #ifndef TSS_E60_B
        #error TSS - TSS_E60_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 61
    #if (TSS_DETECT_EL_METHOD(61,TIC))
      #ifndef TSS_E61_P
        #error TSS - TSS_E61_P is not defined
      #endif
      #ifndef TSS_E61_B
        #error TSS - TSS_E61_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 62
    #if (TSS_DETECT_EL_METHOD(62,TIC))
      #ifndef TSS_E62_P
        #error TSS - TSS_E62_P is not defined
      #endif
      #ifndef TSS_E62_B
        #error TSS - TSS_E62_B is not defined
      #endif
    #endif
  #endif
  #if TSS_N_ELECTRODES > 63
    #if (TSS_DETECT_EL_METHOD(63,TIC))
      #ifndef TSS_E63_P
        #error TSS - TSS_E63_P is not defined
      #endif
      #ifndef TSS_E63_B
        #error TSS - TSS_E63_B is not defined
      #endif
    #endif
  #endif

  /*********************************************************************************
  *                      TPM/FTM Timer Name Recognition
  *********************************************************************************/
      
  #define TSS_TPMCH0_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH1_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH2_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH3_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH4_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH5_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH6_TIC_TIMER_NAME           TPM
  #define TSS_TPMCH7_TIC_TIMER_NAME           TPM
  
  #define TSS_TPM0CH0_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH1_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH2_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH3_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH4_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH5_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH6_TIC_TIMER_NAME          TPM0
  #define TSS_TPM0CH7_TIC_TIMER_NAME          TPM0
  
  #define TSS_TPM1CH0_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH1_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH2_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH3_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH4_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH5_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH6_TIC_TIMER_NAME          TPM1
  #define TSS_TPM1CH7_TIC_TIMER_NAME          TPM1
  
  #define TSS_TPM2CH0_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH1_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH2_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH3_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH4_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH5_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH6_TIC_TIMER_NAME          TPM2
  #define TSS_TPM2CH7_TIC_TIMER_NAME          TPM2
  
  #define TSS_TPM3CH0_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH1_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH2_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH3_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH4_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH5_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH6_TIC_TIMER_NAME          TPM3
  #define TSS_TPM3CH7_TIC_TIMER_NAME          TPM3
  
  #define TSS_TPM4CH0_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH1_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH2_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH3_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH4_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH5_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH6_TIC_TIMER_NAME          TPM4
  #define TSS_TPM4CH7_TIC_TIMER_NAME          TPM4
  
  #define TSS_FTMCH0_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH1_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH2_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH3_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH4_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH5_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH6_TIC_TIMER_NAME           FTM
  #define TSS_FTMCH7_TIC_TIMER_NAME           FTM
  
  #define TSS_FTM0CH0_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH1_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH2_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH3_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH4_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH5_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH6_TIC_TIMER_NAME          FTM0
  #define TSS_FTM0CH7_TIC_TIMER_NAME          FTM0
  
  #define TSS_FTM1CH0_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH1_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH2_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH3_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH4_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH5_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH6_TIC_TIMER_NAME          FTM1
  #define TSS_FTM1CH7_TIC_TIMER_NAME          FTM1
  
  #define TSS_FTM2CH0_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH1_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH2_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH3_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH4_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH5_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH6_TIC_TIMER_NAME          FTM2
  #define TSS_FTM2CH7_TIC_TIMER_NAME          FTM2
  
  #define TSS_FTM3CH0_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH1_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH2_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH3_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH4_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH5_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH6_TIC_TIMER_NAME          FTM3
  #define TSS_FTM3CH7_TIC_TIMER_NAME          FTM3
  
  #define TSS_FTM4CH0_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH1_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH2_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH3_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH4_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH5_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH6_TIC_TIMER_NAME          FTM4
  #define TSS_FTM4CH7_TIC_TIMER_NAME          FTM4
  
  
  #define TSS_TPM_CH0_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH1_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH2_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH3_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH4_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH5_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH6_TIC_TIMER_NAME          TPM
  #define TSS_TPM_CH7_TIC_TIMER_NAME          TPM
  
  #define TSS_TPM0_CH0_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH1_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH2_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH3_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH4_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH5_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH6_TIC_TIMER_NAME         TPM0
  #define TSS_TPM0_CH7_TIC_TIMER_NAME         TPM0
  
  #define TSS_TPM1_CH0_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH1_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH2_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH3_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH4_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH5_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH6_TIC_TIMER_NAME         TPM1
  #define TSS_TPM1_CH7_TIC_TIMER_NAME         TPM1
  
  #define TSS_TPM2_CH0_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH1_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH2_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH3_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH4_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH5_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH6_TIC_TIMER_NAME         TPM2
  #define TSS_TPM2_CH7_TIC_TIMER_NAME         TPM2
  
  #define TSS_TPM3_CH0_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH1_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH2_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH3_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH4_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH5_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH6_TIC_TIMER_NAME         TPM3
  #define TSS_TPM3_CH7_TIC_TIMER_NAME         TPM3
  
  #define TSS_TPM4_CH0_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH1_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH2_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH3_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH4_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH5_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH6_TIC_TIMER_NAME         TPM4
  #define TSS_TPM4_CH7_TIC_TIMER_NAME         TPM4
  
  #define TSS_FTM_CH0_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH1_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH2_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH3_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH4_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH5_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH6_TIC_TIMER_NAME          FTM
  #define TSS_FTM_CH7_TIC_TIMER_NAME          FTM
  
  #define TSS_FTM0_CH0_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH1_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH2_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH3_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH4_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH5_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH6_TIC_TIMER_NAME         FTM0
  #define TSS_FTM0_CH7_TIC_TIMER_NAME         FTM0
  
  #define TSS_FTM1_CH0_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH1_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH2_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH3_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH4_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH5_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH6_TIC_TIMER_NAME         FTM1
  #define TSS_FTM1_CH7_TIC_TIMER_NAME         FTM1
  
  #define TSS_FTM2_CH0_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH1_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH2_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH3_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH4_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH5_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH6_TIC_TIMER_NAME         FTM2
  #define TSS_FTM2_CH7_TIC_TIMER_NAME         FTM2
  
  #define TSS_FTM3_CH0_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH1_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH2_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH3_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH4_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH5_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH6_TIC_TIMER_NAME         FTM3
  #define TSS_FTM3_CH7_TIC_TIMER_NAME         FTM3
  
  #define TSS_FTM4_CH0_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH1_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH2_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH3_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH4_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH5_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH6_TIC_TIMER_NAME         FTM4
  #define TSS_FTM4_CH7_TIC_TIMER_NAME         FTM4
  
  #define TSS_TIC_TIMER_NAME_RESULT(res)     TSS_##res##_TIC_TIMER_NAME
  #define TSS_TIC_TIMER_NAME_CONV(text)      TSS_TIC_TIMER_NAME_RESULT(text)
  #define TSS_TIC_TIMER_NAME(elec)           TSS_TIC_TIMER_NAME_CONV(elec)

  #define TSS_TIC_EL_TIMER_NAME(el)          TSS_TIC_TIMER_NAME(TSS_E##el##_TYPE)     
      
  /*********************************************************************************
  *                      TPM/FTM Timer MUX definition
  *********************************************************************************/
      
  #if TSS_HCS08_MCU || TSS_CFV1_MCU

  #elif TSS_KINETIS_MCU
    #define TSS_PTA0_TIC_TIMER_MUX           3
    #define TSS_PTA1_TIC_TIMER_MUX           3
    #define TSS_PTA2_TIC_TIMER_MUX           3
    #define TSS_PTA3_TIC_TIMER_MUX           3
    #define TSS_PTA4_TIC_TIMER_MUX           3
    #define TSS_PTA5_TIC_TIMER_MUX           3
    #define TSS_PTA6_TIC_TIMER_MUX           3
    #define TSS_PTA7_TIC_TIMER_MUX           3
    #define TSS_PTA8_TIC_TIMER_MUX           3
    #define TSS_PTA9_TIC_TIMER_MUX           3
    #define TSS_PTA10_TIC_TIMER_MUX          3
    #define TSS_PTA11_TIC_TIMER_MUX          3
    #define TSS_PTA12_TIC_TIMER_MUX          3
    #define TSS_PTA13_TIC_TIMER_MUX          3
    #define TSS_PTA14_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA15_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA16_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA17_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA18_TIC_TIMER_MUX          NOTDEF /* FLT */
    #define TSS_PTA19_TIC_TIMER_MUX          NOTDEF /* FLT */
    #define TSS_PTA20_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTA21_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTA22_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTA23_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTA24_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA25_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA26_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA27_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA28_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA29_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTA30_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTA31_TIC_TIMER_MUX          NOTEXIST
  
    #define TSS_PTB0_TIC_TIMER_MUX           3
    #define TSS_PTB1_TIC_TIMER_MUX           3
    #define TSS_PTB2_TIC_TIMER_MUX           NOTDEF /* FLT */
    #define TSS_PTB3_TIC_TIMER_MUX           NOTDEF /* FLT */
    #define TSS_PTB4_TIC_TIMER_MUX           NOTDEF /* FLT */
    #define TSS_PTB5_TIC_TIMER_MUX           NOTDEF /* FLT */
    #define TSS_PTB6_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTB7_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTB8_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTB9_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTB10_TIC_TIMER_MUX          NOTDEF /* FLT */
    #define TSS_PTB11_TIC_TIMER_MUX          NOTDEF /* FLT */
    #define TSS_PTB12_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB13_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB14_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB15_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB16_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTB17_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTB18_TIC_TIMER_MUX          3
    #define TSS_PTB19_TIC_TIMER_MUX          3
    #define TSS_PTB20_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTB21_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTB22_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTB23_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTB24_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB25_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB26_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB27_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB28_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB29_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB30_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTB31_TIC_TIMER_MUX          NOTEXIST
  
    #define TSS_PTC0_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTC1_TIC_TIMER_MUX           4
    #define TSS_PTC2_TIC_TIMER_MUX           4
    #define TSS_PTC3_TIC_TIMER_MUX           4
    #define TSS_PTC4_TIC_TIMER_MUX           4
    #define TSS_PTC5_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTC6_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTC7_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTC8_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTC9_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTC10_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC11_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC12_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC13_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC14_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC15_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC16_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC17_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC18_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC19_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTC20_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC21_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC22_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC23_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC24_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC25_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC26_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC27_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC28_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC29_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC30_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTC31_TIC_TIMER_MUX          NOTEXIST
  
    #define TSS_PTD0_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTD1_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTD2_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTD3_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTD4_TIC_TIMER_MUX           4
    #define TSS_PTD5_TIC_TIMER_MUX           4
    #define TSS_PTD6_TIC_TIMER_MUX           4
    #define TSS_PTD7_TIC_TIMER_MUX           4
    #define TSS_PTD8_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTD9_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTD10_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTD11_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTD12_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTD13_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTD14_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTD15_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTD16_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD17_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD18_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD19_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD20_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD21_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD22_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD23_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD24_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD25_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD26_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD27_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD28_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD29_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD30_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTD31_TIC_TIMER_MUX          NOTEXIST
  
    #define TSS_PTE0_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE1_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE2_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE3_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE4_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE5_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE6_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE7_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE8_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE9_TIC_TIMER_MUX           NOTDEF
    #define TSS_PTE10_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE11_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE12_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE13_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE14_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE15_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE16_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE17_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE18_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE19_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE20_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE21_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE22_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE23_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE24_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE25_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE26_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE27_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE28_TIC_TIMER_MUX          NOTDEF
    #define TSS_PTE29_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE30_TIC_TIMER_MUX          NOTEXIST
    #define TSS_PTE31_TIC_TIMER_MUX          NOTEXIST
  #else /* End of TSS_KINETIS_MCU */
    #error "TSS - Not supported MCU used"
  #endif

  #define TSS_TIC_TIMER_MUX_RESULT(port,bit)     TSS_PT##port##bit##_TIC_TIMER_MUX
  #define TSS_TIC_TIMER_MUX_CONV(port,bit)       TSS_TIC_TIMER_MUX_RESULT(port,bit)
  #define TSS_TIC_TIMER_MUX(port, bit)           TSS_TIC_TIMER_MUX_CONV(port,bit)

  #define TSS_TIC_EL_TIMER_MUX(el)               TSS_TIC_TIMER_MUX(TSS_E##el##_P, TSS_E##el##_B)             

  /*********************************************************************************
  *                      TPM/FTM Timer Input Capture Channel
  *********************************************************************************/

  #define TSS_TPMCH0_TIC_TIMER_CHANNEL           0
  #define TSS_TPMCH1_TIC_TIMER_CHANNEL           1
  #define TSS_TPMCH2_TIC_TIMER_CHANNEL           2
  #define TSS_TPMCH3_TIC_TIMER_CHANNEL           3
  #define TSS_TPMCH4_TIC_TIMER_CHANNEL           4
  #define TSS_TPMCH5_TIC_TIMER_CHANNEL           5
  #define TSS_TPMCH6_TIC_TIMER_CHANNEL           6
  #define TSS_TPMCH7_TIC_TIMER_CHANNEL           7
  
  #define TSS_TPM0CH0_TIC_TIMER_CHANNEL          0
  #define TSS_TPM0CH1_TIC_TIMER_CHANNEL          1
  #define TSS_TPM0CH2_TIC_TIMER_CHANNEL          2
  #define TSS_TPM0CH3_TIC_TIMER_CHANNEL          3
  #define TSS_TPM0CH4_TIC_TIMER_CHANNEL          4
  #define TSS_TPM0CH5_TIC_TIMER_CHANNEL          5
  #define TSS_TPM0CH6_TIC_TIMER_CHANNEL          6
  #define TSS_TPM0CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_TPM1CH0_TIC_TIMER_CHANNEL          0
  #define TSS_TPM1CH1_TIC_TIMER_CHANNEL          1
  #define TSS_TPM1CH2_TIC_TIMER_CHANNEL          2
  #define TSS_TPM1CH3_TIC_TIMER_CHANNEL          3
  #define TSS_TPM1CH4_TIC_TIMER_CHANNEL          4
  #define TSS_TPM1CH5_TIC_TIMER_CHANNEL          5
  #define TSS_TPM1CH6_TIC_TIMER_CHANNEL          6
  #define TSS_TPM1CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_TPM2CH0_TIC_TIMER_CHANNEL          0
  #define TSS_TPM2CH1_TIC_TIMER_CHANNEL          1
  #define TSS_TPM2CH2_TIC_TIMER_CHANNEL          2
  #define TSS_TPM2CH3_TIC_TIMER_CHANNEL          3
  #define TSS_TPM2CH4_TIC_TIMER_CHANNEL          4
  #define TSS_TPM2CH5_TIC_TIMER_CHANNEL          5
  #define TSS_TPM2CH6_TIC_TIMER_CHANNEL          6
  #define TSS_TPM2CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_TPM3CH0_TIC_TIMER_CHANNEL          0
  #define TSS_TPM3CH1_TIC_TIMER_CHANNEL          1
  #define TSS_TPM3CH2_TIC_TIMER_CHANNEL          2
  #define TSS_TPM3CH3_TIC_TIMER_CHANNEL          3
  #define TSS_TPM3CH4_TIC_TIMER_CHANNEL          4
  #define TSS_TPM3CH5_TIC_TIMER_CHANNEL          5
  #define TSS_TPM3CH6_TIC_TIMER_CHANNEL          6
  #define TSS_TPM3CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_TPM4CH0_TIC_TIMER_CHANNEL          0
  #define TSS_TPM4CH1_TIC_TIMER_CHANNEL          1
  #define TSS_TPM4CH2_TIC_TIMER_CHANNEL          2
  #define TSS_TPM4CH3_TIC_TIMER_CHANNEL          3
  #define TSS_TPM4CH4_TIC_TIMER_CHANNEL          4
  #define TSS_TPM4CH5_TIC_TIMER_CHANNEL          5
  #define TSS_TPM4CH6_TIC_TIMER_CHANNEL          6
  #define TSS_TPM4CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_FTMCH0_TIC_TIMER_CHANNEL           0
  #define TSS_FTMCH1_TIC_TIMER_CHANNEL           1
  #define TSS_FTMCH2_TIC_TIMER_CHANNEL           2
  #define TSS_FTMCH3_TIC_TIMER_CHANNEL           3
  #define TSS_FTMCH4_TIC_TIMER_CHANNEL           4
  #define TSS_FTMCH5_TIC_TIMER_CHANNEL           5
  #define TSS_FTMCH6_TIC_TIMER_CHANNEL           6
  #define TSS_FTMCH7_TIC_TIMER_CHANNEL           7
  
  #define TSS_FTM0CH0_TIC_TIMER_CHANNEL          0
  #define TSS_FTM0CH1_TIC_TIMER_CHANNEL          1
  #define TSS_FTM0CH2_TIC_TIMER_CHANNEL          2
  #define TSS_FTM0CH3_TIC_TIMER_CHANNEL          3
  #define TSS_FTM0CH4_TIC_TIMER_CHANNEL          4
  #define TSS_FTM0CH5_TIC_TIMER_CHANNEL          5
  #define TSS_FTM0CH6_TIC_TIMER_CHANNEL          6
  #define TSS_FTM0CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_FTM1CH0_TIC_TIMER_CHANNEL          0
  #define TSS_FTM1CH1_TIC_TIMER_CHANNEL          1
  #define TSS_FTM1CH2_TIC_TIMER_CHANNEL          2
  #define TSS_FTM1CH3_TIC_TIMER_CHANNEL          3
  #define TSS_FTM1CH4_TIC_TIMER_CHANNEL          4
  #define TSS_FTM1CH5_TIC_TIMER_CHANNEL          5
  #define TSS_FTM1CH6_TIC_TIMER_CHANNEL          6
  #define TSS_FTM1CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_FTM2CH0_TIC_TIMER_CHANNEL          0
  #define TSS_FTM2CH1_TIC_TIMER_CHANNEL          1
  #define TSS_FTM2CH2_TIC_TIMER_CHANNEL          2
  #define TSS_FTM2CH3_TIC_TIMER_CHANNEL          3
  #define TSS_FTM2CH4_TIC_TIMER_CHANNEL          4
  #define TSS_FTM2CH5_TIC_TIMER_CHANNEL          5
  #define TSS_FTM2CH6_TIC_TIMER_CHANNEL          6
  #define TSS_FTM2CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_FTM3CH0_TIC_TIMER_CHANNEL          0
  #define TSS_FTM3CH1_TIC_TIMER_CHANNEL          1
  #define TSS_FTM3CH2_TIC_TIMER_CHANNEL          2
  #define TSS_FTM3CH3_TIC_TIMER_CHANNEL          3
  #define TSS_FTM3CH4_TIC_TIMER_CHANNEL          4
  #define TSS_FTM3CH5_TIC_TIMER_CHANNEL          5
  #define TSS_FTM3CH6_TIC_TIMER_CHANNEL          6
  #define TSS_FTM3CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_FTM4CH0_TIC_TIMER_CHANNEL          0
  #define TSS_FTM4CH1_TIC_TIMER_CHANNEL          1
  #define TSS_FTM4CH2_TIC_TIMER_CHANNEL          2
  #define TSS_FTM4CH3_TIC_TIMER_CHANNEL          3
  #define TSS_FTM4CH4_TIC_TIMER_CHANNEL          4
  #define TSS_FTM4CH5_TIC_TIMER_CHANNEL          5
  #define TSS_FTM4CH6_TIC_TIMER_CHANNEL          6
  #define TSS_FTM4CH7_TIC_TIMER_CHANNEL          7
  
  
  #define TSS_TPM_CH0_TIC_TIMER_CHANNEL          0
  #define TSS_TPM_CH1_TIC_TIMER_CHANNEL          1
  #define TSS_TPM_CH2_TIC_TIMER_CHANNEL          2
  #define TSS_TPM_CH3_TIC_TIMER_CHANNEL          3
  #define TSS_TPM_CH4_TIC_TIMER_CHANNEL          4
  #define TSS_TPM_CH5_TIC_TIMER_CHANNEL          5
  #define TSS_TPM_CH6_TIC_TIMER_CHANNEL          6
  #define TSS_TPM_CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_TPM0_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_TPM0_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_TPM0_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_TPM0_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_TPM0_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_TPM0_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_TPM0_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_TPM0_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_TPM1_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_TPM1_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_TPM1_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_TPM1_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_TPM1_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_TPM1_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_TPM1_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_TPM1_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_TPM2_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_TPM2_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_TPM2_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_TPM2_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_TPM2_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_TPM2_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_TPM2_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_TPM2_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_TPM3_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_TPM3_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_TPM3_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_TPM3_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_TPM3_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_TPM3_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_TPM3_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_TPM3_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_TPM4_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_TPM4_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_TPM4_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_TPM4_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_TPM4_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_TPM4_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_TPM4_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_TPM4_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_FTM_CH0_TIC_TIMER_CHANNEL          0
  #define TSS_FTM_CH1_TIC_TIMER_CHANNEL          1
  #define TSS_FTM_CH2_TIC_TIMER_CHANNEL          2
  #define TSS_FTM_CH3_TIC_TIMER_CHANNEL          3
  #define TSS_FTM_CH4_TIC_TIMER_CHANNEL          4
  #define TSS_FTM_CH5_TIC_TIMER_CHANNEL          5
  #define TSS_FTM_CH6_TIC_TIMER_CHANNEL          6
  #define TSS_FTM_CH7_TIC_TIMER_CHANNEL          7
  
  #define TSS_FTM0_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_FTM0_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_FTM0_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_FTM0_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_FTM0_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_FTM0_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_FTM0_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_FTM0_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_FTM1_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_FTM1_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_FTM1_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_FTM1_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_FTM1_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_FTM1_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_FTM1_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_FTM1_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_FTM2_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_FTM2_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_FTM2_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_FTM2_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_FTM2_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_FTM2_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_FTM2_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_FTM2_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_FTM3_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_FTM3_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_FTM3_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_FTM3_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_FTM3_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_FTM3_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_FTM3_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_FTM3_CH7_TIC_TIMER_CHANNEL         7
  
  #define TSS_FTM4_CH0_TIC_TIMER_CHANNEL         0
  #define TSS_FTM4_CH1_TIC_TIMER_CHANNEL         1
  #define TSS_FTM4_CH2_TIC_TIMER_CHANNEL         2
  #define TSS_FTM4_CH3_TIC_TIMER_CHANNEL         3
  #define TSS_FTM4_CH4_TIC_TIMER_CHANNEL         4
  #define TSS_FTM4_CH5_TIC_TIMER_CHANNEL         5
  #define TSS_FTM4_CH6_TIC_TIMER_CHANNEL         6
  #define TSS_FTM4_CH7_TIC_TIMER_CHANNEL         7
      
  #define TSS_TIC_TIMER_CHANNEL_RESULT(res)      TSS_##res##_TIC_TIMER_CHANNEL
  #define TSS_TIC_TIMER_CHANNEL_CONV(text)       TSS_TIC_TIMER_CHANNEL_RESULT(text)
  #define TSS_TIC_TIMER_CHANNEL(elec)            TSS_TIC_TIMER_CHANNEL_CONV(elec)

  #define TSS_TIC_EL_TIMER_CHANNEL(el)           TSS_TIC_TIMER_CHANNEL(TSS_E##el##_TYPE)       
      
  /*********************************************************************************
  *                TPM/FTM Input Capture Method Macros Definitions 
  *********************************************************************************/

  /* Timer name convert macros */
  #define TSS_TIC_TIMER_TO_SC(reg)           reg##SC      
      
  #define TSS_GET_TIC_TIMER_SC(name)         TSS_TIC_TIMER_TO_SC(name)

  /* Addresses of all the configuration timer registers */
  #define TSS_TIC_TIMER_ADDRESS(x)           &TSS_GET_TIC_TIMER_SC(x)  /* The address of the timer is assigned by the compiler */

  /* TPM/FTM configuration values */
  #define TSS_TIC_TIMER_PRESCALE_MASK        0x07U
  #define TSS_TIC_TIMER_IE                   0x40U
  #define TSS_TIC_TIMER_FLAG                 0x80U
  #define TSS_TIC_TIMER_ON                   0x08U
  #define TSS_TIC_TIMER_OFF                  0xE7U
  #define TSS_TIC_TIMER_FLAG_ACK             0x7FU

  /* TPM/FTM Address assignment */
  #define TSS_TIC_TIMER_SC(x)                *(volatile UINT8  *)(TSS_TIC_TIMER_ADDRESS(x)+0) 
  #define TSS_TIC_TIMER_CNT(x)               *(volatile UINT16 *)(TSS_TIC_TIMER_ADDRESS(x)+1)
  #define TSS_TIC_TIMER_CNTH(x)              *(volatile UINT8  *)(TSS_TIC_TIMER_ADDRESS(x)+1)
  #define TSS_TIC_TIMER_CNTL(x)              *(volatile UINT8  *)(TSS_TIC_TIMER_ADDRESS(x)+2)
  #define TSS_TIC_TIMER_MOD(x)               *(volatile UINT16 *)(TSS_TIC_TIMER_ADDRESS(x)+3)
  #define TSS_TIC_TIMER_MODH(x)              *(volatile UINT8  *)(TSS_TIC_TIMER_ADDRESS(x)+3)
  #define TSS_TIC_TIMER_MODL(x)              *(volatile UINT16 *)(TSS_TIC_TIMER_ADDRESS(x)+4)

  /* TPM/FTM Control assignment */  
  #define TSS_TIC_TIMER_SET_PRESCALE(x,y)    (TSS_TIC_TIMER_SC(x) = (UINT8)((TSS_TIC_TIMER_SC(x) & (~TSS_TIC_TIMER_PRESCALE_MASK)) | (y)))   /*Changed due to MISRA*/
  #define TSS_TIC_TIMER_ENABLE_INT(x)        (TSS_TIC_TIMER_SC(x) |= TSS_TIC_TIMER_IE)
  #define TSS_TIC_TIMER_DISABLE_INT(x)       TSS_TIC_TIMER_SC(x) &= !TSS_TIC_TIMER_IE
  #define TSS_TIC_TIMER_SET_MOD(x,y)         (TSS_TIC_TIMER_MOD(x) = y)
  #define TSS_TIC_TIMER_GET_MOD(x)           TSS_TIC_TIMER_MOD(x)
  #define TSS_TIC_TIMER_START(x)             (TSS_TIC_TIMER_SC(x) |= TSS_TIC_TIMER_ON)
  #define TSS_TIC_TIMER_STOP(x)              (TSS_TIC_TIMER_SC(x) &= TSS_TIC_TIMER_OFF)
  #define TSS_TIC_TIMER_RESET(x)             (TSS_TIC_TIMER_CNT(x) = 0x0000U)
  #define TSS_TIC_TIMER_GET_LOWCNT(x)        TSS_TIC_TIMER_CNTL(x)             
  #define TSS_TIC_TIMER_GET_HICNT(x)         TSS_TIC_TIMER_CNTH(x)             
  #define TSS_TIC_TIMER_GET_CNT(x)           TSS_TIC_TIMER_CNT(x)

  #define TSS_TIC_TIMER_CLEARFLAG(x)         TSS_TIC_TIMER_SC(x) &= TSS_TIC_TIMER_FLAG_ACK;
  #define TSS_TIC_TIMER_OVF_FLAG(x)          (TSS_TIC_TIMER_SC(x) & TSS_TIC_TIMER_FLAG)
  #define TSS_TIC_TIMER_RUNS(x)              (TSS_TIC_TIMER_SC(x) & TSS_TIC_TIMER_ON)
  
  /* TPM/FTM Channel Control Macros */

  #define TSS_TPMCH0SC           TPMC0SC
  #define TSS_TPMCH1SC           TPMC1SC
  #define TSS_TPMCH2SC           TPMC2SC
  #define TSS_TPMCH3SC           TPMC3SC
  #define TSS_TPMCH4SC           TPMC4SC
  #define TSS_TPMCH5SC           TPMC5SC
  #define TSS_TPMCH6SC           TPMC6SC
  #define TSS_TPMCH7SC           TPMC7SC
  
  #define TSS_TPM0CH0SC          TPM0C0SC
  #define TSS_TPM0CH1SC          TPM0C1SC
  #define TSS_TPM0CH2SC          TPM0C2SC
  #define TSS_TPM0CH3SC          TPM0C3SC
  #define TSS_TPM0CH4SC          TPM0C4SC
  #define TSS_TPM0CH5SC          TPM0C5SC
  #define TSS_TPM0CH6SC          TPM0C6SC
  #define TSS_TPM0CH7SC          TPM0C7SC
  
  #define TSS_TPM1CH0SC          TPM1C0SC
  #define TSS_TPM1CH1SC          TPM1C1SC
  #define TSS_TPM1CH2SC          TPM1C2SC
  #define TSS_TPM1CH3SC          TPM1C3SC
  #define TSS_TPM1CH4SC          TPM1C4SC
  #define TSS_TPM1CH5SC          TPM1C5SC
  #define TSS_TPM1CH6SC          TPM1C6SC
  #define TSS_TPM1CH7SC          TPM1C7SC
  
  #define TSS_TPM2CH0SC          TPM2C0SC
  #define TSS_TPM2CH1SC          TPM2C1SC
  #define TSS_TPM2CH2SC          TPM2C2SC
  #define TSS_TPM2CH3SC          TPM2C3SC
  #define TSS_TPM2CH4SC          TPM2C4SC
  #define TSS_TPM2CH5SC          TPM2C5SC
  #define TSS_TPM2CH6SC          TPM2C6SC
  #define TSS_TPM2CH7SC          TPM2C7SC
  
  #define TSS_TPM3CH0SC          TPM3C0SC
  #define TSS_TPM3CH1SC          TPM3C1SC
  #define TSS_TPM3CH2SC          TPM3C2SC
  #define TSS_TPM3CH3SC          TPM3C3SC
  #define TSS_TPM3CH4SC          TPM3C4SC
  #define TSS_TPM3CH5SC          TPM3C5SC
  #define TSS_TPM3CH6SC          TPM3C6SC
  #define TSS_TPM3CH7SC          TPM3C7SC
  
  #define TSS_TPM4CH0SC          TPM4C0SC
  #define TSS_TPM4CH1SC          TPM4C1SC
  #define TSS_TPM4CH2SC          TPM4C2SC
  #define TSS_TPM4CH3SC          TPM4C3SC
  #define TSS_TPM4CH4SC          TPM4C4SC
  #define TSS_TPM4CH5SC          TPM4C5SC
  #define TSS_TPM4CH6SC          TPM4C6SC
  #define TSS_TPM4CH7SC          TPM4C7SC
  
  #define TSS_FTMCH0SC           FTMC0SC
  #define TSS_FTMCH1SC           FTMC1SC
  #define TSS_FTMCH2SC           FTMC2SC
  #define TSS_FTMCH3SC           FTMC3SC
  #define TSS_FTMCH4SC           FTMC4SC
  #define TSS_FTMCH5SC           FTMC5SC
  #define TSS_FTMCH6SC           FTMC6SC
  #define TSS_FTMCH7SC           FTMC7SC
  
  #define TSS_FTM0CH0SC          FTM0C0SC
  #define TSS_FTM0CH1SC          FTM0C1SC
  #define TSS_FTM0CH2SC          FTM0C2SC
  #define TSS_FTM0CH3SC          FTM0C3SC
  #define TSS_FTM0CH4SC          FTM0C4SC
  #define TSS_FTM0CH5SC          FTM0C5SC
  #define TSS_FTM0CH6SC          FTM0C6SC
  #define TSS_FTM0CH7SC          FTM0C7SC
  
  #define TSS_FTM1CH0SC          FTM1C0SC
  #define TSS_FTM1CH1SC          FTM1C1SC
  #define TSS_FTM1CH2SC          FTM1C2SC
  #define TSS_FTM1CH3SC          FTM1C3SC
  #define TSS_FTM1CH4SC          FTM1C4SC
  #define TSS_FTM1CH5SC          FTM1C5SC
  #define TSS_FTM1CH6SC          FTM1C6SC
  #define TSS_FTM1CH7SC          FTM1C7SC
  
  #define TSS_FTM2CH0SC          FTM2C0SC
  #define TSS_FTM2CH1SC          FTM2C1SC
  #define TSS_FTM2CH2SC          FTM2C2SC
  #define TSS_FTM2CH3SC          FTM2C3SC
  #define TSS_FTM2CH4SC          FTM2C4SC
  #define TSS_FTM2CH5SC          FTM2C5SC
  #define TSS_FTM2CH6SC          FTM2C6SC
  #define TSS_FTM2CH7SC          FTM2C7SC
  
  #define TSS_FTM3CH0SC          FTM3C0SC
  #define TSS_FTM3CH1SC          FTM3C1SC
  #define TSS_FTM3CH2SC          FTM3C2SC
  #define TSS_FTM3CH3SC          FTM3C3SC
  #define TSS_FTM3CH4SC          FTM3C4SC
  #define TSS_FTM3CH5SC          FTM3C5SC
  #define TSS_FTM3CH6SC          FTM3C6SC
  #define TSS_FTM3CH7SC          FTM3C7SC
  
  #define TSS_FTM4CH0SC          FTM4C0SC
  #define TSS_FTM4CH1SC          FTM4C1SC
  #define TSS_FTM4CH2SC          FTM4C2SC
  #define TSS_FTM4CH3SC          FTM4C3SC
  #define TSS_FTM4CH4SC          FTM4C4SC
  #define TSS_FTM4CH5SC          FTM4C5SC
  #define TSS_FTM4CH6SC          FTM4C6SC
  #define TSS_FTM4CH7SC          FTM4C7SC
  
  
  #define TSS_TPM_CH0SC          TPMC0SC
  #define TSS_TPM_CH1SC          TPMC1SC
  #define TSS_TPM_CH2SC          TPMC2SC
  #define TSS_TPM_CH3SC          TPMC3SC
  #define TSS_TPM_CH4SC          TPMC4SC
  #define TSS_TPM_CH5SC          TPMC5SC
  #define TSS_TPM_CH6SC          TPMC6SC
  #define TSS_TPM_CH7SC          TPMC7SC
  
  #define TSS_TPM0_CH0SC         TPM0C0SC
  #define TSS_TPM0_CH1SC         TPM0C1SC
  #define TSS_TPM0_CH2SC         TPM0C2SC
  #define TSS_TPM0_CH3SC         TPM0C3SC
  #define TSS_TPM0_CH4SC         TPM0C4SC
  #define TSS_TPM0_CH5SC         TPM0C5SC
  #define TSS_TPM0_CH6SC         TPM0C6SC
  #define TSS_TPM0_CH7SC         TPM0C7SC
  
  #define TSS_TPM1_CH0SC         TPM1C0SC
  #define TSS_TPM1_CH1SC         TPM1C1SC
  #define TSS_TPM1_CH2SC         TPM1C2SC
  #define TSS_TPM1_CH3SC         TPM1C3SC
  #define TSS_TPM1_CH4SC         TPM1C4SC
  #define TSS_TPM1_CH5SC         TPM1C5SC
  #define TSS_TPM1_CH6SC         TPM1C6SC
  #define TSS_TPM1_CH7SC         TPM1C7SC
  
  #define TSS_TPM2_CH0SC         TPM2C0SC
  #define TSS_TPM2_CH1SC         TPM2C1SC
  #define TSS_TPM2_CH2SC         TPM2C2SC
  #define TSS_TPM2_CH3SC         TPM2C3SC
  #define TSS_TPM2_CH4SC         TPM2C4SC
  #define TSS_TPM2_CH5SC         TPM2C5SC
  #define TSS_TPM2_CH6SC         TPM2C6SC
  #define TSS_TPM2_CH7SC         TPM2C7SC
  
  #define TSS_TPM3_CH0SC         TPM3C0SC
  #define TSS_TPM3_CH1SC         TPM3C1SC
  #define TSS_TPM3_CH2SC         TPM3C2SC
  #define TSS_TPM3_CH3SC         TPM3C3SC
  #define TSS_TPM3_CH4SC         TPM3C4SC
  #define TSS_TPM3_CH5SC         TPM3C5SC
  #define TSS_TPM3_CH6SC         TPM3C6SC
  #define TSS_TPM3_CH7SC         TPM3C7SC
  
  #define TSS_TPM4_CH0SC         TPM4C0SC
  #define TSS_TPM4_CH1SC         TPM4C1SC
  #define TSS_TPM4_CH2SC         TPM4C2SC
  #define TSS_TPM4_CH3SC         TPM4C3SC
  #define TSS_TPM4_CH4SC         TPM4C4SC
  #define TSS_TPM4_CH5SC         TPM4C5SC
  #define TSS_TPM4_CH6SC         TPM4C6SC
  #define TSS_TPM4_CH7SC         TPM4C7SC
  
  #define TSS_FTM_CH0SC          FTMC0SC
  #define TSS_FTM_CH1SC          FTMC1SC
  #define TSS_FTM_CH2SC          FTMC2SC
  #define TSS_FTM_CH3SC          FTMC3SC
  #define TSS_FTM_CH4SC          FTMC4SC
  #define TSS_FTM_CH5SC          FTMC5SC
  #define TSS_FTM_CH6SC          FTMC6SC
  #define TSS_FTM_CH7SC          FTMC7SC
  
  #define TSS_FTM0_CH0SC         FTM0C0SC
  #define TSS_FTM0_CH1SC         FTM0C1SC
  #define TSS_FTM0_CH2SC         FTM0C2SC
  #define TSS_FTM0_CH3SC         FTM0C3SC
  #define TSS_FTM0_CH4SC         FTM0C4SC
  #define TSS_FTM0_CH5SC         FTM0C5SC
  #define TSS_FTM0_CH6SC         FTM0C6SC
  #define TSS_FTM0_CH7SC         FTM0C7SC
  
  #define TSS_FTM1_CH0SC         FTM1C0SC
  #define TSS_FTM1_CH1SC         FTM1C1SC
  #define TSS_FTM1_CH2SC         FTM1C2SC
  #define TSS_FTM1_CH3SC         FTM1C3SC
  #define TSS_FTM1_CH4SC         FTM1C4SC
  #define TSS_FTM1_CH5SC         FTM1C5SC
  #define TSS_FTM1_CH6SC         FTM1C6SC
  #define TSS_FTM1_CH7SC         FTM1C7SC
  
  #define TSS_FTM2_CH0SC         FTM2C0SC
  #define TSS_FTM2_CH1SC         FTM2C1SC
  #define TSS_FTM2_CH2SC         FTM2C2SC
  #define TSS_FTM2_CH3SC         FTM2C3SC
  #define TSS_FTM2_CH4SC         FTM2C4SC
  #define TSS_FTM2_CH5SC         FTM2C5SC
  #define TSS_FTM2_CH6SC         FTM2C6SC
  #define TSS_FTM2_CH7SC         FTM2C7SC
  
  #define TSS_FTM3_CH0SC         FTM3C0SC
  #define TSS_FTM3_CH1SC         FTM3C1SC
  #define TSS_FTM3_CH2SC         FTM3C2SC
  #define TSS_FTM3_CH3SC         FTM3C3SC
  #define TSS_FTM3_CH4SC         FTM3C4SC
  #define TSS_FTM3_CH5SC         FTM3C5SC
  #define TSS_FTM3_CH6SC         FTM3C6SC
  #define TSS_FTM3_CH7SC         FTM3C7SC
  
  #define TSS_FTM4_CH0SC         FTM4C0SC
  #define TSS_FTM4_CH1SC         FTM4C1SC
  #define TSS_FTM4_CH2SC         FTM4C2SC
  #define TSS_FTM4_CH3SC         FTM4C3SC
  #define TSS_FTM4_CH4SC         FTM4C4SC
  #define TSS_FTM4_CH5SC         FTM4C5SC
  #define TSS_FTM4_CH6SC         FTM4C6SC
  #define TSS_FTM4_CH7SC         FTM4C7SC
      
  #define TSS_TIC_TIMER_TO_CH_SC(reg)        TSS_##reg##SC
  #define TSS_GET_TIC_TIMER_CH_SC(name)      TSS_TIC_TIMER_TO_CH_SC(name)

  #define TSS_TIC_TIMER_CH_ICM_EN            0x04
  #define TSS_TIC_TIMER_CH_FLAG              0x80
  
  /* TPM/FTM Channel Value Read Macros */

  #define TSS_TPMCH0V           TPMC0V
  #define TSS_TPMCH1V           TPMC1V
  #define TSS_TPMCH2V           TPMC2V
  #define TSS_TPMCH3V           TPMC3V
  #define TSS_TPMCH4V           TPMC4V
  #define TSS_TPMCH5V           TPMC5V
  #define TSS_TPMCH6V           TPMC6V
  #define TSS_TPMCH7V           TPMC7V
  
  #define TSS_TPM0CH0V          TPM0C0V
  #define TSS_TPM0CH1V          TPM0C1V
  #define TSS_TPM0CH2V          TPM0C2V
  #define TSS_TPM0CH3V          TPM0C3V
  #define TSS_TPM0CH4V          TPM0C4V
  #define TSS_TPM0CH5V          TPM0C5V
  #define TSS_TPM0CH6V          TPM0C6V
  #define TSS_TPM0CH7V          TPM0C7V
  
  #define TSS_TPM1CH0V          TPM1C0V
  #define TSS_TPM1CH1V          TPM1C1V
  #define TSS_TPM1CH2V          TPM1C2V
  #define TSS_TPM1CH3V          TPM1C3V
  #define TSS_TPM1CH4V          TPM1C4V
  #define TSS_TPM1CH5V          TPM1C5V
  #define TSS_TPM1CH6V          TPM1C6V
  #define TSS_TPM1CH7V          TPM1C7V
  
  #define TSS_TPM2CH0V          TPM2C0V
  #define TSS_TPM2CH1V          TPM2C1V
  #define TSS_TPM2CH2V          TPM2C2V
  #define TSS_TPM2CH3V          TPM2C3V
  #define TSS_TPM2CH4V          TPM2C4V
  #define TSS_TPM2CH5V          TPM2C5V
  #define TSS_TPM2CH6V          TPM2C6V
  #define TSS_TPM2CH7V          TPM2C7V
  
  #define TSS_TPM3CH0V          TPM3C0V
  #define TSS_TPM3CH1V          TPM3C1V
  #define TSS_TPM3CH2V          TPM3C2V
  #define TSS_TPM3CH3V          TPM3C3V
  #define TSS_TPM3CH4V          TPM3C4V
  #define TSS_TPM3CH5V          TPM3C5V
  #define TSS_TPM3CH6V          TPM3C6V
  #define TSS_TPM3CH7V          TPM3C7V
  
  #define TSS_TPM4CH0V          TPM4C0V
  #define TSS_TPM4CH1V          TPM4C1V
  #define TSS_TPM4CH2V          TPM4C2V
  #define TSS_TPM4CH3V          TPM4C3V
  #define TSS_TPM4CH4V          TPM4C4V
  #define TSS_TPM4CH5V          TPM4C5V
  #define TSS_TPM4CH6V          TPM4C6V
  #define TSS_TPM4CH7V          TPM4C7V
  
  #define TSS_FTMCH0V           FTMC0V
  #define TSS_FTMCH1V           FTMC1V
  #define TSS_FTMCH2V           FTMC2V
  #define TSS_FTMCH3V           FTMC3V
  #define TSS_FTMCH4V           FTMC4V
  #define TSS_FTMCH5V           FTMC5V
  #define TSS_FTMCH6V           FTMC6V
  #define TSS_FTMCH7V           FTMC7V
  
  #define TSS_FTM0CH0V          FTM0C0V
  #define TSS_FTM0CH1V          FTM0C1V
  #define TSS_FTM0CH2V          FTM0C2V
  #define TSS_FTM0CH3V          FTM0C3V
  #define TSS_FTM0CH4V          FTM0C4V
  #define TSS_FTM0CH5V          FTM0C5V
  #define TSS_FTM0CH6V          FTM0C6V
  #define TSS_FTM0CH7V          FTM0C7V
  
  #define TSS_FTM1CH0V          FTM1C0V
  #define TSS_FTM1CH1V          FTM1C1V
  #define TSS_FTM1CH2V          FTM1C2V
  #define TSS_FTM1CH3V          FTM1C3V
  #define TSS_FTM1CH4V          FTM1C4V
  #define TSS_FTM1CH5V          FTM1C5V
  #define TSS_FTM1CH6V          FTM1C6V
  #define TSS_FTM1CH7V          FTM1C7V
  
  #define TSS_FTM2CH0V          FTM2C0V
  #define TSS_FTM2CH1V          FTM2C1V
  #define TSS_FTM2CH2V          FTM2C2V
  #define TSS_FTM2CH3V          FTM2C3V
  #define TSS_FTM2CH4V          FTM2C4V
  #define TSS_FTM2CH5V          FTM2C5V
  #define TSS_FTM2CH6V          FTM2C6V
  #define TSS_FTM2CH7V          FTM2C7V
  
  #define TSS_FTM3CH0V          FTM3C0V
  #define TSS_FTM3CH1V          FTM3C1V
  #define TSS_FTM3CH2V          FTM3C2V
  #define TSS_FTM3CH3V          FTM3C3V
  #define TSS_FTM3CH4V          FTM3C4V
  #define TSS_FTM3CH5V          FTM3C5V
  #define TSS_FTM3CH6V          FTM3C6V
  #define TSS_FTM3CH7V          FTM3C7V
  
  #define TSS_FTM4CH0V          FTM4C0V
  #define TSS_FTM4CH1V          FTM4C1V
  #define TSS_FTM4CH2V          FTM4C2V
  #define TSS_FTM4CH3V          FTM4C3V
  #define TSS_FTM4CH4V          FTM4C4V
  #define TSS_FTM4CH5V          FTM4C5V
  #define TSS_FTM4CH6V          FTM4C6V
  #define TSS_FTM4CH7V          FTM4C7V
  
  
  #define TSS_TPM_CH0V          TPMC0V
  #define TSS_TPM_CH1V          TPMC1V
  #define TSS_TPM_CH2V          TPMC2V
  #define TSS_TPM_CH3V          TPMC3V
  #define TSS_TPM_CH4V          TPMC4V
  #define TSS_TPM_CH5V          TPMC5V
  #define TSS_TPM_CH6V          TPMC6V
  #define TSS_TPM_CH7V          TPMC7V
  
  #define TSS_TPM0_CH0V         TPM0C0V
  #define TSS_TPM0_CH1V         TPM0C1V
  #define TSS_TPM0_CH2V         TPM0C2V
  #define TSS_TPM0_CH3V         TPM0C3V
  #define TSS_TPM0_CH4V         TPM0C4V
  #define TSS_TPM0_CH5V         TPM0C5V
  #define TSS_TPM0_CH6V         TPM0C6V
  #define TSS_TPM0_CH7V         TPM0C7V
  
  #define TSS_TPM1_CH0V         TPM1C0V
  #define TSS_TPM1_CH1V         TPM1C1V
  #define TSS_TPM1_CH2V         TPM1C2V
  #define TSS_TPM1_CH3V         TPM1C3V
  #define TSS_TPM1_CH4V         TPM1C4V
  #define TSS_TPM1_CH5V         TPM1C5V
  #define TSS_TPM1_CH6V         TPM1C6V
  #define TSS_TPM1_CH7V         TPM1C7V
  
  #define TSS_TPM2_CH0V         TPM2C0V
  #define TSS_TPM2_CH1V         TPM2C1V
  #define TSS_TPM2_CH2V         TPM2C2V
  #define TSS_TPM2_CH3V         TPM2C3V
  #define TSS_TPM2_CH4V         TPM2C4V
  #define TSS_TPM2_CH5V         TPM2C5V
  #define TSS_TPM2_CH6V         TPM2C6V
  #define TSS_TPM2_CH7V         TPM2C7V
  
  #define TSS_TPM3_CH0V         TPM3C0V
  #define TSS_TPM3_CH1V         TPM3C1V
  #define TSS_TPM3_CH2V         TPM3C2V
  #define TSS_TPM3_CH3V         TPM3C3V
  #define TSS_TPM3_CH4V         TPM3C4V
  #define TSS_TPM3_CH5V         TPM3C5V
  #define TSS_TPM3_CH6V         TPM3C6V
  #define TSS_TPM3_CH7V         TPM3C7V
  
  #define TSS_TPM4_CH0V         TPM4C0V
  #define TSS_TPM4_CH1V         TPM4C1V
  #define TSS_TPM4_CH2V         TPM4C2V
  #define TSS_TPM4_CH3V         TPM4C3V
  #define TSS_TPM4_CH4V         TPM4C4V
  #define TSS_TPM4_CH5V         TPM4C5V
  #define TSS_TPM4_CH6V         TPM4C6V
  #define TSS_TPM4_CH7V         TPM4C7V
  
  #define TSS_FTM_CH0V          FTMC0V
  #define TSS_FTM_CH1V          FTMC1V
  #define TSS_FTM_CH2V          FTMC2V
  #define TSS_FTM_CH3V          FTMC3V
  #define TSS_FTM_CH4V          FTMC4V
  #define TSS_FTM_CH5V          FTMC5V
  #define TSS_FTM_CH6V          FTMC6V
  #define TSS_FTM_CH7V          FTMC7V
  
  #define TSS_FTM0_CH0V         FTM0C0V
  #define TSS_FTM0_CH1V         FTM0C1V
  #define TSS_FTM0_CH2V         FTM0C2V
  #define TSS_FTM0_CH3V         FTM0C3V
  #define TSS_FTM0_CH4V         FTM0C4V
  #define TSS_FTM0_CH5V         FTM0C5V
  #define TSS_FTM0_CH6V         FTM0C6V
  #define TSS_FTM0_CH7V         FTM0C7V
  
  #define TSS_FTM1_CH0V         FTM1C0V
  #define TSS_FTM1_CH1V         FTM1C1V
  #define TSS_FTM1_CH2V         FTM1C2V
  #define TSS_FTM1_CH3V         FTM1C3V
  #define TSS_FTM1_CH4V         FTM1C4V
  #define TSS_FTM1_CH5V         FTM1C5V
  #define TSS_FTM1_CH6V         FTM1C6V
  #define TSS_FTM1_CH7V         FTM1C7V
  
  #define TSS_FTM2_CH0V         FTM2C0V
  #define TSS_FTM2_CH1V         FTM2C1V
  #define TSS_FTM2_CH2V         FTM2C2V
  #define TSS_FTM2_CH3V         FTM2C3V
  #define TSS_FTM2_CH4V         FTM2C4V
  #define TSS_FTM2_CH5V         FTM2C5V
  #define TSS_FTM2_CH6V         FTM2C6V
  #define TSS_FTM2_CH7V         FTM2C7V
  
  #define TSS_FTM3_CH0V         FTM3C0V
  #define TSS_FTM3_CH1V         FTM3C1V
  #define TSS_FTM3_CH2V         FTM3C2V
  #define TSS_FTM3_CH3V         FTM3C3V
  #define TSS_FTM3_CH4V         FTM3C4V
  #define TSS_FTM3_CH5V         FTM3C5V
  #define TSS_FTM3_CH6V         FTM3C6V
  #define TSS_FTM3_CH7V         FTM3C7V
  
  #define TSS_FTM4_CH0V         FTM4C0V
  #define TSS_FTM4_CH1V         FTM4C1V
  #define TSS_FTM4_CH2V         FTM4C2V
  #define TSS_FTM4_CH3V         FTM4C3V
  #define TSS_FTM4_CH4V         FTM4C4V
  #define TSS_FTM4_CH5V         FTM4C5V
  #define TSS_FTM4_CH6V         FTM4C6V
  #define TSS_FTM4_CH7V         FTM4C7V

  #define TSS_TIC_TIMER_TO_CH_V(reg)         TSS_##reg##V
  #define TSS_GET_TIC_TIMER_CH_V(name)       TSS_TIC_TIMER_TO_CH_V(name)

  /* TPM/FTM Timer Control Macros decoded by electrode name*/
  
  #define TSS_TIC_TIMER_EL_RESET(el)            TSS_TIC_TIMER_RESET(TSS_TIC_TIMER_NAME(TSS_E##el##_TYPE))
  #define TSS_TIC_TIMER_EL_START(el)            TSS_TIC_TIMER_START(TSS_TIC_TIMER_NAME(TSS_E##el##_TYPE))
  #define TSS_TIC_TIMER_EL_STOP(el)             TSS_TIC_TIMER_STOP(TSS_TIC_TIMER_NAME(TSS_E##el##_TYPE))
  #define TSS_TIC_TIMER_EL_OVF_FLAG(el)         TSS_TIC_TIMER_OVF_FLAG(TSS_TIC_TIMER_NAME(TSS_E##el##_TYPE))
  #define TSS_TIC_TIMER_EL_CLEARFLAG(el)        TSS_TIC_TIMER_CLEARFLAG(TSS_TIC_TIMER_NAME(TSS_E##el##_TYPE))
  
  #define TSS_TIC_TIMER_EL_CHANNEL_ENABLE(el)   TSS_GET_TIC_TIMER_CH_SC(TSS_E##el##_TYPE) = TSS_TIC_TIMER_CH_ICM_EN
  #define TSS_TIC_TIMER_EL_CHANNEL_FLAG(el)     (TSS_GET_TIC_TIMER_CH_SC(TSS_E##el##_TYPE) & TSS_TIC_TIMER_CH_FLAG)
  #define TSS_TIC_TIMER_EL_CHANNEL_DISABLE(el)  TSS_GET_TIC_TIMER_CH_SC(TSS_E##el##_TYPE) = 0x00
  #define TSS_TIC_TIMER_EL_CHANNEL_V(el)        TSS_GET_TIC_TIMER_CH_V(TSS_E##el##_TYPE)
  
  #define TSS_TIC_TIMER_INIT(timer)             TSS_TIC_TIMER_STOP(timer); /* Stops the timer */\
                                                TSS_TIC_TIMER_RESET(timer); /* Resets the timer */\
                                                TSS_TIC_TIMER_SET_PRESCALE(timer, TSS_SENSOR_PRESCALER); /* Sets a preescaler value */\
                                                TSS_TIC_TIMER_ENABLE_INT(timer); /* Enable Timer interrupt */\
                                                TSS_TIC_TIMER_SET_MOD(timer, TSS_SENSOR_TIMEOUT); /* Sets the timeout value */

  
  /*******************************************************
  **** Indication of not supported MCUs and features ****
  *******************************************************/
  
  #if defined(TSS_HCS08_MCU)
    #if (defined(_MC9S08QD4_H) || defined(_MC9S08QD2_H))
      #if (TSS_TPMTIC_USED || TSS_TPM1TIC_USED || TSS_TPM2TIC_USED || TSS_TPM3TIC_USED || TSS_TPM4TIC_USED)
        #error "Timer Input Capture method is not supported yet by TSS for MC9S08GD family"
      #endif  
      #if (TSS_FTMICM_USED || TSS_FTM1ICM_USED || TSS_FTM2ICM_USED || TSS_FTM3ICM_USED || TSS_FTM4ICM_USED)
        #error "Timer Input Capture method is not supported yet by TSS for MC9S08GD family"
      #endif  
    #endif
    #if (defined(_SC9S08IA4_H) || defined(_SC9S08IA2_H))
      #if (TSS_TPMTIC_USED || TSS_TPM1TIC_USED || TSS_TPM2TIC_USED || TSS_TPM3TIC_USED || TSS_TPM4TIC_USED)
        #error "Timer Input Capture method is not supported yet by TSS for MC9S08IA family"
      #endif  
      #if (TSS_FTMICM_USED || TSS_FTM1ICM_USED || TSS_FTM2ICM_USED || TSS_FTM3ICM_USED || TSS_FTM4ICM_USED)
        #error "Timer Input Capture method is not supported yet by TSS for MC9S08IA family"
      #endif  
    #endif
  #endif
      
#endif /*__TSS_SENSORTIC_H__*/